Class: Aws::AppStream::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::AppStream::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-appstream/client.rb
Overview
An API client for AppStream. To construct a client, you need to configure a ‘:region` and `:credentials`.
client = Aws::AppStream::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the [developer guide](/sdk-for-ruby/v3/developer-guide/setup-config.html).
See #initialize for a full list of supported configuration options.
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#associate_app_block_builder_app_block(params = {}) ⇒ Types::AssociateAppBlockBuilderAppBlockResult
Associates the specified app block builder with the specified app block.
-
#associate_application_fleet(params = {}) ⇒ Types::AssociateApplicationFleetResult
Associates the specified application with the specified fleet.
-
#associate_application_to_entitlement(params = {}) ⇒ Struct
Associates an application to entitle.
-
#associate_fleet(params = {}) ⇒ Struct
Associates the specified fleet with the specified stack.
-
#associate_software_to_image_builder(params = {}) ⇒ Struct
Associates license included application(s) with an existing image builder instance.
-
#batch_associate_user_stack(params = {}) ⇒ Types::BatchAssociateUserStackResult
Associates the specified users with the specified stacks.
-
#batch_disassociate_user_stack(params = {}) ⇒ Types::BatchDisassociateUserStackResult
Disassociates the specified users from the specified stacks.
-
#copy_image(params = {}) ⇒ Types::CopyImageResponse
Copies the image within the same region or to a new region within the same AWS account.
-
#create_app_block(params = {}) ⇒ Types::CreateAppBlockResult
Creates an app block.
-
#create_app_block_builder(params = {}) ⇒ Types::CreateAppBlockBuilderResult
Creates an app block builder.
-
#create_app_block_builder_streaming_url(params = {}) ⇒ Types::CreateAppBlockBuilderStreamingURLResult
Creates a URL to start a create app block builder streaming session.
-
#create_application(params = {}) ⇒ Types::CreateApplicationResult
Creates an application.
-
#create_directory_config(params = {}) ⇒ Types::CreateDirectoryConfigResult
Creates a Directory Config object in WorkSpaces Applications.
-
#create_entitlement(params = {}) ⇒ Types::CreateEntitlementResult
Creates a new entitlement.
-
#create_export_image_task(params = {}) ⇒ Types::CreateExportImageTaskResult
Creates a task to export a WorkSpaces Applications image to an EC2 AMI.
-
#create_fleet(params = {}) ⇒ Types::CreateFleetResult
Creates a fleet.
-
#create_image_builder(params = {}) ⇒ Types::CreateImageBuilderResult
Creates an image builder.
-
#create_image_builder_streaming_url(params = {}) ⇒ Types::CreateImageBuilderStreamingURLResult
Creates a URL to start an image builder streaming session.
-
#create_imported_image(params = {}) ⇒ Types::CreateImportedImageResult
Creates a custom WorkSpaces Applications image by importing an EC2 AMI.
-
#create_stack(params = {}) ⇒ Types::CreateStackResult
Creates a stack to start streaming applications to users.
-
#create_streaming_url(params = {}) ⇒ Types::CreateStreamingURLResult
Creates a temporary URL to start an WorkSpaces Applications streaming session for the specified user.
-
#create_theme_for_stack(params = {}) ⇒ Types::CreateThemeForStackResult
Creates custom branding that customizes the appearance of the streaming application catalog page.
-
#create_updated_image(params = {}) ⇒ Types::CreateUpdatedImageResult
Creates a new image with the latest Windows operating system updates, driver updates, and WorkSpaces Applications agent software.
-
#create_usage_report_subscription(params = {}) ⇒ Types::CreateUsageReportSubscriptionResult
Creates a usage report subscription.
-
#create_user(params = {}) ⇒ Struct
Creates a new user in the user pool.
-
#delete_app_block(params = {}) ⇒ Struct
Deletes an app block.
-
#delete_app_block_builder(params = {}) ⇒ Struct
Deletes an app block builder.
-
#delete_application(params = {}) ⇒ Struct
Deletes an application.
-
#delete_directory_config(params = {}) ⇒ Struct
Deletes the specified Directory Config object from WorkSpaces Applications.
-
#delete_entitlement(params = {}) ⇒ Struct
Deletes the specified entitlement.
-
#delete_fleet(params = {}) ⇒ Struct
Deletes the specified fleet.
-
#delete_image(params = {}) ⇒ Types::DeleteImageResult
Deletes the specified image.
-
#delete_image_builder(params = {}) ⇒ Types::DeleteImageBuilderResult
Deletes the specified image builder and releases the capacity.
-
#delete_image_permissions(params = {}) ⇒ Struct
Deletes permissions for the specified private image.
-
#delete_stack(params = {}) ⇒ Struct
Deletes the specified stack.
-
#delete_theme_for_stack(params = {}) ⇒ Struct
Deletes custom branding that customizes the appearance of the streaming application catalog page.
-
#delete_usage_report_subscription(params = {}) ⇒ Struct
Disables usage report generation.
-
#delete_user(params = {}) ⇒ Struct
Deletes a user from the user pool.
-
#describe_app_block_builder_app_block_associations(params = {}) ⇒ Types::DescribeAppBlockBuilderAppBlockAssociationsResult
Retrieves a list that describes one or more app block builder associations.
-
#describe_app_block_builders(params = {}) ⇒ Types::DescribeAppBlockBuildersResult
Retrieves a list that describes one or more app block builders.
-
#describe_app_blocks(params = {}) ⇒ Types::DescribeAppBlocksResult
Retrieves a list that describes one or more app blocks.
-
#describe_app_license_usage(params = {}) ⇒ Types::DescribeAppLicenseUsageResult
Retrieves license included application usage information.
-
#describe_application_fleet_associations(params = {}) ⇒ Types::DescribeApplicationFleetAssociationsResult
Retrieves a list that describes one or more application fleet associations.
-
#describe_applications(params = {}) ⇒ Types::DescribeApplicationsResult
Retrieves a list that describes one or more applications.
-
#describe_directory_configs(params = {}) ⇒ Types::DescribeDirectoryConfigsResult
Retrieves a list that describes one or more specified Directory Config objects for WorkSpaces Applications, if the names for these objects are provided.
-
#describe_entitlements(params = {}) ⇒ Types::DescribeEntitlementsResult
Retrieves a list that describes one of more entitlements.
-
#describe_fleets(params = {}) ⇒ Types::DescribeFleetsResult
Retrieves a list that describes one or more specified fleets, if the fleet names are provided.
-
#describe_image_builders(params = {}) ⇒ Types::DescribeImageBuildersResult
Retrieves a list that describes one or more specified image builders, if the image builder names are provided.
-
#describe_image_permissions(params = {}) ⇒ Types::DescribeImagePermissionsResult
Retrieves a list that describes the permissions for shared AWS account IDs on a private image that you own.
-
#describe_images(params = {}) ⇒ Types::DescribeImagesResult
Retrieves a list that describes one or more specified images, if the image names or image ARNs are provided.
-
#describe_sessions(params = {}) ⇒ Types::DescribeSessionsResult
Retrieves a list that describes the streaming sessions for a specified stack and fleet.
-
#describe_software_associations(params = {}) ⇒ Types::DescribeSoftwareAssociationsResult
Retrieves license included application associations for a specified resource.
-
#describe_stacks(params = {}) ⇒ Types::DescribeStacksResult
Retrieves a list that describes one or more specified stacks, if the stack names are provided.
-
#describe_theme_for_stack(params = {}) ⇒ Types::DescribeThemeForStackResult
Retrieves a list that describes the theme for a specified stack.
-
#describe_usage_report_subscriptions(params = {}) ⇒ Types::DescribeUsageReportSubscriptionsResult
Retrieves a list that describes one or more usage report subscriptions.
-
#describe_user_stack_associations(params = {}) ⇒ Types::DescribeUserStackAssociationsResult
Retrieves a list that describes the UserStackAssociation objects.
-
#describe_users(params = {}) ⇒ Types::DescribeUsersResult
Retrieves a list that describes one or more specified users in the user pool.
-
#disable_user(params = {}) ⇒ Struct
Disables the specified user in the user pool.
-
#disassociate_app_block_builder_app_block(params = {}) ⇒ Struct
Disassociates a specified app block builder from a specified app block.
-
#disassociate_application_fleet(params = {}) ⇒ Struct
Disassociates the specified application from the fleet.
-
#disassociate_application_from_entitlement(params = {}) ⇒ Struct
Deletes the specified application from the specified entitlement.
-
#disassociate_fleet(params = {}) ⇒ Struct
Disassociates the specified fleet from the specified stack.
-
#disassociate_software_from_image_builder(params = {}) ⇒ Struct
Removes license included application(s) association(s) from an image builder instance.
-
#drain_session_instance(params = {}) ⇒ Struct
Drains the instance hosting the specified streaming session.
-
#enable_user(params = {}) ⇒ Struct
Enables a user in the user pool.
-
#expire_session(params = {}) ⇒ Struct
Immediately stops the specified streaming session.
-
#get_export_image_task(params = {}) ⇒ Types::GetExportImageTaskResult
Retrieves information about an export image task, including its current state, progress, and any error details.
-
#list_associated_fleets(params = {}) ⇒ Types::ListAssociatedFleetsResult
Retrieves the name of the fleet that is associated with the specified stack.
-
#list_associated_stacks(params = {}) ⇒ Types::ListAssociatedStacksResult
Retrieves the name of the stack with which the specified fleet is associated.
-
#list_entitled_applications(params = {}) ⇒ Types::ListEntitledApplicationsResult
Retrieves a list of entitled applications.
-
#list_export_image_tasks(params = {}) ⇒ Types::ListExportImageTasksResult
Lists export image tasks, with optional filtering and pagination.
-
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Retrieves a list of all tags for the specified WorkSpaces Applications resource.
-
#start_app_block_builder(params = {}) ⇒ Types::StartAppBlockBuilderResult
Starts an app block builder.
-
#start_fleet(params = {}) ⇒ Struct
Starts the specified fleet.
-
#start_image_builder(params = {}) ⇒ Types::StartImageBuilderResult
Starts the specified image builder.
-
#start_software_deployment_to_image_builder(params = {}) ⇒ Struct
Initiates license included applications deployment to an image builder instance.
-
#stop_app_block_builder(params = {}) ⇒ Types::StopAppBlockBuilderResult
Stops an app block builder.
-
#stop_fleet(params = {}) ⇒ Struct
Stops the specified fleet.
-
#stop_image_builder(params = {}) ⇒ Types::StopImageBuilderResult
Stops the specified image builder.
-
#tag_resource(params = {}) ⇒ Struct
Adds or overwrites one or more tags for the specified WorkSpaces Applications resource.
-
#untag_resource(params = {}) ⇒ Struct
Disassociates one or more specified tags from the specified WorkSpaces Applications resource.
-
#update_app_block_builder(params = {}) ⇒ Types::UpdateAppBlockBuilderResult
Updates an app block builder.
-
#update_application(params = {}) ⇒ Types::UpdateApplicationResult
Updates the specified application.
-
#update_directory_config(params = {}) ⇒ Types::UpdateDirectoryConfigResult
Updates the specified Directory Config object in WorkSpaces Applications.
-
#update_entitlement(params = {}) ⇒ Types::UpdateEntitlementResult
Updates the specified entitlement.
-
#update_fleet(params = {}) ⇒ Types::UpdateFleetResult
Updates the specified fleet.
-
#update_image_permissions(params = {}) ⇒ Struct
Adds or updates permissions for the specified private image.
-
#update_stack(params = {}) ⇒ Types::UpdateStackResult
Updates the specified fields for the specified stack.
-
#update_theme_for_stack(params = {}) ⇒ Types::UpdateThemeForStackResult
Updates custom branding that customizes the appearance of the streaming application catalog page.
Class Method Summary collapse
- .errors_module ⇒ Object private
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
-
#wait_until(waiter_name, params = {}, options = {}) {|w.waiter| ... } ⇒ Boolean
Polls an API operation until a resource enters a desired state.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
480 481 482 |
# File 'lib/aws-sdk-appstream/client.rb', line 480 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
6602 6603 6604 |
# File 'lib/aws-sdk-appstream/client.rb', line 6602 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
6605 6606 6607 |
# File 'lib/aws-sdk-appstream/client.rb', line 6605 def errors_module Errors end |
Instance Method Details
#associate_app_block_builder_app_block(params = {}) ⇒ Types::AssociateAppBlockBuilderAppBlockResult
Associates the specified app block builder with the specified app block.
515 516 517 518 |
# File 'lib/aws-sdk-appstream/client.rb', line 515 def associate_app_block_builder_app_block(params = {}, = {}) req = build_request(:associate_app_block_builder_app_block, params) req.send_request() end |
#associate_application_fleet(params = {}) ⇒ Types::AssociateApplicationFleetResult
Associates the specified application with the specified fleet. This is only supported for Elastic fleets.
549 550 551 552 |
# File 'lib/aws-sdk-appstream/client.rb', line 549 def associate_application_fleet(params = {}, = {}) req = build_request(:associate_application_fleet, params) req.send_request() end |
#associate_application_to_entitlement(params = {}) ⇒ Struct
Associates an application to entitle.
579 580 581 582 |
# File 'lib/aws-sdk-appstream/client.rb', line 579 def associate_application_to_entitlement(params = {}, = {}) req = build_request(:associate_application_to_entitlement, params) req.send_request() end |
#associate_fleet(params = {}) ⇒ Struct
Associates the specified fleet with the specified stack.
605 606 607 608 |
# File 'lib/aws-sdk-appstream/client.rb', line 605 def associate_fleet(params = {}, = {}) req = build_request(:associate_fleet, params) req.send_request() end |
#associate_software_to_image_builder(params = {}) ⇒ Struct
Associates license included application(s) with an existing image builder instance.
683 684 685 686 |
# File 'lib/aws-sdk-appstream/client.rb', line 683 def associate_software_to_image_builder(params = {}, = {}) req = build_request(:associate_software_to_image_builder, params) req.send_request() end |
#batch_associate_user_stack(params = {}) ⇒ Types::BatchAssociateUserStackResult
Associates the specified users with the specified stacks. Users in a user pool cannot be assigned to stacks with fleets that are joined to an Active Directory domain.
726 727 728 729 |
# File 'lib/aws-sdk-appstream/client.rb', line 726 def batch_associate_user_stack(params = {}, = {}) req = build_request(:batch_associate_user_stack, params) req.send_request() end |
#batch_disassociate_user_stack(params = {}) ⇒ Types::BatchDisassociateUserStackResult
Disassociates the specified users from the specified stacks.
767 768 769 770 |
# File 'lib/aws-sdk-appstream/client.rb', line 767 def batch_disassociate_user_stack(params = {}, = {}) req = build_request(:batch_disassociate_user_stack, params) req.send_request() end |
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
6460 6461 6462 6463 6464 6465 6466 6467 6468 6469 6470 6471 6472 6473 6474 6475 6476 |
# File 'lib/aws-sdk-appstream/client.rb', line 6460 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::AppStream') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-appstream' context[:gem_version] = '1.133.0' Seahorse::Client::Request.new(handlers, context) end |
#copy_image(params = {}) ⇒ Types::CopyImageResponse
Copies the image within the same region or to a new region within the same AWS account. Note that any tags you added to the image will not be copied.
813 814 815 816 |
# File 'lib/aws-sdk-appstream/client.rb', line 813 def copy_image(params = {}, = {}) req = build_request(:copy_image, params) req.send_request() end |
#create_app_block(params = {}) ⇒ Types::CreateAppBlockResult
Creates an app block.
App blocks are a WorkSpaces Applications resource that stores the details about the virtual hard disk in an S3 bucket. It also stores the setup script with details about how to mount the virtual hard disk. The virtual hard disk includes the application binaries and other files necessary to launch your applications. Multiple applications can be assigned to a single app block.
This is only supported for Elastic fleets.
922 923 924 925 |
# File 'lib/aws-sdk-appstream/client.rb', line 922 def create_app_block(params = {}, = {}) req = build_request(:create_app_block, params) req.send_request() end |
#create_app_block_builder(params = {}) ⇒ Types::CreateAppBlockBuilderResult
Creates an app block builder.
1073 1074 1075 1076 |
# File 'lib/aws-sdk-appstream/client.rb', line 1073 def create_app_block_builder(params = {}, = {}) req = build_request(:create_app_block_builder, params) req.send_request() end |
#create_app_block_builder_streaming_url(params = {}) ⇒ Types::CreateAppBlockBuilderStreamingURLResult
Creates a URL to start a create app block builder streaming session.
1108 1109 1110 1111 |
# File 'lib/aws-sdk-appstream/client.rb', line 1108 def create_app_block_builder_streaming_url(params = {}, = {}) req = build_request(:create_app_block_builder_streaming_url, params) req.send_request() end |
#create_application(params = {}) ⇒ Types::CreateApplicationResult
Creates an application.
Applications are a WorkSpaces Applications resource that stores the details about how to launch applications on Elastic fleet streaming instances. An application consists of the launch details, icon, and display name. Applications are associated with an app block that contains the application binaries and other files. The applications assigned to an Elastic fleet are the applications users can launch.
This is only supported for Elastic fleets.
1212 1213 1214 1215 |
# File 'lib/aws-sdk-appstream/client.rb', line 1212 def create_application(params = {}, = {}) req = build_request(:create_application, params) req.send_request() end |
#create_directory_config(params = {}) ⇒ Types::CreateDirectoryConfigResult
Creates a Directory Config object in WorkSpaces Applications. This object includes the configuration information required to join fleets and image builders to Microsoft Active Directory domains.
1279 1280 1281 1282 |
# File 'lib/aws-sdk-appstream/client.rb', line 1279 def create_directory_config(params = {}, = {}) req = build_request(:create_directory_config, params) req.send_request() end |
#create_entitlement(params = {}) ⇒ Types::CreateEntitlementResult
Creates a new entitlement. Entitlements control access to specific applications within a stack, based on user attributes. Entitlements apply to SAML 2.0 federated user identities. WorkSpaces Applications user pool and streaming URL users are entitled to all applications in a stack. Entitlements don’t apply to the desktop stream view application, or to applications managed by a dynamic app provider using the Dynamic Application Framework.
1342 1343 1344 1345 |
# File 'lib/aws-sdk-appstream/client.rb', line 1342 def create_entitlement(params = {}, = {}) req = build_request(:create_entitlement, params) req.send_request() end |
#create_export_image_task(params = {}) ⇒ Types::CreateExportImageTaskResult
Creates a task to export a WorkSpaces Applications image to an EC2 AMI. This allows you to use your customized WorkSpaces Applications images with other AWS services or for backup purposes.
1408 1409 1410 1411 |
# File 'lib/aws-sdk-appstream/client.rb', line 1408 def create_export_image_task(params = {}, = {}) req = build_request(:create_export_image_task, params) req.send_request() end |
#create_fleet(params = {}) ⇒ Types::CreateFleetResult
Creates a fleet. A fleet consists of streaming instances that your users access for their applications and desktops.
1805 1806 1807 1808 |
# File 'lib/aws-sdk-appstream/client.rb', line 1805 def create_fleet(params = {}, = {}) req = build_request(:create_fleet, params) req.send_request() end |
#create_image_builder(params = {}) ⇒ Types::CreateImageBuilderResult
Creates an image builder. An image builder is a virtual machine that is used to create an image.
The initial state of the builder is ‘PENDING`. When it is ready, the state is `RUNNING`.
2190 2191 2192 2193 |
# File 'lib/aws-sdk-appstream/client.rb', line 2190 def create_image_builder(params = {}, = {}) req = build_request(:create_image_builder, params) req.send_request() end |
#create_image_builder_streaming_url(params = {}) ⇒ Types::CreateImageBuilderStreamingURLResult
Creates a URL to start an image builder streaming session.
2225 2226 2227 2228 |
# File 'lib/aws-sdk-appstream/client.rb', line 2225 def create_image_builder_streaming_url(params = {}, = {}) req = build_request(:create_image_builder_streaming_url, params) req.send_request() end |
#create_imported_image(params = {}) ⇒ Types::CreateImportedImageResult
Creates a custom WorkSpaces Applications image by importing an EC2 AMI. This allows you to use your own customized AMI to create WorkSpaces Applications images that support additional instance types beyond the standard stream.* instances.
2374 2375 2376 2377 |
# File 'lib/aws-sdk-appstream/client.rb', line 2374 def create_imported_image(params = {}, = {}) req = build_request(:create_imported_image, params) req.send_request() end |
#create_stack(params = {}) ⇒ Types::CreateStackResult
Creates a stack to start streaming applications to users. A stack consists of an associated fleet, user access policies, and storage configurations.
2570 2571 2572 2573 |
# File 'lib/aws-sdk-appstream/client.rb', line 2570 def create_stack(params = {}, = {}) req = build_request(:create_stack, params) req.send_request() end |
#create_streaming_url(params = {}) ⇒ Types::CreateStreamingURLResult
Creates a temporary URL to start an WorkSpaces Applications streaming session for the specified user. A streaming URL enables application streaming to be tested without user setup.
2632 2633 2634 2635 |
# File 'lib/aws-sdk-appstream/client.rb', line 2632 def create_streaming_url(params = {}, = {}) req = build_request(:create_streaming_url, params) req.send_request() end |
#create_theme_for_stack(params = {}) ⇒ Types::CreateThemeForStackResult
Creates custom branding that customizes the appearance of the streaming application catalog page.
2710 2711 2712 2713 |
# File 'lib/aws-sdk-appstream/client.rb', line 2710 def create_theme_for_stack(params = {}, = {}) req = build_request(:create_theme_for_stack, params) req.send_request() end |
#create_updated_image(params = {}) ⇒ Types::CreateUpdatedImageResult
Creates a new image with the latest Windows operating system updates, driver updates, and WorkSpaces Applications agent software.
For more information, see the “Update an Image by Using Managed WorkSpaces Applications Image Updates” section in [Administer Your WorkSpaces Applications Images], in the *Amazon WorkSpaces Applications Administration Guide*.
[1]: docs.aws.amazon.com/appstream2/latest/developerguide/administer-images.html
2842 2843 2844 2845 |
# File 'lib/aws-sdk-appstream/client.rb', line 2842 def create_updated_image(params = {}, = {}) req = build_request(:create_updated_image, params) req.send_request() end |
#create_usage_report_subscription(params = {}) ⇒ Types::CreateUsageReportSubscriptionResult
Creates a usage report subscription. Usage reports are generated daily.
2864 2865 2866 2867 |
# File 'lib/aws-sdk-appstream/client.rb', line 2864 def create_usage_report_subscription(params = {}, = {}) req = build_request(:create_usage_report_subscription, params) req.send_request() end |
#create_user(params = {}) ⇒ Struct
Creates a new user in the user pool.
2918 2919 2920 2921 |
# File 'lib/aws-sdk-appstream/client.rb', line 2918 def create_user(params = {}, = {}) req = build_request(:create_user, params) req.send_request() end |
#delete_app_block(params = {}) ⇒ Struct
Deletes an app block.
2940 2941 2942 2943 |
# File 'lib/aws-sdk-appstream/client.rb', line 2940 def delete_app_block(params = {}, = {}) req = build_request(:delete_app_block, params) req.send_request() end |
#delete_app_block_builder(params = {}) ⇒ Struct
Deletes an app block builder.
An app block builder can only be deleted when it has no association with an app block.
2965 2966 2967 2968 |
# File 'lib/aws-sdk-appstream/client.rb', line 2965 def delete_app_block_builder(params = {}, = {}) req = build_request(:delete_app_block_builder, params) req.send_request() end |
#delete_application(params = {}) ⇒ Struct
Deletes an application.
2987 2988 2989 2990 |
# File 'lib/aws-sdk-appstream/client.rb', line 2987 def delete_application(params = {}, = {}) req = build_request(:delete_application, params) req.send_request() end |
#delete_directory_config(params = {}) ⇒ Struct
Deletes the specified Directory Config object from WorkSpaces Applications. This object includes the information required to join streaming instances to an Active Directory domain.
3011 3012 3013 3014 |
# File 'lib/aws-sdk-appstream/client.rb', line 3011 def delete_directory_config(params = {}, = {}) req = build_request(:delete_directory_config, params) req.send_request() end |
#delete_entitlement(params = {}) ⇒ Struct
Deletes the specified entitlement.
3037 3038 3039 3040 |
# File 'lib/aws-sdk-appstream/client.rb', line 3037 def delete_entitlement(params = {}, = {}) req = build_request(:delete_entitlement, params) req.send_request() end |
#delete_fleet(params = {}) ⇒ Struct
Deletes the specified fleet.
3059 3060 3061 3062 |
# File 'lib/aws-sdk-appstream/client.rb', line 3059 def delete_fleet(params = {}, = {}) req = build_request(:delete_fleet, params) req.send_request() end |
#delete_image(params = {}) ⇒ Types::DeleteImageResult
Deletes the specified image. You cannot delete an image when it is in use. After you delete an image, you cannot provision new capacity using the image.
3136 3137 3138 3139 |
# File 'lib/aws-sdk-appstream/client.rb', line 3136 def delete_image(params = {}, = {}) req = build_request(:delete_image, params) req.send_request() end |
#delete_image_builder(params = {}) ⇒ Types::DeleteImageBuilderResult
Deletes the specified image builder and releases the capacity.
3197 3198 3199 3200 |
# File 'lib/aws-sdk-appstream/client.rb', line 3197 def delete_image_builder(params = {}, = {}) req = build_request(:delete_image_builder, params) req.send_request() end |
#delete_image_permissions(params = {}) ⇒ Struct
Deletes permissions for the specified private image. After you delete permissions for an image, AWS accounts to which you previously granted these permissions can no longer use the image.
3226 3227 3228 3229 |
# File 'lib/aws-sdk-appstream/client.rb', line 3226 def (params = {}, = {}) req = build_request(:delete_image_permissions, params) req.send_request() end |
#delete_stack(params = {}) ⇒ Struct
Deletes the specified stack. After the stack is deleted, the application streaming environment provided by the stack is no longer available to users. Also, any reservations made for application streaming sessions for the stack are released.
3251 3252 3253 3254 |
# File 'lib/aws-sdk-appstream/client.rb', line 3251 def delete_stack(params = {}, = {}) req = build_request(:delete_stack, params) req.send_request() end |
#delete_theme_for_stack(params = {}) ⇒ Struct
Deletes custom branding that customizes the appearance of the streaming application catalog page.
3274 3275 3276 3277 |
# File 'lib/aws-sdk-appstream/client.rb', line 3274 def delete_theme_for_stack(params = {}, = {}) req = build_request(:delete_theme_for_stack, params) req.send_request() end |
#delete_usage_report_subscription(params = {}) ⇒ Struct
Disables usage report generation.
3287 3288 3289 3290 |
# File 'lib/aws-sdk-appstream/client.rb', line 3287 def delete_usage_report_subscription(params = {}, = {}) req = build_request(:delete_usage_report_subscription, params) req.send_request() end |
#delete_user(params = {}) ⇒ Struct
Deletes a user from the user pool.
3317 3318 3319 3320 |
# File 'lib/aws-sdk-appstream/client.rb', line 3317 def delete_user(params = {}, = {}) req = build_request(:delete_user, params) req.send_request() end |
#describe_app_block_builder_app_block_associations(params = {}) ⇒ Types::DescribeAppBlockBuilderAppBlockAssociationsResult
Retrieves a list that describes one or more app block builder associations.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
3365 3366 3367 3368 |
# File 'lib/aws-sdk-appstream/client.rb', line 3365 def describe_app_block_builder_app_block_associations(params = {}, = {}) req = build_request(:describe_app_block_builder_app_block_associations, params) req.send_request() end |
#describe_app_block_builders(params = {}) ⇒ Types::DescribeAppBlockBuildersResult
Retrieves a list that describes one or more app block builders.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
3430 3431 3432 3433 |
# File 'lib/aws-sdk-appstream/client.rb', line 3430 def describe_app_block_builders(params = {}, = {}) req = build_request(:describe_app_block_builders, params) req.send_request() end |
#describe_app_blocks(params = {}) ⇒ Types::DescribeAppBlocksResult
Retrieves a list that describes one or more app blocks.
3491 3492 3493 3494 |
# File 'lib/aws-sdk-appstream/client.rb', line 3491 def describe_app_blocks(params = {}, = {}) req = build_request(:describe_app_blocks, params) req.send_request() end |
#describe_app_license_usage(params = {}) ⇒ Types::DescribeAppLicenseUsageResult
Retrieves license included application usage information.
3539 3540 3541 3542 |
# File 'lib/aws-sdk-appstream/client.rb', line 3539 def describe_app_license_usage(params = {}, = {}) req = build_request(:describe_app_license_usage, params) req.send_request() end |
#describe_application_fleet_associations(params = {}) ⇒ Types::DescribeApplicationFleetAssociationsResult
Retrieves a list that describes one or more application fleet associations. Either ApplicationArn or FleetName must be specified.
3585 3586 3587 3588 |
# File 'lib/aws-sdk-appstream/client.rb', line 3585 def describe_application_fleet_associations(params = {}, = {}) req = build_request(:describe_application_fleet_associations, params) req.send_request() end |
#describe_applications(params = {}) ⇒ Types::DescribeApplicationsResult
Retrieves a list that describes one or more applications.
3643 3644 3645 3646 |
# File 'lib/aws-sdk-appstream/client.rb', line 3643 def describe_applications(params = {}, = {}) req = build_request(:describe_applications, params) req.send_request() end |
#describe_directory_configs(params = {}) ⇒ Types::DescribeDirectoryConfigsResult
Retrieves a list that describes one or more specified Directory Config objects for WorkSpaces Applications, if the names for these objects are provided. Otherwise, all Directory Config objects in the account are described. These objects include the configuration information required to join fleets and image builders to Microsoft Active Directory domains.
Although the response syntax in this topic includes the account password, this password is not returned in the actual response.
3698 3699 3700 3701 |
# File 'lib/aws-sdk-appstream/client.rb', line 3698 def describe_directory_configs(params = {}, = {}) req = build_request(:describe_directory_configs, params) req.send_request() end |
#describe_entitlements(params = {}) ⇒ Types::DescribeEntitlementsResult
Retrieves a list that describes one of more entitlements.
3750 3751 3752 3753 |
# File 'lib/aws-sdk-appstream/client.rb', line 3750 def describe_entitlements(params = {}, = {}) req = build_request(:describe_entitlements, params) req.send_request() end |
#describe_fleets(params = {}) ⇒ Types::DescribeFleetsResult
Retrieves a list that describes one or more specified fleets, if the fleet names are provided. Otherwise, all fleets in the account are described.
The following waiters are defined for this operation (see #wait_until for detailed usage):
* fleet_started
* fleet_stopped
3838 3839 3840 3841 |
# File 'lib/aws-sdk-appstream/client.rb', line 3838 def describe_fleets(params = {}, = {}) req = build_request(:describe_fleets, params) req.send_request() end |
#describe_image_builders(params = {}) ⇒ Types::DescribeImageBuildersResult
Retrieves a list that describes one or more specified image builders, if the image builder names are provided. Otherwise, all image builders in the account are described.
3913 3914 3915 3916 |
# File 'lib/aws-sdk-appstream/client.rb', line 3913 def describe_image_builders(params = {}, = {}) req = build_request(:describe_image_builders, params) req.send_request() end |
#describe_image_permissions(params = {}) ⇒ Types::DescribeImagePermissionsResult
Retrieves a list that describes the permissions for shared AWS account IDs on a private image that you own.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
3966 3967 3968 3969 |
# File 'lib/aws-sdk-appstream/client.rb', line 3966 def (params = {}, = {}) req = build_request(:describe_image_permissions, params) req.send_request() end |
#describe_images(params = {}) ⇒ Types::DescribeImagesResult
Retrieves a list that describes one or more specified images, if the image names or image ARNs are provided. Otherwise, all images in the account are described.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
4065 4066 4067 4068 |
# File 'lib/aws-sdk-appstream/client.rb', line 4065 def describe_images(params = {}, = {}) req = build_request(:describe_images, params) req.send_request() end |
#describe_sessions(params = {}) ⇒ Types::DescribeSessionsResult
Retrieves a list that describes the streaming sessions for a specified stack and fleet. If a UserId is provided for the stack and fleet, only streaming sessions for that user are described. If an authentication type is not provided, the default is to authenticate users using a streaming URL.
4143 4144 4145 4146 |
# File 'lib/aws-sdk-appstream/client.rb', line 4143 def describe_sessions(params = {}, = {}) req = build_request(:describe_sessions, params) req.send_request() end |
#describe_software_associations(params = {}) ⇒ Types::DescribeSoftwareAssociationsResult
Retrieves license included application associations for a specified resource.
4191 4192 4193 4194 |
# File 'lib/aws-sdk-appstream/client.rb', line 4191 def describe_software_associations(params = {}, = {}) req = build_request(:describe_software_associations, params) req.send_request() end |
#describe_stacks(params = {}) ⇒ Types::DescribeStacksResult
Retrieves a list that describes one or more specified stacks, if the stack names are provided. Otherwise, all stacks in the account are described.
4270 4271 4272 4273 |
# File 'lib/aws-sdk-appstream/client.rb', line 4270 def describe_stacks(params = {}, = {}) req = build_request(:describe_stacks, params) req.send_request() end |
#describe_theme_for_stack(params = {}) ⇒ Types::DescribeThemeForStackResult
Retrieves a list that describes the theme for a specified stack. A theme is custom branding that customizes the appearance of the streaming application catalog page.
4309 4310 4311 4312 |
# File 'lib/aws-sdk-appstream/client.rb', line 4309 def describe_theme_for_stack(params = {}, = {}) req = build_request(:describe_theme_for_stack, params) req.send_request() end |
#describe_usage_report_subscriptions(params = {}) ⇒ Types::DescribeUsageReportSubscriptionsResult
Retrieves a list that describes one or more usage report subscriptions.
4351 4352 4353 4354 |
# File 'lib/aws-sdk-appstream/client.rb', line 4351 def describe_usage_report_subscriptions(params = {}, = {}) req = build_request(:describe_usage_report_subscriptions, params) req.send_request() end |
#describe_user_stack_associations(params = {}) ⇒ Types::DescribeUserStackAssociationsResult
Retrieves a list that describes the UserStackAssociation objects. You must specify either or both of the following:
-
The stack name
-
The user name (email address of the user associated with the stack) and the authentication type for the user
4413 4414 4415 4416 |
# File 'lib/aws-sdk-appstream/client.rb', line 4413 def describe_user_stack_associations(params = {}, = {}) req = build_request(:describe_user_stack_associations, params) req.send_request() end |
#describe_users(params = {}) ⇒ Types::DescribeUsersResult
Retrieves a list that describes one or more specified users in the user pool.
4462 4463 4464 4465 |
# File 'lib/aws-sdk-appstream/client.rb', line 4462 def describe_users(params = {}, = {}) req = build_request(:describe_users, params) req.send_request() end |
#disable_user(params = {}) ⇒ Struct
Disables the specified user in the user pool. Users can’t sign in to WorkSpaces Applications until they are re-enabled. This action does not delete the user.
4494 4495 4496 4497 |
# File 'lib/aws-sdk-appstream/client.rb', line 4494 def disable_user(params = {}, = {}) req = build_request(:disable_user, params) req.send_request() end |
#disassociate_app_block_builder_app_block(params = {}) ⇒ Struct
Disassociates a specified app block builder from a specified app block.
4521 4522 4523 4524 |
# File 'lib/aws-sdk-appstream/client.rb', line 4521 def disassociate_app_block_builder_app_block(params = {}, = {}) req = build_request(:disassociate_app_block_builder_app_block, params) req.send_request() end |
#disassociate_application_fleet(params = {}) ⇒ Struct
Disassociates the specified application from the fleet.
4547 4548 4549 4550 |
# File 'lib/aws-sdk-appstream/client.rb', line 4547 def disassociate_application_fleet(params = {}, = {}) req = build_request(:disassociate_application_fleet, params) req.send_request() end |
#disassociate_application_from_entitlement(params = {}) ⇒ Struct
Deletes the specified application from the specified entitlement.
4577 4578 4579 4580 |
# File 'lib/aws-sdk-appstream/client.rb', line 4577 def disassociate_application_from_entitlement(params = {}, = {}) req = build_request(:disassociate_application_from_entitlement, params) req.send_request() end |
#disassociate_fleet(params = {}) ⇒ Struct
Disassociates the specified fleet from the specified stack.
4603 4604 4605 4606 |
# File 'lib/aws-sdk-appstream/client.rb', line 4603 def disassociate_fleet(params = {}, = {}) req = build_request(:disassociate_fleet, params) req.send_request() end |
#disassociate_software_from_image_builder(params = {}) ⇒ Struct
Removes license included application(s) association(s) from an image builder instance.
4681 4682 4683 4684 |
# File 'lib/aws-sdk-appstream/client.rb', line 4681 def disassociate_software_from_image_builder(params = {}, = {}) req = build_request(:disassociate_software_from_image_builder, params) req.send_request() end |
#drain_session_instance(params = {}) ⇒ Struct
Drains the instance hosting the specified streaming session. The instance stops accepting new sessions while existing sessions continue uninterrupted. Once all sessions end, the instance is reclaimed and replaced. This only applies to multi-session fleets.
4706 4707 4708 4709 |
# File 'lib/aws-sdk-appstream/client.rb', line 4706 def drain_session_instance(params = {}, = {}) req = build_request(:drain_session_instance, params) req.send_request() end |
#enable_user(params = {}) ⇒ Struct
Enables a user in the user pool. After being enabled, users can sign in to WorkSpaces Applications and open applications from the stacks to which they are assigned.
4741 4742 4743 4744 |
# File 'lib/aws-sdk-appstream/client.rb', line 4741 def enable_user(params = {}, = {}) req = build_request(:enable_user, params) req.send_request() end |
#expire_session(params = {}) ⇒ Struct
Immediately stops the specified streaming session.
4763 4764 4765 4766 |
# File 'lib/aws-sdk-appstream/client.rb', line 4763 def expire_session(params = {}, = {}) req = build_request(:expire_session, params) req.send_request() end |
#get_export_image_task(params = {}) ⇒ Types::GetExportImageTaskResult
Retrieves information about an export image task, including its current state, progress, and any error details.
4804 4805 4806 4807 |
# File 'lib/aws-sdk-appstream/client.rb', line 4804 def get_export_image_task(params = {}, = {}) req = build_request(:get_export_image_task, params) req.send_request() end |
#list_associated_fleets(params = {}) ⇒ Types::ListAssociatedFleetsResult
Retrieves the name of the fleet that is associated with the specified stack.
4841 4842 4843 4844 |
# File 'lib/aws-sdk-appstream/client.rb', line 4841 def list_associated_fleets(params = {}, = {}) req = build_request(:list_associated_fleets, params) req.send_request() end |
#list_associated_stacks(params = {}) ⇒ Types::ListAssociatedStacksResult
Retrieves the name of the stack with which the specified fleet is associated.
4878 4879 4880 4881 |
# File 'lib/aws-sdk-appstream/client.rb', line 4878 def list_associated_stacks(params = {}, = {}) req = build_request(:list_associated_stacks, params) req.send_request() end |
#list_entitled_applications(params = {}) ⇒ Types::ListEntitledApplicationsResult
Retrieves a list of entitled applications.
4922 4923 4924 4925 |
# File 'lib/aws-sdk-appstream/client.rb', line 4922 def list_entitled_applications(params = {}, = {}) req = build_request(:list_entitled_applications, params) req.send_request() end |
#list_export_image_tasks(params = {}) ⇒ Types::ListExportImageTasksResult
Lists export image tasks, with optional filtering and pagination. Use this operation to monitor the status of multiple export operations.
4982 4983 4984 4985 |
# File 'lib/aws-sdk-appstream/client.rb', line 4982 def list_export_image_tasks(params = {}, = {}) req = build_request(:list_export_image_tasks, params) req.send_request() end |
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Retrieves a list of all tags for the specified WorkSpaces Applications resource. You can tag WorkSpaces Applications image builders, images, fleets, and stacks.
For more information about tags, see [Tagging Your Resources] in the *Amazon WorkSpaces Applications Administration Guide*.
[1]: docs.aws.amazon.com/appstream2/latest/developerguide/tagging-basic.html
5020 5021 5022 5023 |
# File 'lib/aws-sdk-appstream/client.rb', line 5020 def (params = {}, = {}) req = build_request(:list_tags_for_resource, params) req.send_request() end |
#start_app_block_builder(params = {}) ⇒ Types::StartAppBlockBuilderResult
Starts an app block builder.
An app block builder can only be started when it’s associated with an app block.
Starting an app block builder starts a new instance, which is equivalent to an elastic fleet instance with application builder assistance functionality.
5078 5079 5080 5081 |
# File 'lib/aws-sdk-appstream/client.rb', line 5078 def start_app_block_builder(params = {}, = {}) req = build_request(:start_app_block_builder, params) req.send_request() end |
#start_fleet(params = {}) ⇒ Struct
Starts the specified fleet.
5100 5101 5102 5103 |
# File 'lib/aws-sdk-appstream/client.rb', line 5100 def start_fleet(params = {}, = {}) req = build_request(:start_fleet, params) req.send_request() end |
#start_image_builder(params = {}) ⇒ Types::StartImageBuilderResult
Starts the specified image builder.
5167 5168 5169 5170 |
# File 'lib/aws-sdk-appstream/client.rb', line 5167 def start_image_builder(params = {}, = {}) req = build_request(:start_image_builder, params) req.send_request() end |
#start_software_deployment_to_image_builder(params = {}) ⇒ Struct
Initiates license included applications deployment to an image builder instance.
5195 5196 5197 5198 |
# File 'lib/aws-sdk-appstream/client.rb', line 5195 def start_software_deployment_to_image_builder(params = {}, = {}) req = build_request(:start_software_deployment_to_image_builder, params) req.send_request() end |
#stop_app_block_builder(params = {}) ⇒ Types::StopAppBlockBuilderResult
Stops an app block builder.
Stopping an app block builder terminates the instance, and the instance state is not persisted.
5249 5250 5251 5252 |
# File 'lib/aws-sdk-appstream/client.rb', line 5249 def stop_app_block_builder(params = {}, = {}) req = build_request(:stop_app_block_builder, params) req.send_request() end |
#stop_fleet(params = {}) ⇒ Struct
Stops the specified fleet.
5271 5272 5273 5274 |
# File 'lib/aws-sdk-appstream/client.rb', line 5271 def stop_fleet(params = {}, = {}) req = build_request(:stop_fleet, params) req.send_request() end |
#stop_image_builder(params = {}) ⇒ Types::StopImageBuilderResult
Stops the specified image builder.
5332 5333 5334 5335 |
# File 'lib/aws-sdk-appstream/client.rb', line 5332 def stop_image_builder(params = {}, = {}) req = build_request(:stop_image_builder, params) req.send_request() end |
#tag_resource(params = {}) ⇒ Struct
Adds or overwrites one or more tags for the specified WorkSpaces Applications resource. You can tag WorkSpaces Applications image builders, images, fleets, and stacks.
Each tag consists of a key and an optional value. If a resource already has a tag with the same key, this operation updates its value.
To list the current tags for your resources, use ListTagsForResource. To disassociate tags from your resources, use UntagResource.
For more information about tags, see [Tagging Your Resources] in the *Amazon WorkSpaces Applications Administration Guide*.
[1]: docs.aws.amazon.com/appstream2/latest/developerguide/tagging-basic.html
5384 5385 5386 5387 |
# File 'lib/aws-sdk-appstream/client.rb', line 5384 def tag_resource(params = {}, = {}) req = build_request(:tag_resource, params) req.send_request() end |
#untag_resource(params = {}) ⇒ Struct
Disassociates one or more specified tags from the specified WorkSpaces Applications resource.
To list the current tags for your resources, use ListTagsForResource.
For more information about tags, see [Tagging Your Resources] in the *Amazon WorkSpaces Applications Administration Guide*.
[1]: docs.aws.amazon.com/appstream2/latest/developerguide/tagging-basic.html
5420 5421 5422 5423 |
# File 'lib/aws-sdk-appstream/client.rb', line 5420 def untag_resource(params = {}, = {}) req = build_request(:untag_resource, params) req.send_request() end |
#update_app_block_builder(params = {}) ⇒ Types::UpdateAppBlockBuilderResult
Updates an app block builder.
If the app block builder is in the ‘STARTING` or `STOPPING` state, you can’t update it. If the app block builder is in the ‘RUNNING` state, you can only update the DisplayName and Description. If the app block builder is in the `STOPPED` state, you can update any attribute except the Name.
5559 5560 5561 5562 |
# File 'lib/aws-sdk-appstream/client.rb', line 5559 def update_app_block_builder(params = {}, = {}) req = build_request(:update_app_block_builder, params) req.send_request() end |
#update_application(params = {}) ⇒ Types::UpdateApplicationResult
Updates the specified application.
5642 5643 5644 5645 |
# File 'lib/aws-sdk-appstream/client.rb', line 5642 def update_application(params = {}, = {}) req = build_request(:update_application, params) req.send_request() end |
#update_directory_config(params = {}) ⇒ Types::UpdateDirectoryConfigResult
Updates the specified Directory Config object in WorkSpaces Applications. This object includes the configuration information required to join fleets and image builders to Microsoft Active Directory domains.
5709 5710 5711 5712 |
# File 'lib/aws-sdk-appstream/client.rb', line 5709 def update_directory_config(params = {}, = {}) req = build_request(:update_directory_config, params) req.send_request() end |
#update_entitlement(params = {}) ⇒ Types::UpdateEntitlementResult
Updates the specified entitlement.
5766 5767 5768 5769 |
# File 'lib/aws-sdk-appstream/client.rb', line 5766 def update_entitlement(params = {}, = {}) req = build_request(:update_entitlement, params) req.send_request() end |
#update_fleet(params = {}) ⇒ Types::UpdateFleetResult
Updates the specified fleet.
If the fleet is in the ‘STOPPED` state, you can update any attribute except the fleet name.
If the fleet is in the ‘RUNNING` state, you can update the following based on the fleet type:
-
Always-On and On-Demand fleet types
You can update the ‘DisplayName`, `ComputeCapacity`, `ImageARN`, `ImageName`, `IdleDisconnectTimeoutInSeconds`, and `DisconnectTimeoutInSeconds` attributes.
-
Elastic fleet type
You can update the ‘DisplayName`, `IdleDisconnectTimeoutInSeconds`, `DisconnectTimeoutInSeconds`, `MaxConcurrentSessions`, `SessionScriptS3Location` and `UsbDeviceFilterStrings` attributes.
If the fleet is in the ‘STARTING` or `STOPPED` state, you can’t update it.
6149 6150 6151 6152 |
# File 'lib/aws-sdk-appstream/client.rb', line 6149 def update_fleet(params = {}, = {}) req = build_request(:update_fleet, params) req.send_request() end |
#update_image_permissions(params = {}) ⇒ Struct
Adds or updates permissions for the specified private image.
6183 6184 6185 6186 |
# File 'lib/aws-sdk-appstream/client.rb', line 6183 def (params = {}, = {}) req = build_request(:update_image_permissions, params) req.send_request() end |
#update_stack(params = {}) ⇒ Types::UpdateStackResult
Updates the specified fields for the specified stack.
6364 6365 6366 6367 |
# File 'lib/aws-sdk-appstream/client.rb', line 6364 def update_stack(params = {}, = {}) req = build_request(:update_stack, params) req.send_request() end |
#update_theme_for_stack(params = {}) ⇒ Types::UpdateThemeForStackResult
Updates custom branding that customizes the appearance of the streaming application catalog page.
6451 6452 6453 6454 |
# File 'lib/aws-sdk-appstream/client.rb', line 6451 def update_theme_for_stack(params = {}, = {}) req = build_request(:update_theme_for_stack, params) req.send_request() end |
#wait_until(waiter_name, params = {}, options = {}) {|w.waiter| ... } ⇒ Boolean
Polls an API operation until a resource enters a desired state.
## Basic Usage
A waiter will call an API operation until:
-
It is successful
-
It enters a terminal state
-
It makes the maximum number of attempts
In between attempts, the waiter will sleep.
# polls in a loop, sleeping between attempts
client.wait_until(waiter_name, params)
## Configuration
You can configure the maximum number of polling attempts, and the delay (in seconds) between each polling attempt. You can pass configuration as the final arguments hash.
# poll for ~25 seconds
client.wait_until(waiter_name, params, {
max_attempts: 5,
delay: 5,
})
## Callbacks
You can be notified before each polling attempt and before each delay. If you throw ‘:success` or `:failure` from these callbacks, it will terminate the waiter.
started_at = Time.now
client.wait_until(waiter_name, params, {
# disable max attempts
max_attempts: nil,
# poll for 1 hour, instead of a number of attempts
before_wait: -> (attempts, response) do
throw :failure if Time.now - started_at > 3600
end
})
## Handling Errors
When a waiter is unsuccessful, it will raise an error. All of the failure errors extend from Waiters::Errors::WaiterFailed.
begin
client.wait_until(...)
rescue Aws::Waiters::Errors::WaiterFailed
# resource did not enter the desired state in time
end
## Valid Waiters
The following table lists the valid waiter names, the operations they call, and the default ‘:delay` and `:max_attempts` values.
| waiter_name | params | :delay | :max_attempts | | ————- | ———————— | ——– | ————- | | fleet_started | #describe_fleets | 30 | 40 | | fleet_stopped | #describe_fleets | 30 | 40 |
6567 6568 6569 6570 6571 |
# File 'lib/aws-sdk-appstream/client.rb', line 6567 def wait_until(waiter_name, params = {}, = {}) w = waiter(waiter_name, ) yield(w.waiter) if block_given? # deprecated w.wait(params) end |
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
6575 6576 6577 |
# File 'lib/aws-sdk-appstream/client.rb', line 6575 def waiter_names waiters.keys end |