Class: Aws::AppStream::Types::AppBlockBuilder
- Inherits:
-
Struct
- Object
- Struct
- Aws::AppStream::Types::AppBlockBuilder
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-appstream/types.rb
Overview
Describes an app block builder.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#access_endpoints ⇒ Array<Types::AccessEndpoint>
The list of interface VPC endpoint (interface endpoint) objects.
-
#app_block_builder_errors ⇒ Array<Types::ResourceError>
The app block builder errors.
-
#arn ⇒ String
The ARN of the app block builder.
-
#created_time ⇒ Time
The creation time of the app block builder.
-
#description ⇒ String
The description of the app block builder.
-
#disable_imdsv1 ⇒ Boolean
Indicates whether Instance Metadata Service Version 1 (IMDSv1) is disabled for the app block builder.
-
#display_name ⇒ String
The display name of the app block builder.
-
#enable_default_internet_access ⇒ Boolean
Indicates whether default internet access is enabled for the app block builder.
-
#iam_role_arn ⇒ String
The ARN of the IAM role that is applied to the app block builder.
-
#instance_type ⇒ String
The instance type of the app block builder.
-
#name ⇒ String
The name of the app block builder.
-
#platform ⇒ String
The platform of the app block builder.
-
#state ⇒ String
The state of the app block builder.
-
#state_change_reason ⇒ Types::AppBlockBuilderStateChangeReason
The state change reason.
-
#vpc_config ⇒ Types::VpcConfig
The VPC configuration for the app block builder.
Instance Attribute Details
#access_endpoints ⇒ Array<Types::AccessEndpoint>
The list of interface VPC endpoint (interface endpoint) objects. Administrators can connect to the app block builder only through the specified endpoints.
339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 |
# File 'lib/aws-sdk-appstream/types.rb', line 339 class AppBlockBuilder < Struct.new( :arn, :name, :display_name, :description, :platform, :instance_type, :enable_default_internet_access, :iam_role_arn, :vpc_config, :state, :created_time, :app_block_builder_errors, :state_change_reason, :access_endpoints, :disable_imdsv1) SENSITIVE = [] include Aws::Structure end |
#app_block_builder_errors ⇒ Array<Types::ResourceError>
The app block builder errors.
339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 |
# File 'lib/aws-sdk-appstream/types.rb', line 339 class AppBlockBuilder < Struct.new( :arn, :name, :display_name, :description, :platform, :instance_type, :enable_default_internet_access, :iam_role_arn, :vpc_config, :state, :created_time, :app_block_builder_errors, :state_change_reason, :access_endpoints, :disable_imdsv1) SENSITIVE = [] include Aws::Structure end |
#arn ⇒ String
The ARN of the app block builder.
339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 |
# File 'lib/aws-sdk-appstream/types.rb', line 339 class AppBlockBuilder < Struct.new( :arn, :name, :display_name, :description, :platform, :instance_type, :enable_default_internet_access, :iam_role_arn, :vpc_config, :state, :created_time, :app_block_builder_errors, :state_change_reason, :access_endpoints, :disable_imdsv1) SENSITIVE = [] include Aws::Structure end |
#created_time ⇒ Time
The creation time of the app block builder.
339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 |
# File 'lib/aws-sdk-appstream/types.rb', line 339 class AppBlockBuilder < Struct.new( :arn, :name, :display_name, :description, :platform, :instance_type, :enable_default_internet_access, :iam_role_arn, :vpc_config, :state, :created_time, :app_block_builder_errors, :state_change_reason, :access_endpoints, :disable_imdsv1) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
The description of the app block builder.
339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 |
# File 'lib/aws-sdk-appstream/types.rb', line 339 class AppBlockBuilder < Struct.new( :arn, :name, :display_name, :description, :platform, :instance_type, :enable_default_internet_access, :iam_role_arn, :vpc_config, :state, :created_time, :app_block_builder_errors, :state_change_reason, :access_endpoints, :disable_imdsv1) SENSITIVE = [] include Aws::Structure end |
#disable_imdsv1 ⇒ Boolean
Indicates whether Instance Metadata Service Version 1 (IMDSv1) is disabled for the app block builder.
339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 |
# File 'lib/aws-sdk-appstream/types.rb', line 339 class AppBlockBuilder < Struct.new( :arn, :name, :display_name, :description, :platform, :instance_type, :enable_default_internet_access, :iam_role_arn, :vpc_config, :state, :created_time, :app_block_builder_errors, :state_change_reason, :access_endpoints, :disable_imdsv1) SENSITIVE = [] include Aws::Structure end |
#display_name ⇒ String
The display name of the app block builder.
339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 |
# File 'lib/aws-sdk-appstream/types.rb', line 339 class AppBlockBuilder < Struct.new( :arn, :name, :display_name, :description, :platform, :instance_type, :enable_default_internet_access, :iam_role_arn, :vpc_config, :state, :created_time, :app_block_builder_errors, :state_change_reason, :access_endpoints, :disable_imdsv1) SENSITIVE = [] include Aws::Structure end |
#enable_default_internet_access ⇒ Boolean
Indicates whether default internet access is enabled for the app block builder.
339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 |
# File 'lib/aws-sdk-appstream/types.rb', line 339 class AppBlockBuilder < Struct.new( :arn, :name, :display_name, :description, :platform, :instance_type, :enable_default_internet_access, :iam_role_arn, :vpc_config, :state, :created_time, :app_block_builder_errors, :state_change_reason, :access_endpoints, :disable_imdsv1) SENSITIVE = [] include Aws::Structure end |
#iam_role_arn ⇒ String
The ARN of the IAM role that is applied to the app block builder.
339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 |
# File 'lib/aws-sdk-appstream/types.rb', line 339 class AppBlockBuilder < Struct.new( :arn, :name, :display_name, :description, :platform, :instance_type, :enable_default_internet_access, :iam_role_arn, :vpc_config, :state, :created_time, :app_block_builder_errors, :state_change_reason, :access_endpoints, :disable_imdsv1) SENSITIVE = [] include Aws::Structure end |
#instance_type ⇒ String
The instance type of the app block builder.
339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 |
# File 'lib/aws-sdk-appstream/types.rb', line 339 class AppBlockBuilder < Struct.new( :arn, :name, :display_name, :description, :platform, :instance_type, :enable_default_internet_access, :iam_role_arn, :vpc_config, :state, :created_time, :app_block_builder_errors, :state_change_reason, :access_endpoints, :disable_imdsv1) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the app block builder.
339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 |
# File 'lib/aws-sdk-appstream/types.rb', line 339 class AppBlockBuilder < Struct.new( :arn, :name, :display_name, :description, :platform, :instance_type, :enable_default_internet_access, :iam_role_arn, :vpc_config, :state, :created_time, :app_block_builder_errors, :state_change_reason, :access_endpoints, :disable_imdsv1) SENSITIVE = [] include Aws::Structure end |
#platform ⇒ String
The platform of the app block builder.
‘WINDOWS_SERVER_2019` is the only valid value.
339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 |
# File 'lib/aws-sdk-appstream/types.rb', line 339 class AppBlockBuilder < Struct.new( :arn, :name, :display_name, :description, :platform, :instance_type, :enable_default_internet_access, :iam_role_arn, :vpc_config, :state, :created_time, :app_block_builder_errors, :state_change_reason, :access_endpoints, :disable_imdsv1) SENSITIVE = [] include Aws::Structure end |
#state ⇒ String
The state of the app block builder.
339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 |
# File 'lib/aws-sdk-appstream/types.rb', line 339 class AppBlockBuilder < Struct.new( :arn, :name, :display_name, :description, :platform, :instance_type, :enable_default_internet_access, :iam_role_arn, :vpc_config, :state, :created_time, :app_block_builder_errors, :state_change_reason, :access_endpoints, :disable_imdsv1) SENSITIVE = [] include Aws::Structure end |
#state_change_reason ⇒ Types::AppBlockBuilderStateChangeReason
The state change reason.
339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 |
# File 'lib/aws-sdk-appstream/types.rb', line 339 class AppBlockBuilder < Struct.new( :arn, :name, :display_name, :description, :platform, :instance_type, :enable_default_internet_access, :iam_role_arn, :vpc_config, :state, :created_time, :app_block_builder_errors, :state_change_reason, :access_endpoints, :disable_imdsv1) SENSITIVE = [] include Aws::Structure end |
#vpc_config ⇒ Types::VpcConfig
The VPC configuration for the app block builder.
339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 |
# File 'lib/aws-sdk-appstream/types.rb', line 339 class AppBlockBuilder < Struct.new( :arn, :name, :display_name, :description, :platform, :instance_type, :enable_default_internet_access, :iam_role_arn, :vpc_config, :state, :created_time, :app_block_builder_errors, :state_change_reason, :access_endpoints, :disable_imdsv1) SENSITIVE = [] include Aws::Structure end |