Class: Aws::AppStream::Types::ApplicationSettingsResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::AppStream::Types::ApplicationSettingsResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-appstream/types.rb
Overview
Describes the persistent application settings for users of a stack.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#enabled ⇒ Boolean
Specifies whether persistent application settings are enabled for users during their streaming sessions.
-
#s3_bucket_name ⇒ String
The S3 bucket where users’ persistent application settings are stored.
-
#settings_group ⇒ String
The path prefix for the S3 bucket where users’ persistent application settings are stored.
Instance Attribute Details
#enabled ⇒ Boolean
Specifies whether persistent application settings are enabled for users during their streaming sessions.
624 625 626 627 628 629 630 |
# File 'lib/aws-sdk-appstream/types.rb', line 624 class ApplicationSettingsResponse < Struct.new( :enabled, :settings_group, :s3_bucket_name) SENSITIVE = [] include Aws::Structure end |
#s3_bucket_name ⇒ String
The S3 bucket where users’ persistent application settings are stored. When persistent application settings are enabled for the first time for an account in an AWS Region, an S3 bucket is created. The bucket is unique to the AWS account and the Region.
624 625 626 627 628 629 630 |
# File 'lib/aws-sdk-appstream/types.rb', line 624 class ApplicationSettingsResponse < Struct.new( :enabled, :settings_group, :s3_bucket_name) SENSITIVE = [] include Aws::Structure end |
#settings_group ⇒ String
The path prefix for the S3 bucket where users’ persistent application settings are stored.
624 625 626 627 628 629 630 |
# File 'lib/aws-sdk-appstream/types.rb', line 624 class ApplicationSettingsResponse < Struct.new( :enabled, :settings_group, :s3_bucket_name) SENSITIVE = [] include Aws::Structure end |