Class: Aws::AppStream::Types::ComputeCapacity

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-appstream/types.rb

Overview

Describes the capacity for a fleet.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#desired_instancesInteger

The desired number of streaming instances.



904
905
906
907
908
909
# File 'lib/aws-sdk-appstream/types.rb', line 904

class ComputeCapacity < Struct.new(
  :desired_instances,
  :desired_sessions)
  SENSITIVE = []
  include Aws::Structure
end

#desired_sessionsInteger

The desired number of user sessions for a multi-session fleet. This is not allowed for single-session fleets.

When you create a fleet, you must set either the DesiredSessions or DesiredInstances attribute, based on the type of fleet you create. You can’t define both attributes or leave both attributes blank.



904
905
906
907
908
909
# File 'lib/aws-sdk-appstream/types.rb', line 904

class ComputeCapacity < Struct.new(
  :desired_instances,
  :desired_sessions)
  SENSITIVE = []
  include Aws::Structure
end