Class: Aws::AppStream::Types::CreateAppBlockBuilderRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::AppStream::Types::CreateAppBlockBuilderRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-appstream/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#access_endpoints ⇒ Array<Types::AccessEndpoint>
The list of interface VPC endpoint (interface endpoint) objects.
-
#description ⇒ String
The description of the app block builder.
-
#disable_imdsv1 ⇒ Boolean
Set to true to disable Instance Metadata Service Version 1 (IMDSv1) and enforce IMDSv2.
-
#display_name ⇒ String
The display name of the app block builder.
-
#enable_default_internet_access ⇒ Boolean
Enables or disables default internet access for the app block builder.
-
#iam_role_arn ⇒ String
The Amazon Resource Name (ARN) of the IAM role to apply to the app block builder.
-
#instance_type ⇒ String
The instance type to use when launching the app block builder.
-
#name ⇒ String
The unique name for the app block builder.
-
#platform ⇒ String
The platform of the app block builder.
-
#tags ⇒ Hash<String,String>
The tags to associate with the app block builder.
-
#vpc_config ⇒ Types::VpcConfig
The VPC configuration for the app block builder.
Instance Attribute Details
#access_endpoints ⇒ Array<Types::AccessEndpoint>
The list of interface VPC endpoint (interface endpoint) objects. Administrators can connect to the app block builder only through the specified endpoints.
1023 1024 1025 1026 1027 1028 1029 1030 1031 1032 1033 1034 1035 1036 1037 |
# File 'lib/aws-sdk-appstream/types.rb', line 1023 class CreateAppBlockBuilderRequest < Struct.new( :name, :description, :display_name, :tags, :platform, :instance_type, :vpc_config, :enable_default_internet_access, :iam_role_arn, :access_endpoints, :disable_imdsv1) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
The description of the app block builder.
1023 1024 1025 1026 1027 1028 1029 1030 1031 1032 1033 1034 1035 1036 1037 |
# File 'lib/aws-sdk-appstream/types.rb', line 1023 class CreateAppBlockBuilderRequest < Struct.new( :name, :description, :display_name, :tags, :platform, :instance_type, :vpc_config, :enable_default_internet_access, :iam_role_arn, :access_endpoints, :disable_imdsv1) SENSITIVE = [] include Aws::Structure end |
#disable_imdsv1 ⇒ Boolean
Set to true to disable Instance Metadata Service Version 1 (IMDSv1) and enforce IMDSv2. Set to false to enable both IMDSv1 and IMDSv2.
1023 1024 1025 1026 1027 1028 1029 1030 1031 1032 1033 1034 1035 1036 1037 |
# File 'lib/aws-sdk-appstream/types.rb', line 1023 class CreateAppBlockBuilderRequest < Struct.new( :name, :description, :display_name, :tags, :platform, :instance_type, :vpc_config, :enable_default_internet_access, :iam_role_arn, :access_endpoints, :disable_imdsv1) SENSITIVE = [] include Aws::Structure end |
#display_name ⇒ String
The display name of the app block builder.
1023 1024 1025 1026 1027 1028 1029 1030 1031 1032 1033 1034 1035 1036 1037 |
# File 'lib/aws-sdk-appstream/types.rb', line 1023 class CreateAppBlockBuilderRequest < Struct.new( :name, :description, :display_name, :tags, :platform, :instance_type, :vpc_config, :enable_default_internet_access, :iam_role_arn, :access_endpoints, :disable_imdsv1) SENSITIVE = [] include Aws::Structure end |
#enable_default_internet_access ⇒ Boolean
Enables or disables default internet access for the app block builder.
1023 1024 1025 1026 1027 1028 1029 1030 1031 1032 1033 1034 1035 1036 1037 |
# File 'lib/aws-sdk-appstream/types.rb', line 1023 class CreateAppBlockBuilderRequest < Struct.new( :name, :description, :display_name, :tags, :platform, :instance_type, :vpc_config, :enable_default_internet_access, :iam_role_arn, :access_endpoints, :disable_imdsv1) SENSITIVE = [] include Aws::Structure end |
#iam_role_arn ⇒ String
The Amazon Resource Name (ARN) of the IAM role to apply to the app block builder. To assume a role, the app block builder calls the AWS Security Token Service (STS) AssumeRole API operation and passes the ARN of the role to use. The operation creates a new session with temporary credentials. WorkSpaces Applications retrieves the temporary credentials and creates the appstream_machine_role credential profile on the instance.
For more information, see [Using an IAM Role to Grant Permissions to Applications and Scripts Running on WorkSpaces Applications Streaming Instances] in the *Amazon WorkSpaces Applications Administration Guide*.
1023 1024 1025 1026 1027 1028 1029 1030 1031 1032 1033 1034 1035 1036 1037 |
# File 'lib/aws-sdk-appstream/types.rb', line 1023 class CreateAppBlockBuilderRequest < Struct.new( :name, :description, :display_name, :tags, :platform, :instance_type, :vpc_config, :enable_default_internet_access, :iam_role_arn, :access_endpoints, :disable_imdsv1) SENSITIVE = [] include Aws::Structure end |
#instance_type ⇒ String
The instance type to use when launching the app block builder. The following instance types are available:
-
stream.standard.small
-
stream.standard.medium
-
stream.standard.large
-
stream.standard.xlarge
-
stream.standard.2xlarge
1023 1024 1025 1026 1027 1028 1029 1030 1031 1032 1033 1034 1035 1036 1037 |
# File 'lib/aws-sdk-appstream/types.rb', line 1023 class CreateAppBlockBuilderRequest < Struct.new( :name, :description, :display_name, :tags, :platform, :instance_type, :vpc_config, :enable_default_internet_access, :iam_role_arn, :access_endpoints, :disable_imdsv1) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The unique name for the app block builder.
1023 1024 1025 1026 1027 1028 1029 1030 1031 1032 1033 1034 1035 1036 1037 |
# File 'lib/aws-sdk-appstream/types.rb', line 1023 class CreateAppBlockBuilderRequest < Struct.new( :name, :description, :display_name, :tags, :platform, :instance_type, :vpc_config, :enable_default_internet_access, :iam_role_arn, :access_endpoints, :disable_imdsv1) SENSITIVE = [] include Aws::Structure end |
#platform ⇒ String
The platform of the app block builder.
WINDOWS_SERVER_2019 is the only valid value.
1023 1024 1025 1026 1027 1028 1029 1030 1031 1032 1033 1034 1035 1036 1037 |
# File 'lib/aws-sdk-appstream/types.rb', line 1023 class CreateAppBlockBuilderRequest < Struct.new( :name, :description, :display_name, :tags, :platform, :instance_type, :vpc_config, :enable_default_internet_access, :iam_role_arn, :access_endpoints, :disable_imdsv1) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Hash<String,String>
The tags to associate with the app block builder. A tag is a key-value pair, and the value is optional. For example, Environment=Test. If you do not specify a value, Environment=.
If you do not specify a value, the value is set to an empty string.
Generally allowed characters are: letters, numbers, and spaces representable in UTF-8, and the following special characters:
_ . : / = + \ - @
For more information, see [Tagging Your Resources] in the *Amazon WorkSpaces Applications Administration Guide*.
[1]: docs.aws.amazon.com/appstream2/latest/developerguide/tagging-basic.html
1023 1024 1025 1026 1027 1028 1029 1030 1031 1032 1033 1034 1035 1036 1037 |
# File 'lib/aws-sdk-appstream/types.rb', line 1023 class CreateAppBlockBuilderRequest < Struct.new( :name, :description, :display_name, :tags, :platform, :instance_type, :vpc_config, :enable_default_internet_access, :iam_role_arn, :access_endpoints, :disable_imdsv1) SENSITIVE = [] include Aws::Structure end |
#vpc_config ⇒ Types::VpcConfig
The VPC configuration for the app block builder.
App block builders require that you specify at least two subnets in different availability zones.
1023 1024 1025 1026 1027 1028 1029 1030 1031 1032 1033 1034 1035 1036 1037 |
# File 'lib/aws-sdk-appstream/types.rb', line 1023 class CreateAppBlockBuilderRequest < Struct.new( :name, :description, :display_name, :tags, :platform, :instance_type, :vpc_config, :enable_default_internet_access, :iam_role_arn, :access_endpoints, :disable_imdsv1) SENSITIVE = [] include Aws::Structure end |