Class: Aws::AppStream::Types::CreateApplicationRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::AppStream::Types::CreateApplicationRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-appstream/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#app_block_arn ⇒ String
The app block ARN to which the application should be associated.
-
#description ⇒ String
The description of the application.
-
#display_name ⇒ String
The display name of the application.
-
#icon_s3_location ⇒ Types::S3Location
The location in S3 of the application icon.
-
#instance_families ⇒ Array<String>
The instance families the application supports.
-
#launch_parameters ⇒ String
The launch parameters of the application.
-
#launch_path ⇒ String
The launch path of the application.
-
#name ⇒ String
The name of the application.
-
#platforms ⇒ Array<String>
The platforms the application supports.
-
#tags ⇒ Hash<String,String>
The tags assigned to the application.
-
#working_directory ⇒ String
The working directory of the application.
Instance Attribute Details
#app_block_arn ⇒ String
The app block ARN to which the application should be associated
1337 1338 1339 1340 1341 1342 1343 1344 1345 1346 1347 1348 1349 1350 1351 |
# File 'lib/aws-sdk-appstream/types.rb', line 1337 class CreateApplicationRequest < Struct.new( :name, :display_name, :description, :icon_s3_location, :launch_path, :working_directory, :launch_parameters, :platforms, :instance_families, :app_block_arn, :tags) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
The description of the application.
1337 1338 1339 1340 1341 1342 1343 1344 1345 1346 1347 1348 1349 1350 1351 |
# File 'lib/aws-sdk-appstream/types.rb', line 1337 class CreateApplicationRequest < Struct.new( :name, :display_name, :description, :icon_s3_location, :launch_path, :working_directory, :launch_parameters, :platforms, :instance_families, :app_block_arn, :tags) SENSITIVE = [] include Aws::Structure end |
#display_name ⇒ String
The display name of the application. This name is visible to users in the application catalog.
1337 1338 1339 1340 1341 1342 1343 1344 1345 1346 1347 1348 1349 1350 1351 |
# File 'lib/aws-sdk-appstream/types.rb', line 1337 class CreateApplicationRequest < Struct.new( :name, :display_name, :description, :icon_s3_location, :launch_path, :working_directory, :launch_parameters, :platforms, :instance_families, :app_block_arn, :tags) SENSITIVE = [] include Aws::Structure end |
#icon_s3_location ⇒ Types::S3Location
The location in S3 of the application icon.
1337 1338 1339 1340 1341 1342 1343 1344 1345 1346 1347 1348 1349 1350 1351 |
# File 'lib/aws-sdk-appstream/types.rb', line 1337 class CreateApplicationRequest < Struct.new( :name, :display_name, :description, :icon_s3_location, :launch_path, :working_directory, :launch_parameters, :platforms, :instance_families, :app_block_arn, :tags) SENSITIVE = [] include Aws::Structure end |
#instance_families ⇒ Array<String>
The instance families the application supports. Valid values are GENERAL_PURPOSE and GRAPHICS_G4.
1337 1338 1339 1340 1341 1342 1343 1344 1345 1346 1347 1348 1349 1350 1351 |
# File 'lib/aws-sdk-appstream/types.rb', line 1337 class CreateApplicationRequest < Struct.new( :name, :display_name, :description, :icon_s3_location, :launch_path, :working_directory, :launch_parameters, :platforms, :instance_families, :app_block_arn, :tags) SENSITIVE = [] include Aws::Structure end |
#launch_parameters ⇒ String
The launch parameters of the application.
1337 1338 1339 1340 1341 1342 1343 1344 1345 1346 1347 1348 1349 1350 1351 |
# File 'lib/aws-sdk-appstream/types.rb', line 1337 class CreateApplicationRequest < Struct.new( :name, :display_name, :description, :icon_s3_location, :launch_path, :working_directory, :launch_parameters, :platforms, :instance_families, :app_block_arn, :tags) SENSITIVE = [] include Aws::Structure end |
#launch_path ⇒ String
The launch path of the application.
1337 1338 1339 1340 1341 1342 1343 1344 1345 1346 1347 1348 1349 1350 1351 |
# File 'lib/aws-sdk-appstream/types.rb', line 1337 class CreateApplicationRequest < Struct.new( :name, :display_name, :description, :icon_s3_location, :launch_path, :working_directory, :launch_parameters, :platforms, :instance_families, :app_block_arn, :tags) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the application. This name is visible to users when display name is not specified.
1337 1338 1339 1340 1341 1342 1343 1344 1345 1346 1347 1348 1349 1350 1351 |
# File 'lib/aws-sdk-appstream/types.rb', line 1337 class CreateApplicationRequest < Struct.new( :name, :display_name, :description, :icon_s3_location, :launch_path, :working_directory, :launch_parameters, :platforms, :instance_families, :app_block_arn, :tags) SENSITIVE = [] include Aws::Structure end |
#platforms ⇒ Array<String>
The platforms the application supports. WINDOWS_SERVER_2019, AMAZON_LINUX2 and UBUNTU_PRO_2404 are supported for Elastic fleets.
1337 1338 1339 1340 1341 1342 1343 1344 1345 1346 1347 1348 1349 1350 1351 |
# File 'lib/aws-sdk-appstream/types.rb', line 1337 class CreateApplicationRequest < Struct.new( :name, :display_name, :description, :icon_s3_location, :launch_path, :working_directory, :launch_parameters, :platforms, :instance_families, :app_block_arn, :tags) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Hash<String,String>
The tags assigned to the application.
1337 1338 1339 1340 1341 1342 1343 1344 1345 1346 1347 1348 1349 1350 1351 |
# File 'lib/aws-sdk-appstream/types.rb', line 1337 class CreateApplicationRequest < Struct.new( :name, :display_name, :description, :icon_s3_location, :launch_path, :working_directory, :launch_parameters, :platforms, :instance_families, :app_block_arn, :tags) SENSITIVE = [] include Aws::Structure end |
#working_directory ⇒ String
The working directory of the application.
1337 1338 1339 1340 1341 1342 1343 1344 1345 1346 1347 1348 1349 1350 1351 |
# File 'lib/aws-sdk-appstream/types.rb', line 1337 class CreateApplicationRequest < Struct.new( :name, :display_name, :description, :icon_s3_location, :launch_path, :working_directory, :launch_parameters, :platforms, :instance_families, :app_block_arn, :tags) SENSITIVE = [] include Aws::Structure end |