Class: Aws::AppStream::Types::CreateExportImageTaskRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::AppStream::Types::CreateExportImageTaskRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-appstream/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#ami_description ⇒ String
An optional description for the exported AMI.
-
#ami_name ⇒ String
The name for the exported EC2 AMI.
-
#iam_role_arn ⇒ String
The ARN of the IAM role that allows WorkSpaces Applications to create the AMI.
-
#image_name ⇒ String
The name of the WorkSpaces Applications image to export.
-
#tag_specifications ⇒ Hash<String,String>
The tags to apply to the exported AMI.
Instance Attribute Details
#ami_description ⇒ String
An optional description for the exported AMI. This description will be applied to the resulting EC2 AMI.
1369 1370 1371 1372 1373 1374 1375 1376 1377 |
# File 'lib/aws-sdk-appstream/types.rb', line 1369 class CreateExportImageTaskRequest < Struct.new( :image_name, :ami_name, :iam_role_arn, :tag_specifications, :ami_description) SENSITIVE = [] include Aws::Structure end |
#ami_name ⇒ String
The name for the exported EC2 AMI. This is a required field that must be unique within your account and region.
1369 1370 1371 1372 1373 1374 1375 1376 1377 |
# File 'lib/aws-sdk-appstream/types.rb', line 1369 class CreateExportImageTaskRequest < Struct.new( :image_name, :ami_name, :iam_role_arn, :tag_specifications, :ami_description) SENSITIVE = [] include Aws::Structure end |
#iam_role_arn ⇒ String
The ARN of the IAM role that allows WorkSpaces Applications to create the AMI. The role must have permissions to copy images, describe images, and create tags, with a trust relationship allowing appstream.amazonaws.com to assume the role.
1369 1370 1371 1372 1373 1374 1375 1376 1377 |
# File 'lib/aws-sdk-appstream/types.rb', line 1369 class CreateExportImageTaskRequest < Struct.new( :image_name, :ami_name, :iam_role_arn, :tag_specifications, :ami_description) SENSITIVE = [] include Aws::Structure end |
#image_name ⇒ String
The name of the WorkSpaces Applications image to export. The image must be in an available state and owned by your account.
1369 1370 1371 1372 1373 1374 1375 1376 1377 |
# File 'lib/aws-sdk-appstream/types.rb', line 1369 class CreateExportImageTaskRequest < Struct.new( :image_name, :ami_name, :iam_role_arn, :tag_specifications, :ami_description) SENSITIVE = [] include Aws::Structure end |
#tag_specifications ⇒ Hash<String,String>
The tags to apply to the exported AMI. These tags help you organize and manage your EC2 AMIs.
1369 1370 1371 1372 1373 1374 1375 1376 1377 |
# File 'lib/aws-sdk-appstream/types.rb', line 1369 class CreateExportImageTaskRequest < Struct.new( :image_name, :ami_name, :iam_role_arn, :tag_specifications, :ami_description) SENSITIVE = [] include Aws::Structure end |