Class: Aws::AppStream::Types::CreateImportedImageRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::AppStream::Types::CreateImportedImageRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-appstream/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[:app_catalog_config]
Instance Attribute Summary collapse
-
#agent_software_version ⇒ String
The version of the WorkSpaces Applications agent to use for the imported image.
-
#app_catalog_config ⇒ Array<Types::ApplicationConfig>
Configuration for the application catalog of the imported image.
-
#description ⇒ String
An optional description for the imported image.
-
#display_name ⇒ String
An optional display name for the imported image.
-
#dry_run ⇒ Boolean
When set to true, performs validation checks without actually creating the imported image.
-
#iam_role_arn ⇒ String
The ARN of the IAM role that allows WorkSpaces Applications to access your AMI.
-
#name ⇒ String
A unique name for the imported image.
-
#runtime_validation_config ⇒ Types::RuntimeValidationConfig
Configuration for runtime validation of the imported image.
-
#source_ami_id ⇒ String
The ID of the EC2 AMI to import.
-
#tags ⇒ Hash<String,String>
The tags to apply to the imported image.
Instance Attribute Details
#agent_software_version ⇒ String
The version of the WorkSpaces Applications agent to use for the imported image. Choose CURRENT_LATEST to use the agent version available at the time of import, or ALWAYS_LATEST to automatically update to the latest agent version when new versions are released.
2213 2214 2215 2216 2217 2218 2219 2220 2221 2222 2223 2224 2225 2226 |
# File 'lib/aws-sdk-appstream/types.rb', line 2213 class CreateImportedImageRequest < Struct.new( :name, :source_ami_id, :iam_role_arn, :description, :display_name, :tags, :runtime_validation_config, :agent_software_version, :app_catalog_config, :dry_run) SENSITIVE = [:app_catalog_config] include Aws::Structure end |
#app_catalog_config ⇒ Array<Types::ApplicationConfig>
Configuration for the application catalog of the imported image. This allows you to specify applications available for streaming, including their paths, icons, and launch parameters. This field contains sensitive data.
2213 2214 2215 2216 2217 2218 2219 2220 2221 2222 2223 2224 2225 2226 |
# File 'lib/aws-sdk-appstream/types.rb', line 2213 class CreateImportedImageRequest < Struct.new( :name, :source_ami_id, :iam_role_arn, :description, :display_name, :tags, :runtime_validation_config, :agent_software_version, :app_catalog_config, :dry_run) SENSITIVE = [:app_catalog_config] include Aws::Structure end |
#description ⇒ String
An optional description for the imported image. The description must match approved regex patterns and can be up to 256 characters.
2213 2214 2215 2216 2217 2218 2219 2220 2221 2222 2223 2224 2225 2226 |
# File 'lib/aws-sdk-appstream/types.rb', line 2213 class CreateImportedImageRequest < Struct.new( :name, :source_ami_id, :iam_role_arn, :description, :display_name, :tags, :runtime_validation_config, :agent_software_version, :app_catalog_config, :dry_run) SENSITIVE = [:app_catalog_config] include Aws::Structure end |
#display_name ⇒ String
An optional display name for the imported image. The display name must match approved regex patterns and can be up to 100 characters.
2213 2214 2215 2216 2217 2218 2219 2220 2221 2222 2223 2224 2225 2226 |
# File 'lib/aws-sdk-appstream/types.rb', line 2213 class CreateImportedImageRequest < Struct.new( :name, :source_ami_id, :iam_role_arn, :description, :display_name, :tags, :runtime_validation_config, :agent_software_version, :app_catalog_config, :dry_run) SENSITIVE = [:app_catalog_config] include Aws::Structure end |
#dry_run ⇒ Boolean
When set to true, performs validation checks without actually creating the imported image. Use this to verify your configuration before executing the actual import operation.
2213 2214 2215 2216 2217 2218 2219 2220 2221 2222 2223 2224 2225 2226 |
# File 'lib/aws-sdk-appstream/types.rb', line 2213 class CreateImportedImageRequest < Struct.new( :name, :source_ami_id, :iam_role_arn, :description, :display_name, :tags, :runtime_validation_config, :agent_software_version, :app_catalog_config, :dry_run) SENSITIVE = [:app_catalog_config] include Aws::Structure end |
#iam_role_arn ⇒ String
The ARN of the IAM role that allows WorkSpaces Applications to access your AMI. The role must have permissions to modify image attributes and describe images, with a trust relationship allowing appstream.amazonaws.com to assume the role.
2213 2214 2215 2216 2217 2218 2219 2220 2221 2222 2223 2224 2225 2226 |
# File 'lib/aws-sdk-appstream/types.rb', line 2213 class CreateImportedImageRequest < Struct.new( :name, :source_ami_id, :iam_role_arn, :description, :display_name, :tags, :runtime_validation_config, :agent_software_version, :app_catalog_config, :dry_run) SENSITIVE = [:app_catalog_config] include Aws::Structure end |
#name ⇒ String
A unique name for the imported image. The name must be between 1 and 100 characters and can contain letters, numbers, underscores, periods, and hyphens.
2213 2214 2215 2216 2217 2218 2219 2220 2221 2222 2223 2224 2225 2226 |
# File 'lib/aws-sdk-appstream/types.rb', line 2213 class CreateImportedImageRequest < Struct.new( :name, :source_ami_id, :iam_role_arn, :description, :display_name, :tags, :runtime_validation_config, :agent_software_version, :app_catalog_config, :dry_run) SENSITIVE = [:app_catalog_config] include Aws::Structure end |
#runtime_validation_config ⇒ Types::RuntimeValidationConfig
Configuration for runtime validation of the imported image. When specified, WorkSpaces Applications provisions an instance to test streaming functionality, which helps ensure the image is suitable for use.
2213 2214 2215 2216 2217 2218 2219 2220 2221 2222 2223 2224 2225 2226 |
# File 'lib/aws-sdk-appstream/types.rb', line 2213 class CreateImportedImageRequest < Struct.new( :name, :source_ami_id, :iam_role_arn, :description, :display_name, :tags, :runtime_validation_config, :agent_software_version, :app_catalog_config, :dry_run) SENSITIVE = [:app_catalog_config] include Aws::Structure end |
#source_ami_id ⇒ String
The ID of the EC2 AMI to import. The AMI must meet specific requirements including Windows Server 2022 Full Base, UEFI boot mode, TPM 2.0 support, and proper drivers.
2213 2214 2215 2216 2217 2218 2219 2220 2221 2222 2223 2224 2225 2226 |
# File 'lib/aws-sdk-appstream/types.rb', line 2213 class CreateImportedImageRequest < Struct.new( :name, :source_ami_id, :iam_role_arn, :description, :display_name, :tags, :runtime_validation_config, :agent_software_version, :app_catalog_config, :dry_run) SENSITIVE = [:app_catalog_config] include Aws::Structure end |
#tags ⇒ Hash<String,String>
The tags to apply to the imported image. Tags help you organize and manage your WorkSpaces Applications resources.
2213 2214 2215 2216 2217 2218 2219 2220 2221 2222 2223 2224 2225 2226 |
# File 'lib/aws-sdk-appstream/types.rb', line 2213 class CreateImportedImageRequest < Struct.new( :name, :source_ami_id, :iam_role_arn, :description, :display_name, :tags, :runtime_validation_config, :agent_software_version, :app_catalog_config, :dry_run) SENSITIVE = [:app_catalog_config] include Aws::Structure end |