Class: Aws::AppStream::Types::CreateStackRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-appstream/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#access_endpointsArray<Types::AccessEndpoint>

The list of interface VPC endpoint (interface endpoint) objects. Users of the stack can connect to WorkSpaces Applications only through the specified endpoints.

Returns:



2446
2447
2448
2449
2450
2451
2452
2453
2454
2455
2456
2457
2458
2459
2460
2461
2462
2463
# File 'lib/aws-sdk-appstream/types.rb', line 2446

class CreateStackRequest < Struct.new(
  :name,
  :description,
  :display_name,
  :storage_connectors,
  :redirect_url,
  :feedback_url,
  :user_settings,
  :application_settings,
  :tags,
  :access_endpoints,
  :embed_host_domains,
  :streaming_experience_settings,
  :content_redirection,
  :agent_access_config)
  SENSITIVE = []
  include Aws::Structure
end

#agent_access_configTypes::AgentAccessConfig

The configuration for agent access on the stack. If specified, agent access is enabled for the stack.

Returns:



2446
2447
2448
2449
2450
2451
2452
2453
2454
2455
2456
2457
2458
2459
2460
2461
2462
2463
# File 'lib/aws-sdk-appstream/types.rb', line 2446

class CreateStackRequest < Struct.new(
  :name,
  :description,
  :display_name,
  :storage_connectors,
  :redirect_url,
  :feedback_url,
  :user_settings,
  :application_settings,
  :tags,
  :access_endpoints,
  :embed_host_domains,
  :streaming_experience_settings,
  :content_redirection,
  :agent_access_config)
  SENSITIVE = []
  include Aws::Structure
end

#application_settingsTypes::ApplicationSettings

The persistent application settings for users of a stack. When these settings are enabled, changes that users make to applications and Windows settings are automatically saved after each session and applied to the next session.

Returns:



2446
2447
2448
2449
2450
2451
2452
2453
2454
2455
2456
2457
2458
2459
2460
2461
2462
2463
# File 'lib/aws-sdk-appstream/types.rb', line 2446

class CreateStackRequest < Struct.new(
  :name,
  :description,
  :display_name,
  :storage_connectors,
  :redirect_url,
  :feedback_url,
  :user_settings,
  :application_settings,
  :tags,
  :access_endpoints,
  :embed_host_domains,
  :streaming_experience_settings,
  :content_redirection,
  :agent_access_config)
  SENSITIVE = []
  include Aws::Structure
end

#content_redirectionTypes::ContentRedirection

Configuration for bidirectional URL redirection between the streaming session and the local client. Use HostToClient to redirect URLs from the remote desktop to the local browser.

Returns:



2446
2447
2448
2449
2450
2451
2452
2453
2454
2455
2456
2457
2458
2459
2460
2461
2462
2463
# File 'lib/aws-sdk-appstream/types.rb', line 2446

class CreateStackRequest < Struct.new(
  :name,
  :description,
  :display_name,
  :storage_connectors,
  :redirect_url,
  :feedback_url,
  :user_settings,
  :application_settings,
  :tags,
  :access_endpoints,
  :embed_host_domains,
  :streaming_experience_settings,
  :content_redirection,
  :agent_access_config)
  SENSITIVE = []
  include Aws::Structure
end

#descriptionString

The description to display.

Returns:



2446
2447
2448
2449
2450
2451
2452
2453
2454
2455
2456
2457
2458
2459
2460
2461
2462
2463
# File 'lib/aws-sdk-appstream/types.rb', line 2446

class CreateStackRequest < Struct.new(
  :name,
  :description,
  :display_name,
  :storage_connectors,
  :redirect_url,
  :feedback_url,
  :user_settings,
  :application_settings,
  :tags,
  :access_endpoints,
  :embed_host_domains,
  :streaming_experience_settings,
  :content_redirection,
  :agent_access_config)
  SENSITIVE = []
  include Aws::Structure
end

#display_nameString

The stack name to display.

Returns:



2446
2447
2448
2449
2450
2451
2452
2453
2454
2455
2456
2457
2458
2459
2460
2461
2462
2463
# File 'lib/aws-sdk-appstream/types.rb', line 2446

class CreateStackRequest < Struct.new(
  :name,
  :description,
  :display_name,
  :storage_connectors,
  :redirect_url,
  :feedback_url,
  :user_settings,
  :application_settings,
  :tags,
  :access_endpoints,
  :embed_host_domains,
  :streaming_experience_settings,
  :content_redirection,
  :agent_access_config)
  SENSITIVE = []
  include Aws::Structure
end

#embed_host_domainsArray<String>

The domains where WorkSpaces Applications streaming sessions can be embedded in an iframe. You must approve the domains that you want to host embedded WorkSpaces Applications streaming sessions.

Returns:



2446
2447
2448
2449
2450
2451
2452
2453
2454
2455
2456
2457
2458
2459
2460
2461
2462
2463
# File 'lib/aws-sdk-appstream/types.rb', line 2446

class CreateStackRequest < Struct.new(
  :name,
  :description,
  :display_name,
  :storage_connectors,
  :redirect_url,
  :feedback_url,
  :user_settings,
  :application_settings,
  :tags,
  :access_endpoints,
  :embed_host_domains,
  :streaming_experience_settings,
  :content_redirection,
  :agent_access_config)
  SENSITIVE = []
  include Aws::Structure
end

#feedback_urlString

The URL that users are redirected to after they click the Send Feedback link. If no URL is specified, no Send Feedback link is displayed.

Returns:



2446
2447
2448
2449
2450
2451
2452
2453
2454
2455
2456
2457
2458
2459
2460
2461
2462
2463
# File 'lib/aws-sdk-appstream/types.rb', line 2446

class CreateStackRequest < Struct.new(
  :name,
  :description,
  :display_name,
  :storage_connectors,
  :redirect_url,
  :feedback_url,
  :user_settings,
  :application_settings,
  :tags,
  :access_endpoints,
  :embed_host_domains,
  :streaming_experience_settings,
  :content_redirection,
  :agent_access_config)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The name of the stack.

Returns:



2446
2447
2448
2449
2450
2451
2452
2453
2454
2455
2456
2457
2458
2459
2460
2461
2462
2463
# File 'lib/aws-sdk-appstream/types.rb', line 2446

class CreateStackRequest < Struct.new(
  :name,
  :description,
  :display_name,
  :storage_connectors,
  :redirect_url,
  :feedback_url,
  :user_settings,
  :application_settings,
  :tags,
  :access_endpoints,
  :embed_host_domains,
  :streaming_experience_settings,
  :content_redirection,
  :agent_access_config)
  SENSITIVE = []
  include Aws::Structure
end

#redirect_urlString

The URL that users are redirected to after their streaming session ends.

Returns:



2446
2447
2448
2449
2450
2451
2452
2453
2454
2455
2456
2457
2458
2459
2460
2461
2462
2463
# File 'lib/aws-sdk-appstream/types.rb', line 2446

class CreateStackRequest < Struct.new(
  :name,
  :description,
  :display_name,
  :storage_connectors,
  :redirect_url,
  :feedback_url,
  :user_settings,
  :application_settings,
  :tags,
  :access_endpoints,
  :embed_host_domains,
  :streaming_experience_settings,
  :content_redirection,
  :agent_access_config)
  SENSITIVE = []
  include Aws::Structure
end

#storage_connectorsArray<Types::StorageConnector>

The storage connectors to enable.

Returns:



2446
2447
2448
2449
2450
2451
2452
2453
2454
2455
2456
2457
2458
2459
2460
2461
2462
2463
# File 'lib/aws-sdk-appstream/types.rb', line 2446

class CreateStackRequest < Struct.new(
  :name,
  :description,
  :display_name,
  :storage_connectors,
  :redirect_url,
  :feedback_url,
  :user_settings,
  :application_settings,
  :tags,
  :access_endpoints,
  :embed_host_domains,
  :streaming_experience_settings,
  :content_redirection,
  :agent_access_config)
  SENSITIVE = []
  include Aws::Structure
end

#streaming_experience_settingsTypes::StreamingExperienceSettings

The streaming protocol you want your stack to prefer. This can be UDP or TCP. Currently, UDP is only supported in the Windows native client.

Returns:



2446
2447
2448
2449
2450
2451
2452
2453
2454
2455
2456
2457
2458
2459
2460
2461
2462
2463
# File 'lib/aws-sdk-appstream/types.rb', line 2446

class CreateStackRequest < Struct.new(
  :name,
  :description,
  :display_name,
  :storage_connectors,
  :redirect_url,
  :feedback_url,
  :user_settings,
  :application_settings,
  :tags,
  :access_endpoints,
  :embed_host_domains,
  :streaming_experience_settings,
  :content_redirection,
  :agent_access_config)
  SENSITIVE = []
  include Aws::Structure
end

#tagsHash<String,String>

The tags to associate with the stack. A tag is a key-value pair, and the value is optional. For example, Environment=Test. If you do not specify a value, Environment=.

If you do not specify a value, the value is set to an empty string.

Generally allowed characters are: letters, numbers, and spaces representable in UTF-8, and the following special characters:

_ . : / = + \ - @

For more information about tags, see Tagging Your Resources in the Amazon WorkSpaces Applications Administration Guide.

Returns:



2446
2447
2448
2449
2450
2451
2452
2453
2454
2455
2456
2457
2458
2459
2460
2461
2462
2463
# File 'lib/aws-sdk-appstream/types.rb', line 2446

class CreateStackRequest < Struct.new(
  :name,
  :description,
  :display_name,
  :storage_connectors,
  :redirect_url,
  :feedback_url,
  :user_settings,
  :application_settings,
  :tags,
  :access_endpoints,
  :embed_host_domains,
  :streaming_experience_settings,
  :content_redirection,
  :agent_access_config)
  SENSITIVE = []
  include Aws::Structure
end

#user_settingsArray<Types::UserSetting>

The actions that are enabled or disabled for users during their streaming sessions. By default, these actions are enabled.

Returns:



2446
2447
2448
2449
2450
2451
2452
2453
2454
2455
2456
2457
2458
2459
2460
2461
2462
2463
# File 'lib/aws-sdk-appstream/types.rb', line 2446

class CreateStackRequest < Struct.new(
  :name,
  :description,
  :display_name,
  :storage_connectors,
  :redirect_url,
  :feedback_url,
  :user_settings,
  :application_settings,
  :tags,
  :access_endpoints,
  :embed_host_domains,
  :streaming_experience_settings,
  :content_redirection,
  :agent_access_config)
  SENSITIVE = []
  include Aws::Structure
end