Class: Aws::AppStream::Types::CreateStreamingURLRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::AppStream::Types::CreateStreamingURLRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-appstream/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#application_id ⇒ String
The name of the application to launch after the session starts.
-
#fleet_name ⇒ String
The name of the fleet.
-
#session_context ⇒ String
The session context.
-
#stack_name ⇒ String
The name of the stack.
-
#user_id ⇒ String
The identifier of the user.
-
#validity ⇒ Integer
The time that the streaming URL will be valid, in seconds.
Instance Attribute Details
#application_id ⇒ String
The name of the application to launch after the session starts. This is the name that you specified as Name in the Image Assistant. If your fleet is enabled for the Desktop stream view, you can also choose to launch directly to the operating system desktop. To do so, specify Desktop.
2513 2514 2515 2516 2517 2518 2519 2520 2521 2522 |
# File 'lib/aws-sdk-appstream/types.rb', line 2513 class CreateStreamingURLRequest < Struct.new( :stack_name, :fleet_name, :user_id, :application_id, :validity, :session_context) SENSITIVE = [] include Aws::Structure end |
#fleet_name ⇒ String
The name of the fleet.
2513 2514 2515 2516 2517 2518 2519 2520 2521 2522 |
# File 'lib/aws-sdk-appstream/types.rb', line 2513 class CreateStreamingURLRequest < Struct.new( :stack_name, :fleet_name, :user_id, :application_id, :validity, :session_context) SENSITIVE = [] include Aws::Structure end |
#session_context ⇒ String
The session context. For more information, see [Session Context] in the *Amazon WorkSpaces Applications Administration Guide*.
2513 2514 2515 2516 2517 2518 2519 2520 2521 2522 |
# File 'lib/aws-sdk-appstream/types.rb', line 2513 class CreateStreamingURLRequest < Struct.new( :stack_name, :fleet_name, :user_id, :application_id, :validity, :session_context) SENSITIVE = [] include Aws::Structure end |
#stack_name ⇒ String
The name of the stack.
2513 2514 2515 2516 2517 2518 2519 2520 2521 2522 |
# File 'lib/aws-sdk-appstream/types.rb', line 2513 class CreateStreamingURLRequest < Struct.new( :stack_name, :fleet_name, :user_id, :application_id, :validity, :session_context) SENSITIVE = [] include Aws::Structure end |
#user_id ⇒ String
The identifier of the user.
2513 2514 2515 2516 2517 2518 2519 2520 2521 2522 |
# File 'lib/aws-sdk-appstream/types.rb', line 2513 class CreateStreamingURLRequest < Struct.new( :stack_name, :fleet_name, :user_id, :application_id, :validity, :session_context) SENSITIVE = [] include Aws::Structure end |
#validity ⇒ Integer
The time that the streaming URL will be valid, in seconds. Specify a value between 1 and 604800 seconds. The default is 60 seconds.
2513 2514 2515 2516 2517 2518 2519 2520 2521 2522 |
# File 'lib/aws-sdk-appstream/types.rb', line 2513 class CreateStreamingURLRequest < Struct.new( :stack_name, :fleet_name, :user_id, :application_id, :validity, :session_context) SENSITIVE = [] include Aws::Structure end |