Class: Aws::AppStream::Types::CreateThemeForStackRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::AppStream::Types::CreateThemeForStackRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-appstream/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#favicon_s3_location ⇒ Types::S3Location
The S3 location of the favicon.
-
#footer_links ⇒ Array<Types::ThemeFooterLink>
The links that are displayed in the footer of the streaming application catalog page.
-
#organization_logo_s3_location ⇒ Types::S3Location
The organization logo that appears on the streaming application catalog page.
-
#stack_name ⇒ String
The name of the stack for the theme.
-
#theme_styling ⇒ String
The color theme that is applied to website links, text, and buttons.
-
#title_text ⇒ String
The title that is displayed at the top of the browser tab during users’ application streaming sessions.
Instance Attribute Details
#favicon_s3_location ⇒ Types::S3Location
The S3 location of the favicon. The favicon enables users to recognize their application streaming site in a browser full of tabs or bookmarks. It is displayed at the top of the browser tab for the application streaming site during users’ streaming sessions.
2578 2579 2580 2581 2582 2583 2584 2585 2586 2587 |
# File 'lib/aws-sdk-appstream/types.rb', line 2578 class CreateThemeForStackRequest < Struct.new( :stack_name, :footer_links, :title_text, :theme_styling, :organization_logo_s3_location, :favicon_s3_location) SENSITIVE = [] include Aws::Structure end |
#footer_links ⇒ Array<Types::ThemeFooterLink>
The links that are displayed in the footer of the streaming application catalog page. These links are helpful resources for users, such as the organization’s IT support and product marketing sites.
2578 2579 2580 2581 2582 2583 2584 2585 2586 2587 |
# File 'lib/aws-sdk-appstream/types.rb', line 2578 class CreateThemeForStackRequest < Struct.new( :stack_name, :footer_links, :title_text, :theme_styling, :organization_logo_s3_location, :favicon_s3_location) SENSITIVE = [] include Aws::Structure end |
#organization_logo_s3_location ⇒ Types::S3Location
The organization logo that appears on the streaming application catalog page.
2578 2579 2580 2581 2582 2583 2584 2585 2586 2587 |
# File 'lib/aws-sdk-appstream/types.rb', line 2578 class CreateThemeForStackRequest < Struct.new( :stack_name, :footer_links, :title_text, :theme_styling, :organization_logo_s3_location, :favicon_s3_location) SENSITIVE = [] include Aws::Structure end |
#stack_name ⇒ String
The name of the stack for the theme.
2578 2579 2580 2581 2582 2583 2584 2585 2586 2587 |
# File 'lib/aws-sdk-appstream/types.rb', line 2578 class CreateThemeForStackRequest < Struct.new( :stack_name, :footer_links, :title_text, :theme_styling, :organization_logo_s3_location, :favicon_s3_location) SENSITIVE = [] include Aws::Structure end |
#theme_styling ⇒ String
The color theme that is applied to website links, text, and buttons. These colors are also applied as accents in the background for the streaming application catalog page.
2578 2579 2580 2581 2582 2583 2584 2585 2586 2587 |
# File 'lib/aws-sdk-appstream/types.rb', line 2578 class CreateThemeForStackRequest < Struct.new( :stack_name, :footer_links, :title_text, :theme_styling, :organization_logo_s3_location, :favicon_s3_location) SENSITIVE = [] include Aws::Structure end |
#title_text ⇒ String
The title that is displayed at the top of the browser tab during users’ application streaming sessions.
2578 2579 2580 2581 2582 2583 2584 2585 2586 2587 |
# File 'lib/aws-sdk-appstream/types.rb', line 2578 class CreateThemeForStackRequest < Struct.new( :stack_name, :footer_links, :title_text, :theme_styling, :organization_logo_s3_location, :favicon_s3_location) SENSITIVE = [] include Aws::Structure end |