Class: Aws::AppStream::Types::CreateUsageReportSubscriptionResult
- Inherits:
-
Struct
- Object
- Struct
- Aws::AppStream::Types::CreateUsageReportSubscriptionResult
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-appstream/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#s3_bucket_name ⇒ String
The Amazon S3 bucket where generated reports are stored.
-
#schedule ⇒ String
The schedule for generating usage reports.
Instance Attribute Details
#s3_bucket_name ⇒ String
The Amazon S3 bucket where generated reports are stored.
If you enabled on-instance session scripts and Amazon S3 logging for your session script configuration, WorkSpaces Applications created an S3 bucket to store the script output. The bucket is unique to your account and Region. When you enable usage reporting in this case, WorkSpaces Applications uses the same bucket to store your usage reports. If you haven’t already enabled on-instance session scripts, when you enable usage reports, WorkSpaces Applications creates a new S3 bucket.
2581 2582 2583 2584 2585 2586 |
# File 'lib/aws-sdk-appstream/types.rb', line 2581 class CreateUsageReportSubscriptionResult < Struct.new( :s3_bucket_name, :schedule) SENSITIVE = [] include Aws::Structure end |
#schedule ⇒ String
The schedule for generating usage reports.
2581 2582 2583 2584 2585 2586 |
# File 'lib/aws-sdk-appstream/types.rb', line 2581 class CreateUsageReportSubscriptionResult < Struct.new( :s3_bucket_name, :schedule) SENSITIVE = [] include Aws::Structure end |