Class: Aws::AppStream::Types::DescribeAppBlockBuildersRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::AppStream::Types::DescribeAppBlockBuildersRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-appstream/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#max_results ⇒ Integer
The maximum size of each page of results.
-
#names ⇒ Array<String>
The names of the app block builders.
-
#next_token ⇒ String
The pagination token used to retrieve the next page of results for this operation.
Instance Attribute Details
#max_results ⇒ Integer
The maximum size of each page of results. The maximum value is 25.
3047 3048 3049 3050 3051 3052 3053 |
# File 'lib/aws-sdk-appstream/types.rb', line 3047 class DescribeAppBlockBuildersRequest < Struct.new( :names, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#names ⇒ Array<String>
The names of the app block builders.
3047 3048 3049 3050 3051 3052 3053 |
# File 'lib/aws-sdk-appstream/types.rb', line 3047 class DescribeAppBlockBuildersRequest < Struct.new( :names, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The pagination token used to retrieve the next page of results for this operation.
3047 3048 3049 3050 3051 3052 3053 |
# File 'lib/aws-sdk-appstream/types.rb', line 3047 class DescribeAppBlockBuildersRequest < Struct.new( :names, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |