Class: Aws::AppStream::Types::DescribeDirectoryConfigsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::AppStream::Types::DescribeDirectoryConfigsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-appstream/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#directory_names ⇒ Array<String>
The directory names.
-
#max_results ⇒ Integer
The maximum size of each page of results.
-
#next_token ⇒ String
The pagination token to use to retrieve the next page of results for this operation.
Instance Attribute Details
#directory_names ⇒ Array<String>
The directory names.
3258 3259 3260 3261 3262 3263 3264 |
# File 'lib/aws-sdk-appstream/types.rb', line 3258 class DescribeDirectoryConfigsRequest < Struct.new( :directory_names, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum size of each page of results.
3258 3259 3260 3261 3262 3263 3264 |
# File 'lib/aws-sdk-appstream/types.rb', line 3258 class DescribeDirectoryConfigsRequest < Struct.new( :directory_names, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The pagination token to use to retrieve the next page of results for this operation. If this value is null, it retrieves the first page.
3258 3259 3260 3261 3262 3263 3264 |
# File 'lib/aws-sdk-appstream/types.rb', line 3258 class DescribeDirectoryConfigsRequest < Struct.new( :directory_names, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |