Class: Aws::AppStream::Types::DescribeImagePermissionsRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-appstream/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#max_resultsInteger

The maximum size of each page of results.



3445
3446
3447
3448
3449
3450
3451
3452
# File 'lib/aws-sdk-appstream/types.rb', line 3445

class DescribeImagePermissionsRequest < Struct.new(
  :name,
  :max_results,
  :shared_aws_account_ids,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The name of the private image for which to describe permissions. The image must be one that you own.



3445
3446
3447
3448
3449
3450
3451
3452
# File 'lib/aws-sdk-appstream/types.rb', line 3445

class DescribeImagePermissionsRequest < Struct.new(
  :name,
  :max_results,
  :shared_aws_account_ids,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

The pagination token to use to retrieve the next page of results for this operation. If this value is null, it retrieves the first page.



3445
3446
3447
3448
3449
3450
3451
3452
# File 'lib/aws-sdk-appstream/types.rb', line 3445

class DescribeImagePermissionsRequest < Struct.new(
  :name,
  :max_results,
  :shared_aws_account_ids,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#shared_aws_account_idsArray<String>

The 12-digit identifier of one or more AWS accounts with which the image is shared.



3445
3446
3447
3448
3449
3450
3451
3452
# File 'lib/aws-sdk-appstream/types.rb', line 3445

class DescribeImagePermissionsRequest < Struct.new(
  :name,
  :max_results,
  :shared_aws_account_ids,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end