Class: Aws::AppStream::Types::DescribeSoftwareAssociationsResult
- Inherits:
-
Struct
- Object
- Struct
- Aws::AppStream::Types::DescribeSoftwareAssociationsResult
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-appstream/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#associated_resource ⇒ String
The ARN of the resource to describe software associations.
-
#next_token ⇒ String
The pagination token to use to retrieve the next page of results for this operation.
-
#software_associations ⇒ Array<Types::SoftwareAssociations>
Collection of license included applications association details including:.
Instance Attribute Details
#associated_resource ⇒ String
The ARN of the resource to describe software associations.
3476 3477 3478 3479 3480 3481 3482 |
# File 'lib/aws-sdk-appstream/types.rb', line 3476 class DescribeSoftwareAssociationsResult < Struct.new( :associated_resource, :software_associations, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The pagination token to use to retrieve the next page of results for this operation.
3476 3477 3478 3479 3480 3481 3482 |
# File 'lib/aws-sdk-appstream/types.rb', line 3476 class DescribeSoftwareAssociationsResult < Struct.new( :associated_resource, :software_associations, :next_token) SENSITIVE = [] include Aws::Structure end |
#software_associations ⇒ Array<Types::SoftwareAssociations>
Collection of license included applications association details including:
-
License included application name and version information
-
Deployment status (SoftwareDeploymentStatus enum)
-
Error details for failed deployments
-
Association timestamps
3476 3477 3478 3479 3480 3481 3482 |
# File 'lib/aws-sdk-appstream/types.rb', line 3476 class DescribeSoftwareAssociationsResult < Struct.new( :associated_resource, :software_associations, :next_token) SENSITIVE = [] include Aws::Structure end |