Class: Aws::AppStream::Types::DescribeUsageReportSubscriptionsResult

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-appstream/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#next_tokenString

The pagination token to use to retrieve the next page of results for this operation. If there are no more pages, this value is null.



3738
3739
3740
3741
3742
3743
# File 'lib/aws-sdk-appstream/types.rb', line 3738

class DescribeUsageReportSubscriptionsResult < Struct.new(
  :usage_report_subscriptions,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#usage_report_subscriptionsArray<Types::UsageReportSubscription>

Information about the usage report subscription.



3738
3739
3740
3741
3742
3743
# File 'lib/aws-sdk-appstream/types.rb', line 3738

class DescribeUsageReportSubscriptionsResult < Struct.new(
  :usage_report_subscriptions,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end