Class: Aws::AppStream::Types::DescribeUserStackAssociationsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::AppStream::Types::DescribeUserStackAssociationsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-appstream/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[:user_name]
Instance Attribute Summary collapse
-
#authentication_type ⇒ String
The authentication type for the user who is associated with the stack.
-
#max_results ⇒ Integer
The maximum size of each page of results.
-
#next_token ⇒ String
The pagination token to use to retrieve the next page of results for this operation.
-
#stack_name ⇒ String
The name of the stack that is associated with the user.
-
#user_name ⇒ String
The email address of the user who is associated with the stack.
Instance Attribute Details
#authentication_type ⇒ String
The authentication type for the user who is associated with the stack. You must specify USERPOOL.
3773 3774 3775 3776 3777 3778 3779 3780 3781 |
# File 'lib/aws-sdk-appstream/types.rb', line 3773 class DescribeUserStackAssociationsRequest < Struct.new( :stack_name, :user_name, :authentication_type, :max_results, :next_token) SENSITIVE = [:user_name] include Aws::Structure end |
#max_results ⇒ Integer
The maximum size of each page of results.
3773 3774 3775 3776 3777 3778 3779 3780 3781 |
# File 'lib/aws-sdk-appstream/types.rb', line 3773 class DescribeUserStackAssociationsRequest < Struct.new( :stack_name, :user_name, :authentication_type, :max_results, :next_token) SENSITIVE = [:user_name] include Aws::Structure end |
#next_token ⇒ String
The pagination token to use to retrieve the next page of results for this operation. If this value is null, it retrieves the first page.
3773 3774 3775 3776 3777 3778 3779 3780 3781 |
# File 'lib/aws-sdk-appstream/types.rb', line 3773 class DescribeUserStackAssociationsRequest < Struct.new( :stack_name, :user_name, :authentication_type, :max_results, :next_token) SENSITIVE = [:user_name] include Aws::Structure end |
#stack_name ⇒ String
The name of the stack that is associated with the user.
3773 3774 3775 3776 3777 3778 3779 3780 3781 |
# File 'lib/aws-sdk-appstream/types.rb', line 3773 class DescribeUserStackAssociationsRequest < Struct.new( :stack_name, :user_name, :authentication_type, :max_results, :next_token) SENSITIVE = [:user_name] include Aws::Structure end |
#user_name ⇒ String
The email address of the user who is associated with the stack.
<note markdown=“1”> Users’ email addresses are case-sensitive.
</note>
3773 3774 3775 3776 3777 3778 3779 3780 3781 |
# File 'lib/aws-sdk-appstream/types.rb', line 3773 class DescribeUserStackAssociationsRequest < Struct.new( :stack_name, :user_name, :authentication_type, :max_results, :next_token) SENSITIVE = [:user_name] include Aws::Structure end |