Class: Aws::AppStream::Types::DescribeUsersRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::AppStream::Types::DescribeUsersRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-appstream/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#authentication_type ⇒ String
The authentication type for the users in the user pool to describe.
-
#max_results ⇒ Integer
The maximum size of each page of results.
-
#next_token ⇒ String
The pagination token to use to retrieve the next page of results for this operation.
Instance Attribute Details
#authentication_type ⇒ String
The authentication type for the users in the user pool to describe. You must specify USERPOOL.
3652 3653 3654 3655 3656 3657 3658 |
# File 'lib/aws-sdk-appstream/types.rb', line 3652 class DescribeUsersRequest < Struct.new( :authentication_type, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum size of each page of results.
3652 3653 3654 3655 3656 3657 3658 |
# File 'lib/aws-sdk-appstream/types.rb', line 3652 class DescribeUsersRequest < Struct.new( :authentication_type, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The pagination token to use to retrieve the next page of results for this operation. If this value is null, it retrieves the first page.
3652 3653 3654 3655 3656 3657 3658 |
# File 'lib/aws-sdk-appstream/types.rb', line 3652 class DescribeUsersRequest < Struct.new( :authentication_type, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |