Class: Aws::AppStream::Types::DescribeUsersResult
- Inherits:
-
Struct
- Object
- Struct
- Aws::AppStream::Types::DescribeUsersResult
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-appstream/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#next_token ⇒ String
The pagination token to use to retrieve the next page of results for this operation.
-
#users ⇒ Array<Types::User>
Information about users in the user pool.
Instance Attribute Details
#next_token ⇒ String
The pagination token to use to retrieve the next page of results for this operation. If there are no more pages, this value is null.
3671 3672 3673 3674 3675 3676 |
# File 'lib/aws-sdk-appstream/types.rb', line 3671 class DescribeUsersResult < Struct.new( :users, :next_token) SENSITIVE = [] include Aws::Structure end |
#users ⇒ Array<Types::User>
Information about users in the user pool.
3671 3672 3673 3674 3675 3676 |
# File 'lib/aws-sdk-appstream/types.rb', line 3671 class DescribeUsersResult < Struct.new( :users, :next_token) SENSITIVE = [] include Aws::Structure end |