Class: Aws::AppStream::Types::DryRunOperationException

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-appstream/types.rb

Overview

The exception that is thrown when a dry run operation is requested. This indicates that the validation checks have been performed successfully, but no actual resources were created or modified.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#messageString

The error message in the exception.

Returns:



3943
3944
3945
3946
3947
# File 'lib/aws-sdk-appstream/types.rb', line 3943

class DryRunOperationException < Struct.new(
  :message)
  SENSITIVE = []
  include Aws::Structure
end