Class: Aws::AppStream::Types::Entitlement

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-appstream/types.rb

Overview

Specifies an entitlement. Entitlements control access to specific applications within a stack, based on user attributes. Entitlements apply to SAML 2.0 federated user identities. WorkSpaces Applications user pool and streaming URL users are entitled to all applications in a stack. Entitlements don’t apply to the desktop stream view application, or to applications managed by a dynamic app provider using the Dynamic Application Framework.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#app_visibilityString

Specifies whether all or selected apps are entitled.

Returns:

  • (String)


4030
4031
4032
4033
4034
4035
4036
4037
4038
4039
4040
# File 'lib/aws-sdk-appstream/types.rb', line 4030

class Entitlement < Struct.new(
  :name,
  :stack_name,
  :description,
  :app_visibility,
  :attributes,
  :created_time,
  :last_modified_time)
  SENSITIVE = []
  include Aws::Structure
end

#attributesArray<Types::EntitlementAttribute>

The attributes of the entitlement.

Returns:



4030
4031
4032
4033
4034
4035
4036
4037
4038
4039
4040
# File 'lib/aws-sdk-appstream/types.rb', line 4030

class Entitlement < Struct.new(
  :name,
  :stack_name,
  :description,
  :app_visibility,
  :attributes,
  :created_time,
  :last_modified_time)
  SENSITIVE = []
  include Aws::Structure
end

#created_timeTime

The time when the entitlement was created.

Returns:

  • (Time)


4030
4031
4032
4033
4034
4035
4036
4037
4038
4039
4040
# File 'lib/aws-sdk-appstream/types.rb', line 4030

class Entitlement < Struct.new(
  :name,
  :stack_name,
  :description,
  :app_visibility,
  :attributes,
  :created_time,
  :last_modified_time)
  SENSITIVE = []
  include Aws::Structure
end

#descriptionString

The description of the entitlement.

Returns:

  • (String)


4030
4031
4032
4033
4034
4035
4036
4037
4038
4039
4040
# File 'lib/aws-sdk-appstream/types.rb', line 4030

class Entitlement < Struct.new(
  :name,
  :stack_name,
  :description,
  :app_visibility,
  :attributes,
  :created_time,
  :last_modified_time)
  SENSITIVE = []
  include Aws::Structure
end

#last_modified_timeTime

The time when the entitlement was last modified.

Returns:

  • (Time)


4030
4031
4032
4033
4034
4035
4036
4037
4038
4039
4040
# File 'lib/aws-sdk-appstream/types.rb', line 4030

class Entitlement < Struct.new(
  :name,
  :stack_name,
  :description,
  :app_visibility,
  :attributes,
  :created_time,
  :last_modified_time)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The name of the entitlement.

Returns:

  • (String)


4030
4031
4032
4033
4034
4035
4036
4037
4038
4039
4040
# File 'lib/aws-sdk-appstream/types.rb', line 4030

class Entitlement < Struct.new(
  :name,
  :stack_name,
  :description,
  :app_visibility,
  :attributes,
  :created_time,
  :last_modified_time)
  SENSITIVE = []
  include Aws::Structure
end

#stack_nameString

The name of the stack with which the entitlement is associated.

Returns:

  • (String)


4030
4031
4032
4033
4034
4035
4036
4037
4038
4039
4040
# File 'lib/aws-sdk-appstream/types.rb', line 4030

class Entitlement < Struct.new(
  :name,
  :stack_name,
  :description,
  :app_visibility,
  :attributes,
  :created_time,
  :last_modified_time)
  SENSITIVE = []
  include Aws::Structure
end