Class: Aws::AppStream::Types::ExportImageTask
- Inherits:
-
Struct
- Object
- Struct
- Aws::AppStream::Types::ExportImageTask
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-appstream/types.rb
Overview
Information about an export image task, including its current state, timestamps, and any error details.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#ami_description ⇒ String
The description that will be applied to the exported EC2 AMI.
-
#ami_id ⇒ String
The ID of the EC2 AMI that was created by this export task.
-
#ami_name ⇒ String
The name of the EC2 AMI that will be created by this export task.
-
#created_date ⇒ Time
The date and time when the export image task was created.
-
#error_details ⇒ Array<Types::ErrorDetails>
Details about any errors that occurred during the export process.
-
#image_arn ⇒ String
The ARN of the WorkSpaces Applications image being exported.
-
#state ⇒ String
The current state of the export image task, such as PENDING, RUNNING, COMPLETED, or FAILED.
-
#tag_specifications ⇒ Hash<String,String>
The tags that will be applied to the exported EC2 AMI.
-
#task_id ⇒ String
The unique identifier for the export image task.
Instance Attribute Details
#ami_description ⇒ String
The description that will be applied to the exported EC2 AMI.
4372 4373 4374 4375 4376 4377 4378 4379 4380 4381 4382 4383 4384 |
# File 'lib/aws-sdk-appstream/types.rb', line 4372 class ExportImageTask < Struct.new( :task_id, :image_arn, :ami_name, :created_date, :ami_description, :state, :ami_id, :tag_specifications, :error_details) SENSITIVE = [] include Aws::Structure end |
#ami_id ⇒ String
The ID of the EC2 AMI that was created by this export task. This field is only populated when the task completes successfully.
4372 4373 4374 4375 4376 4377 4378 4379 4380 4381 4382 4383 4384 |
# File 'lib/aws-sdk-appstream/types.rb', line 4372 class ExportImageTask < Struct.new( :task_id, :image_arn, :ami_name, :created_date, :ami_description, :state, :ami_id, :tag_specifications, :error_details) SENSITIVE = [] include Aws::Structure end |
#ami_name ⇒ String
The name of the EC2 AMI that will be created by this export task.
4372 4373 4374 4375 4376 4377 4378 4379 4380 4381 4382 4383 4384 |
# File 'lib/aws-sdk-appstream/types.rb', line 4372 class ExportImageTask < Struct.new( :task_id, :image_arn, :ami_name, :created_date, :ami_description, :state, :ami_id, :tag_specifications, :error_details) SENSITIVE = [] include Aws::Structure end |
#created_date ⇒ Time
The date and time when the export image task was created.
4372 4373 4374 4375 4376 4377 4378 4379 4380 4381 4382 4383 4384 |
# File 'lib/aws-sdk-appstream/types.rb', line 4372 class ExportImageTask < Struct.new( :task_id, :image_arn, :ami_name, :created_date, :ami_description, :state, :ami_id, :tag_specifications, :error_details) SENSITIVE = [] include Aws::Structure end |
#error_details ⇒ Array<Types::ErrorDetails>
Details about any errors that occurred during the export process. This field is only populated when the task fails.
4372 4373 4374 4375 4376 4377 4378 4379 4380 4381 4382 4383 4384 |
# File 'lib/aws-sdk-appstream/types.rb', line 4372 class ExportImageTask < Struct.new( :task_id, :image_arn, :ami_name, :created_date, :ami_description, :state, :ami_id, :tag_specifications, :error_details) SENSITIVE = [] include Aws::Structure end |
#image_arn ⇒ String
The ARN of the WorkSpaces Applications image being exported.
4372 4373 4374 4375 4376 4377 4378 4379 4380 4381 4382 4383 4384 |
# File 'lib/aws-sdk-appstream/types.rb', line 4372 class ExportImageTask < Struct.new( :task_id, :image_arn, :ami_name, :created_date, :ami_description, :state, :ami_id, :tag_specifications, :error_details) SENSITIVE = [] include Aws::Structure end |
#state ⇒ String
The current state of the export image task, such as PENDING, RUNNING, COMPLETED, or FAILED.
4372 4373 4374 4375 4376 4377 4378 4379 4380 4381 4382 4383 4384 |
# File 'lib/aws-sdk-appstream/types.rb', line 4372 class ExportImageTask < Struct.new( :task_id, :image_arn, :ami_name, :created_date, :ami_description, :state, :ami_id, :tag_specifications, :error_details) SENSITIVE = [] include Aws::Structure end |
#tag_specifications ⇒ Hash<String,String>
The tags that will be applied to the exported EC2 AMI.
4372 4373 4374 4375 4376 4377 4378 4379 4380 4381 4382 4383 4384 |
# File 'lib/aws-sdk-appstream/types.rb', line 4372 class ExportImageTask < Struct.new( :task_id, :image_arn, :ami_name, :created_date, :ami_description, :state, :ami_id, :tag_specifications, :error_details) SENSITIVE = [] include Aws::Structure end |
#task_id ⇒ String
The unique identifier for the export image task. Use this ID to track the task’s progress and retrieve its details.
4372 4373 4374 4375 4376 4377 4378 4379 4380 4381 4382 4383 4384 |
# File 'lib/aws-sdk-appstream/types.rb', line 4372 class ExportImageTask < Struct.new( :task_id, :image_arn, :ami_name, :created_date, :ami_description, :state, :ami_id, :tag_specifications, :error_details) SENSITIVE = [] include Aws::Structure end |