Class: Aws::AppStream::Types::Filter

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-appstream/types.rb

Overview

A filter for narrowing down the results when listing export image tasks. Filters allow you to specify criteria such as task state or creation date.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#nameString

The name of the filter. Valid filter names depend on the operation being performed.

Returns:



4221
4222
4223
4224
4225
4226
# File 'lib/aws-sdk-appstream/types.rb', line 4221

class Filter < Struct.new(
  :name,
  :values)
  SENSITIVE = []
  include Aws::Structure
end

#valuesArray<String>

The values for the filter. Multiple values can be specified for a single filter name.

Returns:



4221
4222
4223
4224
4225
4226
# File 'lib/aws-sdk-appstream/types.rb', line 4221

class Filter < Struct.new(
  :name,
  :values)
  SENSITIVE = []
  include Aws::Structure
end