Class: Aws::AppStream::Types::ImageBuilder

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-appstream/types.rb

Overview

Describes a virtual machine that is used to create an image.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#access_endpointsArray<Types::AccessEndpoint>

The list of virtual private cloud (VPC) interface endpoint objects. Administrators can connect to the image builder only through the specified endpoints.

Returns:



4945
4946
4947
4948
4949
4950
4951
4952
4953
4954
4955
4956
4957
4958
4959
4960
4961
4962
4963
4964
4965
4966
4967
4968
4969
# File 'lib/aws-sdk-appstream/types.rb', line 4945

class ImageBuilder < Struct.new(
  :name,
  :arn,
  :image_arn,
  :description,
  :display_name,
  :vpc_config,
  :instance_type,
  :platform,
  :iam_role_arn,
  :state,
  :state_change_reason,
  :created_time,
  :enable_default_internet_access,
  :domain_join_info,
  :network_access_configuration,
  :image_builder_errors,
  :appstream_agent_version,
  :access_endpoints,
  :root_volume_config,
  :latest_appstream_agent_version,
  :disable_imdsv1)
  SENSITIVE = []
  include Aws::Structure
end

#appstream_agent_versionString

The version of the WorkSpaces Applications agent that is currently being used by the image builder.

Returns:

  • (String)


4945
4946
4947
4948
4949
4950
4951
4952
4953
4954
4955
4956
4957
4958
4959
4960
4961
4962
4963
4964
4965
4966
4967
4968
4969
# File 'lib/aws-sdk-appstream/types.rb', line 4945

class ImageBuilder < Struct.new(
  :name,
  :arn,
  :image_arn,
  :description,
  :display_name,
  :vpc_config,
  :instance_type,
  :platform,
  :iam_role_arn,
  :state,
  :state_change_reason,
  :created_time,
  :enable_default_internet_access,
  :domain_join_info,
  :network_access_configuration,
  :image_builder_errors,
  :appstream_agent_version,
  :access_endpoints,
  :root_volume_config,
  :latest_appstream_agent_version,
  :disable_imdsv1)
  SENSITIVE = []
  include Aws::Structure
end

#arnString

The ARN for the image builder.

Returns:

  • (String)


4945
4946
4947
4948
4949
4950
4951
4952
4953
4954
4955
4956
4957
4958
4959
4960
4961
4962
4963
4964
4965
4966
4967
4968
4969
# File 'lib/aws-sdk-appstream/types.rb', line 4945

class ImageBuilder < Struct.new(
  :name,
  :arn,
  :image_arn,
  :description,
  :display_name,
  :vpc_config,
  :instance_type,
  :platform,
  :iam_role_arn,
  :state,
  :state_change_reason,
  :created_time,
  :enable_default_internet_access,
  :domain_join_info,
  :network_access_configuration,
  :image_builder_errors,
  :appstream_agent_version,
  :access_endpoints,
  :root_volume_config,
  :latest_appstream_agent_version,
  :disable_imdsv1)
  SENSITIVE = []
  include Aws::Structure
end

#created_timeTime

The time stamp when the image builder was created.

Returns:

  • (Time)


4945
4946
4947
4948
4949
4950
4951
4952
4953
4954
4955
4956
4957
4958
4959
4960
4961
4962
4963
4964
4965
4966
4967
4968
4969
# File 'lib/aws-sdk-appstream/types.rb', line 4945

class ImageBuilder < Struct.new(
  :name,
  :arn,
  :image_arn,
  :description,
  :display_name,
  :vpc_config,
  :instance_type,
  :platform,
  :iam_role_arn,
  :state,
  :state_change_reason,
  :created_time,
  :enable_default_internet_access,
  :domain_join_info,
  :network_access_configuration,
  :image_builder_errors,
  :appstream_agent_version,
  :access_endpoints,
  :root_volume_config,
  :latest_appstream_agent_version,
  :disable_imdsv1)
  SENSITIVE = []
  include Aws::Structure
end

#descriptionString

The description to display.

Returns:

  • (String)


4945
4946
4947
4948
4949
4950
4951
4952
4953
4954
4955
4956
4957
4958
4959
4960
4961
4962
4963
4964
4965
4966
4967
4968
4969
# File 'lib/aws-sdk-appstream/types.rb', line 4945

class ImageBuilder < Struct.new(
  :name,
  :arn,
  :image_arn,
  :description,
  :display_name,
  :vpc_config,
  :instance_type,
  :platform,
  :iam_role_arn,
  :state,
  :state_change_reason,
  :created_time,
  :enable_default_internet_access,
  :domain_join_info,
  :network_access_configuration,
  :image_builder_errors,
  :appstream_agent_version,
  :access_endpoints,
  :root_volume_config,
  :latest_appstream_agent_version,
  :disable_imdsv1)
  SENSITIVE = []
  include Aws::Structure
end

#disable_imdsv1Boolean

Indicates whether Instance Metadata Service Version 1 (IMDSv1) is disabled for the image builder.

Returns:

  • (Boolean)


4945
4946
4947
4948
4949
4950
4951
4952
4953
4954
4955
4956
4957
4958
4959
4960
4961
4962
4963
4964
4965
4966
4967
4968
4969
# File 'lib/aws-sdk-appstream/types.rb', line 4945

class ImageBuilder < Struct.new(
  :name,
  :arn,
  :image_arn,
  :description,
  :display_name,
  :vpc_config,
  :instance_type,
  :platform,
  :iam_role_arn,
  :state,
  :state_change_reason,
  :created_time,
  :enable_default_internet_access,
  :domain_join_info,
  :network_access_configuration,
  :image_builder_errors,
  :appstream_agent_version,
  :access_endpoints,
  :root_volume_config,
  :latest_appstream_agent_version,
  :disable_imdsv1)
  SENSITIVE = []
  include Aws::Structure
end

#display_nameString

The image builder name to display.

Returns:

  • (String)


4945
4946
4947
4948
4949
4950
4951
4952
4953
4954
4955
4956
4957
4958
4959
4960
4961
4962
4963
4964
4965
4966
4967
4968
4969
# File 'lib/aws-sdk-appstream/types.rb', line 4945

class ImageBuilder < Struct.new(
  :name,
  :arn,
  :image_arn,
  :description,
  :display_name,
  :vpc_config,
  :instance_type,
  :platform,
  :iam_role_arn,
  :state,
  :state_change_reason,
  :created_time,
  :enable_default_internet_access,
  :domain_join_info,
  :network_access_configuration,
  :image_builder_errors,
  :appstream_agent_version,
  :access_endpoints,
  :root_volume_config,
  :latest_appstream_agent_version,
  :disable_imdsv1)
  SENSITIVE = []
  include Aws::Structure
end

#domain_join_infoTypes::DomainJoinInfo

The name of the directory and organizational unit (OU) to use to join the image builder to a Microsoft Active Directory domain.



4945
4946
4947
4948
4949
4950
4951
4952
4953
4954
4955
4956
4957
4958
4959
4960
4961
4962
4963
4964
4965
4966
4967
4968
4969
# File 'lib/aws-sdk-appstream/types.rb', line 4945

class ImageBuilder < Struct.new(
  :name,
  :arn,
  :image_arn,
  :description,
  :display_name,
  :vpc_config,
  :instance_type,
  :platform,
  :iam_role_arn,
  :state,
  :state_change_reason,
  :created_time,
  :enable_default_internet_access,
  :domain_join_info,
  :network_access_configuration,
  :image_builder_errors,
  :appstream_agent_version,
  :access_endpoints,
  :root_volume_config,
  :latest_appstream_agent_version,
  :disable_imdsv1)
  SENSITIVE = []
  include Aws::Structure
end

#enable_default_internet_accessBoolean

Enables or disables default internet access for the image builder.

Returns:

  • (Boolean)


4945
4946
4947
4948
4949
4950
4951
4952
4953
4954
4955
4956
4957
4958
4959
4960
4961
4962
4963
4964
4965
4966
4967
4968
4969
# File 'lib/aws-sdk-appstream/types.rb', line 4945

class ImageBuilder < Struct.new(
  :name,
  :arn,
  :image_arn,
  :description,
  :display_name,
  :vpc_config,
  :instance_type,
  :platform,
  :iam_role_arn,
  :state,
  :state_change_reason,
  :created_time,
  :enable_default_internet_access,
  :domain_join_info,
  :network_access_configuration,
  :image_builder_errors,
  :appstream_agent_version,
  :access_endpoints,
  :root_volume_config,
  :latest_appstream_agent_version,
  :disable_imdsv1)
  SENSITIVE = []
  include Aws::Structure
end

#iam_role_arnString

The ARN of the IAM role that is applied to the image builder. To assume a role, the image builder calls the AWS Security Token Service (STS) AssumeRole API operation and passes the ARN of the role to use. The operation creates a new session with temporary credentials. WorkSpaces Applications retrieves the temporary credentials and creates the appstream_machine_role credential profile on the instance.

For more information, see [Using an IAM Role to Grant Permissions to Applications and Scripts Running on WorkSpaces Applications Streaming Instances] in the *Amazon WorkSpaces Applications Administration Guide*.

[1]: docs.aws.amazon.com/appstream2/latest/developerguide/using-iam-roles-to-grant-permissions-to-applications-scripts-streaming-instances.html

Returns:

  • (String)


4945
4946
4947
4948
4949
4950
4951
4952
4953
4954
4955
4956
4957
4958
4959
4960
4961
4962
4963
4964
4965
4966
4967
4968
4969
# File 'lib/aws-sdk-appstream/types.rb', line 4945

class ImageBuilder < Struct.new(
  :name,
  :arn,
  :image_arn,
  :description,
  :display_name,
  :vpc_config,
  :instance_type,
  :platform,
  :iam_role_arn,
  :state,
  :state_change_reason,
  :created_time,
  :enable_default_internet_access,
  :domain_join_info,
  :network_access_configuration,
  :image_builder_errors,
  :appstream_agent_version,
  :access_endpoints,
  :root_volume_config,
  :latest_appstream_agent_version,
  :disable_imdsv1)
  SENSITIVE = []
  include Aws::Structure
end

#image_arnString

The ARN of the image from which this builder was created.

Returns:

  • (String)


4945
4946
4947
4948
4949
4950
4951
4952
4953
4954
4955
4956
4957
4958
4959
4960
4961
4962
4963
4964
4965
4966
4967
4968
4969
# File 'lib/aws-sdk-appstream/types.rb', line 4945

class ImageBuilder < Struct.new(
  :name,
  :arn,
  :image_arn,
  :description,
  :display_name,
  :vpc_config,
  :instance_type,
  :platform,
  :iam_role_arn,
  :state,
  :state_change_reason,
  :created_time,
  :enable_default_internet_access,
  :domain_join_info,
  :network_access_configuration,
  :image_builder_errors,
  :appstream_agent_version,
  :access_endpoints,
  :root_volume_config,
  :latest_appstream_agent_version,
  :disable_imdsv1)
  SENSITIVE = []
  include Aws::Structure
end

#image_builder_errorsArray<Types::ResourceError>

The image builder errors.

Returns:



4945
4946
4947
4948
4949
4950
4951
4952
4953
4954
4955
4956
4957
4958
4959
4960
4961
4962
4963
4964
4965
4966
4967
4968
4969
# File 'lib/aws-sdk-appstream/types.rb', line 4945

class ImageBuilder < Struct.new(
  :name,
  :arn,
  :image_arn,
  :description,
  :display_name,
  :vpc_config,
  :instance_type,
  :platform,
  :iam_role_arn,
  :state,
  :state_change_reason,
  :created_time,
  :enable_default_internet_access,
  :domain_join_info,
  :network_access_configuration,
  :image_builder_errors,
  :appstream_agent_version,
  :access_endpoints,
  :root_volume_config,
  :latest_appstream_agent_version,
  :disable_imdsv1)
  SENSITIVE = []
  include Aws::Structure
end

#instance_typeString

The instance type for the image builder. The following instance types are available:

  • stream.standard.small

  • stream.standard.medium

  • stream.standard.large

  • stream.compute.large

  • stream.compute.xlarge

  • stream.compute.2xlarge

  • stream.compute.4xlarge

  • stream.compute.8xlarge

  • stream.memory.large

  • stream.memory.xlarge

  • stream.memory.2xlarge

  • stream.memory.4xlarge

  • stream.memory.8xlarge

  • stream.memory.z1d.large

  • stream.memory.z1d.xlarge

  • stream.memory.z1d.2xlarge

  • stream.memory.z1d.3xlarge

  • stream.memory.z1d.6xlarge

  • stream.memory.z1d.12xlarge

  • stream.graphics.g4dn.xlarge

  • stream.graphics.g4dn.2xlarge

  • stream.graphics.g4dn.4xlarge

  • stream.graphics.g4dn.8xlarge

  • stream.graphics.g4dn.12xlarge

  • stream.graphics.g4dn.16xlarge

  • stream.graphics.g5.xlarge

  • stream.graphics.g5.2xlarge

  • stream.graphics.g5.4xlarge

  • stream.graphics.g5.8xlarge

  • stream.graphics.g5.16xlarge

  • stream.graphics.g5.12xlarge

  • stream.graphics.g5.24xlarge

  • stream.graphics.g6.xlarge

  • stream.graphics.g6.2xlarge

  • stream.graphics.g6.4xlarge

  • stream.graphics.g6.8xlarge

  • stream.graphics.g6.16xlarge

  • stream.graphics.g6.12xlarge

  • stream.graphics.g6.24xlarge

  • stream.graphics.gr6.4xlarge

  • stream.graphics.gr6.8xlarge

  • stream.graphics.g6f.large

  • stream.graphics.g6f.xlarge

  • stream.graphics.g6f.2xlarge

  • stream.graphics.g6f.4xlarge

  • stream.graphics.gr6f.4xlarge

Returns:

  • (String)


4945
4946
4947
4948
4949
4950
4951
4952
4953
4954
4955
4956
4957
4958
4959
4960
4961
4962
4963
4964
4965
4966
4967
4968
4969
# File 'lib/aws-sdk-appstream/types.rb', line 4945

class ImageBuilder < Struct.new(
  :name,
  :arn,
  :image_arn,
  :description,
  :display_name,
  :vpc_config,
  :instance_type,
  :platform,
  :iam_role_arn,
  :state,
  :state_change_reason,
  :created_time,
  :enable_default_internet_access,
  :domain_join_info,
  :network_access_configuration,
  :image_builder_errors,
  :appstream_agent_version,
  :access_endpoints,
  :root_volume_config,
  :latest_appstream_agent_version,
  :disable_imdsv1)
  SENSITIVE = []
  include Aws::Structure
end

#latest_appstream_agent_versionString

Indicates whether the image builder is using the latest WorkSpaces Applications agent version or not.

Returns:

  • (String)


4945
4946
4947
4948
4949
4950
4951
4952
4953
4954
4955
4956
4957
4958
4959
4960
4961
4962
4963
4964
4965
4966
4967
4968
4969
# File 'lib/aws-sdk-appstream/types.rb', line 4945

class ImageBuilder < Struct.new(
  :name,
  :arn,
  :image_arn,
  :description,
  :display_name,
  :vpc_config,
  :instance_type,
  :platform,
  :iam_role_arn,
  :state,
  :state_change_reason,
  :created_time,
  :enable_default_internet_access,
  :domain_join_info,
  :network_access_configuration,
  :image_builder_errors,
  :appstream_agent_version,
  :access_endpoints,
  :root_volume_config,
  :latest_appstream_agent_version,
  :disable_imdsv1)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The name of the image builder.

Returns:

  • (String)


4945
4946
4947
4948
4949
4950
4951
4952
4953
4954
4955
4956
4957
4958
4959
4960
4961
4962
4963
4964
4965
4966
4967
4968
4969
# File 'lib/aws-sdk-appstream/types.rb', line 4945

class ImageBuilder < Struct.new(
  :name,
  :arn,
  :image_arn,
  :description,
  :display_name,
  :vpc_config,
  :instance_type,
  :platform,
  :iam_role_arn,
  :state,
  :state_change_reason,
  :created_time,
  :enable_default_internet_access,
  :domain_join_info,
  :network_access_configuration,
  :image_builder_errors,
  :appstream_agent_version,
  :access_endpoints,
  :root_volume_config,
  :latest_appstream_agent_version,
  :disable_imdsv1)
  SENSITIVE = []
  include Aws::Structure
end

#network_access_configurationTypes::NetworkAccessConfiguration

Describes the network details of the fleet or image builder instance.



4945
4946
4947
4948
4949
4950
4951
4952
4953
4954
4955
4956
4957
4958
4959
4960
4961
4962
4963
4964
4965
4966
4967
4968
4969
# File 'lib/aws-sdk-appstream/types.rb', line 4945

class ImageBuilder < Struct.new(
  :name,
  :arn,
  :image_arn,
  :description,
  :display_name,
  :vpc_config,
  :instance_type,
  :platform,
  :iam_role_arn,
  :state,
  :state_change_reason,
  :created_time,
  :enable_default_internet_access,
  :domain_join_info,
  :network_access_configuration,
  :image_builder_errors,
  :appstream_agent_version,
  :access_endpoints,
  :root_volume_config,
  :latest_appstream_agent_version,
  :disable_imdsv1)
  SENSITIVE = []
  include Aws::Structure
end

#platformString

The operating system platform of the image builder.

Returns:

  • (String)


4945
4946
4947
4948
4949
4950
4951
4952
4953
4954
4955
4956
4957
4958
4959
4960
4961
4962
4963
4964
4965
4966
4967
4968
4969
# File 'lib/aws-sdk-appstream/types.rb', line 4945

class ImageBuilder < Struct.new(
  :name,
  :arn,
  :image_arn,
  :description,
  :display_name,
  :vpc_config,
  :instance_type,
  :platform,
  :iam_role_arn,
  :state,
  :state_change_reason,
  :created_time,
  :enable_default_internet_access,
  :domain_join_info,
  :network_access_configuration,
  :image_builder_errors,
  :appstream_agent_version,
  :access_endpoints,
  :root_volume_config,
  :latest_appstream_agent_version,
  :disable_imdsv1)
  SENSITIVE = []
  include Aws::Structure
end

#root_volume_configTypes::VolumeConfig

The current configuration of the root volume for the image builder, including the storage size in GB.

Returns:



4945
4946
4947
4948
4949
4950
4951
4952
4953
4954
4955
4956
4957
4958
4959
4960
4961
4962
4963
4964
4965
4966
4967
4968
4969
# File 'lib/aws-sdk-appstream/types.rb', line 4945

class ImageBuilder < Struct.new(
  :name,
  :arn,
  :image_arn,
  :description,
  :display_name,
  :vpc_config,
  :instance_type,
  :platform,
  :iam_role_arn,
  :state,
  :state_change_reason,
  :created_time,
  :enable_default_internet_access,
  :domain_join_info,
  :network_access_configuration,
  :image_builder_errors,
  :appstream_agent_version,
  :access_endpoints,
  :root_volume_config,
  :latest_appstream_agent_version,
  :disable_imdsv1)
  SENSITIVE = []
  include Aws::Structure
end

#stateString

The state of the image builder.

Returns:

  • (String)


4945
4946
4947
4948
4949
4950
4951
4952
4953
4954
4955
4956
4957
4958
4959
4960
4961
4962
4963
4964
4965
4966
4967
4968
4969
# File 'lib/aws-sdk-appstream/types.rb', line 4945

class ImageBuilder < Struct.new(
  :name,
  :arn,
  :image_arn,
  :description,
  :display_name,
  :vpc_config,
  :instance_type,
  :platform,
  :iam_role_arn,
  :state,
  :state_change_reason,
  :created_time,
  :enable_default_internet_access,
  :domain_join_info,
  :network_access_configuration,
  :image_builder_errors,
  :appstream_agent_version,
  :access_endpoints,
  :root_volume_config,
  :latest_appstream_agent_version,
  :disable_imdsv1)
  SENSITIVE = []
  include Aws::Structure
end

#state_change_reasonTypes::ImageBuilderStateChangeReason

The reason why the last state change occurred.



4945
4946
4947
4948
4949
4950
4951
4952
4953
4954
4955
4956
4957
4958
4959
4960
4961
4962
4963
4964
4965
4966
4967
4968
4969
# File 'lib/aws-sdk-appstream/types.rb', line 4945

class ImageBuilder < Struct.new(
  :name,
  :arn,
  :image_arn,
  :description,
  :display_name,
  :vpc_config,
  :instance_type,
  :platform,
  :iam_role_arn,
  :state,
  :state_change_reason,
  :created_time,
  :enable_default_internet_access,
  :domain_join_info,
  :network_access_configuration,
  :image_builder_errors,
  :appstream_agent_version,
  :access_endpoints,
  :root_volume_config,
  :latest_appstream_agent_version,
  :disable_imdsv1)
  SENSITIVE = []
  include Aws::Structure
end

#vpc_configTypes::VpcConfig

The VPC configuration of the image builder.

Returns:



4945
4946
4947
4948
4949
4950
4951
4952
4953
4954
4955
4956
4957
4958
4959
4960
4961
4962
4963
4964
4965
4966
4967
4968
4969
# File 'lib/aws-sdk-appstream/types.rb', line 4945

class ImageBuilder < Struct.new(
  :name,
  :arn,
  :image_arn,
  :description,
  :display_name,
  :vpc_config,
  :instance_type,
  :platform,
  :iam_role_arn,
  :state,
  :state_change_reason,
  :created_time,
  :enable_default_internet_access,
  :domain_join_info,
  :network_access_configuration,
  :image_builder_errors,
  :appstream_agent_version,
  :access_endpoints,
  :root_volume_config,
  :latest_appstream_agent_version,
  :disable_imdsv1)
  SENSITIVE = []
  include Aws::Structure
end