Class: Aws::AppStream::Types::ListAssociatedFleetsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::AppStream::Types::ListAssociatedFleetsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-appstream/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#next_token ⇒ String
The pagination token to use to retrieve the next page of results for this operation.
-
#stack_name ⇒ String
The name of the stack.
Instance Attribute Details
#next_token ⇒ String
The pagination token to use to retrieve the next page of results for this operation. If this value is null, it retrieves the first page.
5133 5134 5135 5136 5137 5138 |
# File 'lib/aws-sdk-appstream/types.rb', line 5133 class ListAssociatedFleetsRequest < Struct.new( :stack_name, :next_token) SENSITIVE = [] include Aws::Structure end |
#stack_name ⇒ String
The name of the stack.
5133 5134 5135 5136 5137 5138 |
# File 'lib/aws-sdk-appstream/types.rb', line 5133 class ListAssociatedFleetsRequest < Struct.new( :stack_name, :next_token) SENSITIVE = [] include Aws::Structure end |