Class: Aws::AppStream::Types::ListAssociatedFleetsResult
- Inherits:
-
Struct
- Object
- Struct
- Aws::AppStream::Types::ListAssociatedFleetsResult
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-appstream/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#names ⇒ Array<String>
The name of the fleet.
-
#next_token ⇒ String
The pagination token to use to retrieve the next page of results for this operation.
Instance Attribute Details
#names ⇒ Array<String>
The name of the fleet.
5151 5152 5153 5154 5155 5156 |
# File 'lib/aws-sdk-appstream/types.rb', line 5151 class ListAssociatedFleetsResult < Struct.new( :names, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The pagination token to use to retrieve the next page of results for this operation. If there are no more pages, this value is null.
5151 5152 5153 5154 5155 5156 |
# File 'lib/aws-sdk-appstream/types.rb', line 5151 class ListAssociatedFleetsResult < Struct.new( :names, :next_token) SENSITIVE = [] include Aws::Structure end |