Class: Aws::AppStream::Types::ListAssociatedStacksRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::AppStream::Types::ListAssociatedStacksRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-appstream/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#fleet_name ⇒ String
The name of the fleet.
-
#next_token ⇒ String
The pagination token to use to retrieve the next page of results for this operation.
Instance Attribute Details
#fleet_name ⇒ String
The name of the fleet.
5169 5170 5171 5172 5173 5174 |
# File 'lib/aws-sdk-appstream/types.rb', line 5169 class ListAssociatedStacksRequest < Struct.new( :fleet_name, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The pagination token to use to retrieve the next page of results for this operation. If this value is null, it retrieves the first page.
5169 5170 5171 5172 5173 5174 |
# File 'lib/aws-sdk-appstream/types.rb', line 5169 class ListAssociatedStacksRequest < Struct.new( :fleet_name, :next_token) SENSITIVE = [] include Aws::Structure end |