Class: Aws::AppStream::Types::ListEntitledApplicationsResult
- Inherits:
-
Struct
- Object
- Struct
- Aws::AppStream::Types::ListEntitledApplicationsResult
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-appstream/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#entitled_applications ⇒ Array<Types::EntitledApplication>
The entitled applications.
-
#next_token ⇒ String
The pagination token used to retrieve the next page of results for this operation.
Instance Attribute Details
#entitled_applications ⇒ Array<Types::EntitledApplication>
The entitled applications.
5233 5234 5235 5236 5237 5238 |
# File 'lib/aws-sdk-appstream/types.rb', line 5233 class ListEntitledApplicationsResult < Struct.new( :entitled_applications, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The pagination token used to retrieve the next page of results for this operation.
5233 5234 5235 5236 5237 5238 |
# File 'lib/aws-sdk-appstream/types.rb', line 5233 class ListEntitledApplicationsResult < Struct.new( :entitled_applications, :next_token) SENSITIVE = [] include Aws::Structure end |