Class: Aws::AppStream::Types::ListExportImageTasksRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-appstream/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#filtersArray<Types::Filter>

Optional filters to apply when listing export image tasks. Filters help you narrow down the results based on specific criteria.

Returns:



5258
5259
5260
5261
5262
5263
5264
# File 'lib/aws-sdk-appstream/types.rb', line 5258

class ListExportImageTasksRequest < Struct.new(
  :filters,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#max_resultsInteger

The maximum number of export image tasks to return in a single request. The valid range is 1-500, with a default of 50.

Returns:



5258
5259
5260
5261
5262
5263
5264
# File 'lib/aws-sdk-appstream/types.rb', line 5258

class ListExportImageTasksRequest < Struct.new(
  :filters,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

The pagination token from a previous request. Use this to retrieve the next page of results when there are more tasks than the MaxResults limit.

Returns:



5258
5259
5260
5261
5262
5263
5264
# File 'lib/aws-sdk-appstream/types.rb', line 5258

class ListExportImageTasksRequest < Struct.new(
  :filters,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end