Class: Aws::AppStream::Types::ListExportImageTasksResult

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-appstream/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#export_image_tasksArray<Types::ExportImageTask>

The list of export image tasks that match the specified criteria.

Returns:



5277
5278
5279
5280
5281
5282
# File 'lib/aws-sdk-appstream/types.rb', line 5277

class ListExportImageTasksResult < Struct.new(
  :export_image_tasks,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

The pagination token to use for retrieving the next page of results. This field is only present when there are more results available.

Returns:

  • (String)


5277
5278
5279
5280
5281
5282
# File 'lib/aws-sdk-appstream/types.rb', line 5277

class ListExportImageTasksResult < Struct.new(
  :export_image_tasks,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end