Class: Aws::AppStream::Types::RuntimeValidationConfig

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-appstream/types.rb

Overview

Configuration for runtime validation of imported images. This structure specifies the instance type to use for testing the imported image’s streaming capabilities.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#intended_instance_typeString

The instance type to use for runtime validation testing. It’s recommended to use the same instance type you plan to use for your fleet to ensure accurate validation results.

Returns:

  • (String)


5459
5460
5461
5462
5463
# File 'lib/aws-sdk-appstream/types.rb', line 5459

class RuntimeValidationConfig < Struct.new(
  :intended_instance_type)
  SENSITIVE = []
  include Aws::Structure
end