Class: Aws::AppStream::Types::Session
- Inherits:
-
Struct
- Object
- Struct
- Aws::AppStream::Types::Session
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-appstream/types.rb
Overview
Describes a streaming session.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#authentication_type ⇒ String
The authentication method.
-
#connection_state ⇒ String
Specifies whether a user is connected to the streaming session.
-
#fleet_name ⇒ String
The name of the fleet for the streaming session.
-
#id ⇒ String
The identifier of the streaming session.
-
#instance_id ⇒ String
The identifier for the instance hosting the session.
-
#max_expiration_time ⇒ Time
The time when the streaming session is set to expire.
-
#network_access_configuration ⇒ Types::NetworkAccessConfiguration
The network details for the streaming session.
-
#stack_name ⇒ String
The name of the stack for the streaming session.
-
#start_time ⇒ Time
The time when a streaming instance is dedicated for the user.
-
#state ⇒ String
The current state of the streaming session.
-
#user_id ⇒ String
The identifier of the user for whom the session was created.
Instance Attribute Details
#authentication_type ⇒ String
The authentication method. The user is authenticated using a streaming URL (API) or SAML 2.0 federation (SAML).
5610 5611 5612 5613 5614 5615 5616 5617 5618 5619 5620 5621 5622 5623 5624 |
# File 'lib/aws-sdk-appstream/types.rb', line 5610 class Session < Struct.new( :id, :user_id, :stack_name, :fleet_name, :state, :connection_state, :start_time, :max_expiration_time, :authentication_type, :network_access_configuration, :instance_id) SENSITIVE = [] include Aws::Structure end |
#connection_state ⇒ String
Specifies whether a user is connected to the streaming session.
5610 5611 5612 5613 5614 5615 5616 5617 5618 5619 5620 5621 5622 5623 5624 |
# File 'lib/aws-sdk-appstream/types.rb', line 5610 class Session < Struct.new( :id, :user_id, :stack_name, :fleet_name, :state, :connection_state, :start_time, :max_expiration_time, :authentication_type, :network_access_configuration, :instance_id) SENSITIVE = [] include Aws::Structure end |
#fleet_name ⇒ String
The name of the fleet for the streaming session.
5610 5611 5612 5613 5614 5615 5616 5617 5618 5619 5620 5621 5622 5623 5624 |
# File 'lib/aws-sdk-appstream/types.rb', line 5610 class Session < Struct.new( :id, :user_id, :stack_name, :fleet_name, :state, :connection_state, :start_time, :max_expiration_time, :authentication_type, :network_access_configuration, :instance_id) SENSITIVE = [] include Aws::Structure end |
#id ⇒ String
The identifier of the streaming session.
5610 5611 5612 5613 5614 5615 5616 5617 5618 5619 5620 5621 5622 5623 5624 |
# File 'lib/aws-sdk-appstream/types.rb', line 5610 class Session < Struct.new( :id, :user_id, :stack_name, :fleet_name, :state, :connection_state, :start_time, :max_expiration_time, :authentication_type, :network_access_configuration, :instance_id) SENSITIVE = [] include Aws::Structure end |
#instance_id ⇒ String
The identifier for the instance hosting the session.
5610 5611 5612 5613 5614 5615 5616 5617 5618 5619 5620 5621 5622 5623 5624 |
# File 'lib/aws-sdk-appstream/types.rb', line 5610 class Session < Struct.new( :id, :user_id, :stack_name, :fleet_name, :state, :connection_state, :start_time, :max_expiration_time, :authentication_type, :network_access_configuration, :instance_id) SENSITIVE = [] include Aws::Structure end |
#max_expiration_time ⇒ Time
The time when the streaming session is set to expire. This time is based on the MaxUserDurationinSeconds value, which determines the maximum length of time that a streaming session can run. A streaming session might end earlier than the time specified in SessionMaxExpirationTime, when the DisconnectTimeOutInSeconds elapses or the user chooses to end his or her session. If the DisconnectTimeOutInSeconds elapses, or the user chooses to end his or her session, the streaming instance is terminated and the streaming session ends.
5610 5611 5612 5613 5614 5615 5616 5617 5618 5619 5620 5621 5622 5623 5624 |
# File 'lib/aws-sdk-appstream/types.rb', line 5610 class Session < Struct.new( :id, :user_id, :stack_name, :fleet_name, :state, :connection_state, :start_time, :max_expiration_time, :authentication_type, :network_access_configuration, :instance_id) SENSITIVE = [] include Aws::Structure end |
#network_access_configuration ⇒ Types::NetworkAccessConfiguration
The network details for the streaming session.
5610 5611 5612 5613 5614 5615 5616 5617 5618 5619 5620 5621 5622 5623 5624 |
# File 'lib/aws-sdk-appstream/types.rb', line 5610 class Session < Struct.new( :id, :user_id, :stack_name, :fleet_name, :state, :connection_state, :start_time, :max_expiration_time, :authentication_type, :network_access_configuration, :instance_id) SENSITIVE = [] include Aws::Structure end |
#stack_name ⇒ String
The name of the stack for the streaming session.
5610 5611 5612 5613 5614 5615 5616 5617 5618 5619 5620 5621 5622 5623 5624 |
# File 'lib/aws-sdk-appstream/types.rb', line 5610 class Session < Struct.new( :id, :user_id, :stack_name, :fleet_name, :state, :connection_state, :start_time, :max_expiration_time, :authentication_type, :network_access_configuration, :instance_id) SENSITIVE = [] include Aws::Structure end |
#start_time ⇒ Time
The time when a streaming instance is dedicated for the user.
5610 5611 5612 5613 5614 5615 5616 5617 5618 5619 5620 5621 5622 5623 5624 |
# File 'lib/aws-sdk-appstream/types.rb', line 5610 class Session < Struct.new( :id, :user_id, :stack_name, :fleet_name, :state, :connection_state, :start_time, :max_expiration_time, :authentication_type, :network_access_configuration, :instance_id) SENSITIVE = [] include Aws::Structure end |
#state ⇒ String
The current state of the streaming session.
5610 5611 5612 5613 5614 5615 5616 5617 5618 5619 5620 5621 5622 5623 5624 |
# File 'lib/aws-sdk-appstream/types.rb', line 5610 class Session < Struct.new( :id, :user_id, :stack_name, :fleet_name, :state, :connection_state, :start_time, :max_expiration_time, :authentication_type, :network_access_configuration, :instance_id) SENSITIVE = [] include Aws::Structure end |
#user_id ⇒ String
The identifier of the user for whom the session was created.
5610 5611 5612 5613 5614 5615 5616 5617 5618 5619 5620 5621 5622 5623 5624 |
# File 'lib/aws-sdk-appstream/types.rb', line 5610 class Session < Struct.new( :id, :user_id, :stack_name, :fleet_name, :state, :connection_state, :start_time, :max_expiration_time, :authentication_type, :network_access_configuration, :instance_id) SENSITIVE = [] include Aws::Structure end |