Class: Aws::AppStream::Types::Stack

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-appstream/types.rb

Overview

Describes a stack.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#access_endpointsArray<Types::AccessEndpoint>

The list of virtual private cloud (VPC) interface endpoint objects. Users of the stack can connect to WorkSpaces Applications only through the specified endpoints.

Returns:



5990
5991
5992
5993
5994
5995
5996
5997
5998
5999
6000
6001
6002
6003
6004
6005
6006
6007
6008
6009
# File 'lib/aws-sdk-appstream/types.rb', line 5990

class Stack < Struct.new(
  :arn,
  :name,
  :description,
  :display_name,
  :created_time,
  :storage_connectors,
  :redirect_url,
  :feedback_url,
  :stack_errors,
  :user_settings,
  :application_settings,
  :access_endpoints,
  :embed_host_domains,
  :streaming_experience_settings,
  :content_redirection,
  :agent_access_config)
  SENSITIVE = []
  include Aws::Structure
end

#agent_access_configTypes::AgentAccessConfig

The agent access configuration of the stack, if agent access is enabled.



5990
5991
5992
5993
5994
5995
5996
5997
5998
5999
6000
6001
6002
6003
6004
6005
6006
6007
6008
6009
# File 'lib/aws-sdk-appstream/types.rb', line 5990

class Stack < Struct.new(
  :arn,
  :name,
  :description,
  :display_name,
  :created_time,
  :storage_connectors,
  :redirect_url,
  :feedback_url,
  :stack_errors,
  :user_settings,
  :application_settings,
  :access_endpoints,
  :embed_host_domains,
  :streaming_experience_settings,
  :content_redirection,
  :agent_access_config)
  SENSITIVE = []
  include Aws::Structure
end

#application_settingsTypes::ApplicationSettingsResponse

The persistent application settings for users of the stack.



5990
5991
5992
5993
5994
5995
5996
5997
5998
5999
6000
6001
6002
6003
6004
6005
6006
6007
6008
6009
# File 'lib/aws-sdk-appstream/types.rb', line 5990

class Stack < Struct.new(
  :arn,
  :name,
  :description,
  :display_name,
  :created_time,
  :storage_connectors,
  :redirect_url,
  :feedback_url,
  :stack_errors,
  :user_settings,
  :application_settings,
  :access_endpoints,
  :embed_host_domains,
  :streaming_experience_settings,
  :content_redirection,
  :agent_access_config)
  SENSITIVE = []
  include Aws::Structure
end

#arnString

The ARN of the stack.

Returns:

  • (String)


5990
5991
5992
5993
5994
5995
5996
5997
5998
5999
6000
6001
6002
6003
6004
6005
6006
6007
6008
6009
# File 'lib/aws-sdk-appstream/types.rb', line 5990

class Stack < Struct.new(
  :arn,
  :name,
  :description,
  :display_name,
  :created_time,
  :storage_connectors,
  :redirect_url,
  :feedback_url,
  :stack_errors,
  :user_settings,
  :application_settings,
  :access_endpoints,
  :embed_host_domains,
  :streaming_experience_settings,
  :content_redirection,
  :agent_access_config)
  SENSITIVE = []
  include Aws::Structure
end

#content_redirectionTypes::ContentRedirection

Configuration for bidirectional URL redirection between the streaming session and the local client. Use HostToClient to redirect URLs from the remote desktop to the local browser.



5990
5991
5992
5993
5994
5995
5996
5997
5998
5999
6000
6001
6002
6003
6004
6005
6006
6007
6008
6009
# File 'lib/aws-sdk-appstream/types.rb', line 5990

class Stack < Struct.new(
  :arn,
  :name,
  :description,
  :display_name,
  :created_time,
  :storage_connectors,
  :redirect_url,
  :feedback_url,
  :stack_errors,
  :user_settings,
  :application_settings,
  :access_endpoints,
  :embed_host_domains,
  :streaming_experience_settings,
  :content_redirection,
  :agent_access_config)
  SENSITIVE = []
  include Aws::Structure
end

#created_timeTime

The time the stack was created.

Returns:

  • (Time)


5990
5991
5992
5993
5994
5995
5996
5997
5998
5999
6000
6001
6002
6003
6004
6005
6006
6007
6008
6009
# File 'lib/aws-sdk-appstream/types.rb', line 5990

class Stack < Struct.new(
  :arn,
  :name,
  :description,
  :display_name,
  :created_time,
  :storage_connectors,
  :redirect_url,
  :feedback_url,
  :stack_errors,
  :user_settings,
  :application_settings,
  :access_endpoints,
  :embed_host_domains,
  :streaming_experience_settings,
  :content_redirection,
  :agent_access_config)
  SENSITIVE = []
  include Aws::Structure
end

#descriptionString

The description to display.

Returns:

  • (String)


5990
5991
5992
5993
5994
5995
5996
5997
5998
5999
6000
6001
6002
6003
6004
6005
6006
6007
6008
6009
# File 'lib/aws-sdk-appstream/types.rb', line 5990

class Stack < Struct.new(
  :arn,
  :name,
  :description,
  :display_name,
  :created_time,
  :storage_connectors,
  :redirect_url,
  :feedback_url,
  :stack_errors,
  :user_settings,
  :application_settings,
  :access_endpoints,
  :embed_host_domains,
  :streaming_experience_settings,
  :content_redirection,
  :agent_access_config)
  SENSITIVE = []
  include Aws::Structure
end

#display_nameString

The stack name to display.

Returns:

  • (String)


5990
5991
5992
5993
5994
5995
5996
5997
5998
5999
6000
6001
6002
6003
6004
6005
6006
6007
6008
6009
# File 'lib/aws-sdk-appstream/types.rb', line 5990

class Stack < Struct.new(
  :arn,
  :name,
  :description,
  :display_name,
  :created_time,
  :storage_connectors,
  :redirect_url,
  :feedback_url,
  :stack_errors,
  :user_settings,
  :application_settings,
  :access_endpoints,
  :embed_host_domains,
  :streaming_experience_settings,
  :content_redirection,
  :agent_access_config)
  SENSITIVE = []
  include Aws::Structure
end

#embed_host_domainsArray<String>

The domains where WorkSpaces Applications streaming sessions can be embedded in an iframe. You must approve the domains that you want to host embedded WorkSpaces Applications streaming sessions.

Returns:

  • (Array<String>)


5990
5991
5992
5993
5994
5995
5996
5997
5998
5999
6000
6001
6002
6003
6004
6005
6006
6007
6008
6009
# File 'lib/aws-sdk-appstream/types.rb', line 5990

class Stack < Struct.new(
  :arn,
  :name,
  :description,
  :display_name,
  :created_time,
  :storage_connectors,
  :redirect_url,
  :feedback_url,
  :stack_errors,
  :user_settings,
  :application_settings,
  :access_endpoints,
  :embed_host_domains,
  :streaming_experience_settings,
  :content_redirection,
  :agent_access_config)
  SENSITIVE = []
  include Aws::Structure
end

#feedback_urlString

The URL that users are redirected to after they click the Send Feedback link. If no URL is specified, no Send Feedback link is displayed.

Returns:

  • (String)


5990
5991
5992
5993
5994
5995
5996
5997
5998
5999
6000
6001
6002
6003
6004
6005
6006
6007
6008
6009
# File 'lib/aws-sdk-appstream/types.rb', line 5990

class Stack < Struct.new(
  :arn,
  :name,
  :description,
  :display_name,
  :created_time,
  :storage_connectors,
  :redirect_url,
  :feedback_url,
  :stack_errors,
  :user_settings,
  :application_settings,
  :access_endpoints,
  :embed_host_domains,
  :streaming_experience_settings,
  :content_redirection,
  :agent_access_config)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The name of the stack.

Returns:

  • (String)


5990
5991
5992
5993
5994
5995
5996
5997
5998
5999
6000
6001
6002
6003
6004
6005
6006
6007
6008
6009
# File 'lib/aws-sdk-appstream/types.rb', line 5990

class Stack < Struct.new(
  :arn,
  :name,
  :description,
  :display_name,
  :created_time,
  :storage_connectors,
  :redirect_url,
  :feedback_url,
  :stack_errors,
  :user_settings,
  :application_settings,
  :access_endpoints,
  :embed_host_domains,
  :streaming_experience_settings,
  :content_redirection,
  :agent_access_config)
  SENSITIVE = []
  include Aws::Structure
end

#redirect_urlString

The URL that users are redirected to after their streaming session ends.

Returns:

  • (String)


5990
5991
5992
5993
5994
5995
5996
5997
5998
5999
6000
6001
6002
6003
6004
6005
6006
6007
6008
6009
# File 'lib/aws-sdk-appstream/types.rb', line 5990

class Stack < Struct.new(
  :arn,
  :name,
  :description,
  :display_name,
  :created_time,
  :storage_connectors,
  :redirect_url,
  :feedback_url,
  :stack_errors,
  :user_settings,
  :application_settings,
  :access_endpoints,
  :embed_host_domains,
  :streaming_experience_settings,
  :content_redirection,
  :agent_access_config)
  SENSITIVE = []
  include Aws::Structure
end

#stack_errorsArray<Types::StackError>

The errors for the stack.

Returns:



5990
5991
5992
5993
5994
5995
5996
5997
5998
5999
6000
6001
6002
6003
6004
6005
6006
6007
6008
6009
# File 'lib/aws-sdk-appstream/types.rb', line 5990

class Stack < Struct.new(
  :arn,
  :name,
  :description,
  :display_name,
  :created_time,
  :storage_connectors,
  :redirect_url,
  :feedback_url,
  :stack_errors,
  :user_settings,
  :application_settings,
  :access_endpoints,
  :embed_host_domains,
  :streaming_experience_settings,
  :content_redirection,
  :agent_access_config)
  SENSITIVE = []
  include Aws::Structure
end

#storage_connectorsArray<Types::StorageConnector>

The storage connectors to enable.

Returns:



5990
5991
5992
5993
5994
5995
5996
5997
5998
5999
6000
6001
6002
6003
6004
6005
6006
6007
6008
6009
# File 'lib/aws-sdk-appstream/types.rb', line 5990

class Stack < Struct.new(
  :arn,
  :name,
  :description,
  :display_name,
  :created_time,
  :storage_connectors,
  :redirect_url,
  :feedback_url,
  :stack_errors,
  :user_settings,
  :application_settings,
  :access_endpoints,
  :embed_host_domains,
  :streaming_experience_settings,
  :content_redirection,
  :agent_access_config)
  SENSITIVE = []
  include Aws::Structure
end

#streaming_experience_settingsTypes::StreamingExperienceSettings

The streaming protocol you want your stack to prefer. This can be UDP or TCP. Currently, UDP is only supported in the Windows native client.



5990
5991
5992
5993
5994
5995
5996
5997
5998
5999
6000
6001
6002
6003
6004
6005
6006
6007
6008
6009
# File 'lib/aws-sdk-appstream/types.rb', line 5990

class Stack < Struct.new(
  :arn,
  :name,
  :description,
  :display_name,
  :created_time,
  :storage_connectors,
  :redirect_url,
  :feedback_url,
  :stack_errors,
  :user_settings,
  :application_settings,
  :access_endpoints,
  :embed_host_domains,
  :streaming_experience_settings,
  :content_redirection,
  :agent_access_config)
  SENSITIVE = []
  include Aws::Structure
end

#user_settingsArray<Types::UserSetting>

The actions that are enabled or disabled for users during their streaming sessions. By default these actions are enabled.

Returns:



5990
5991
5992
5993
5994
5995
5996
5997
5998
5999
6000
6001
6002
6003
6004
6005
6006
6007
6008
6009
# File 'lib/aws-sdk-appstream/types.rb', line 5990

class Stack < Struct.new(
  :arn,
  :name,
  :description,
  :display_name,
  :created_time,
  :storage_connectors,
  :redirect_url,
  :feedback_url,
  :stack_errors,
  :user_settings,
  :application_settings,
  :access_endpoints,
  :embed_host_domains,
  :streaming_experience_settings,
  :content_redirection,
  :agent_access_config)
  SENSITIVE = []
  include Aws::Structure
end