Class: Aws::AppStream::Types::StartImageBuilderRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::AppStream::Types::StartImageBuilderRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-appstream/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#appstream_agent_version ⇒ String
The version of the WorkSpaces Applications agent to use for this image builder.
-
#name ⇒ String
The name of the image builder.
Instance Attribute Details
#appstream_agent_version ⇒ String
The version of the WorkSpaces Applications agent to use for this image builder. To use the latest version of the WorkSpaces Applications agent, specify [LATEST].
6067 6068 6069 6070 6071 6072 |
# File 'lib/aws-sdk-appstream/types.rb', line 6067 class StartImageBuilderRequest < Struct.new( :name, :appstream_agent_version) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the image builder.
6067 6068 6069 6070 6071 6072 |
# File 'lib/aws-sdk-appstream/types.rb', line 6067 class StartImageBuilderRequest < Struct.new( :name, :appstream_agent_version) SENSITIVE = [] include Aws::Structure end |