Class: Aws::AppStream::Types::UpdateApplicationRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::AppStream::Types::UpdateApplicationRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-appstream/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#app_block_arn ⇒ String
The ARN of the app block.
-
#attributes_to_delete ⇒ Array<String>
The attributes to delete for an application.
-
#description ⇒ String
The description of the application.
-
#display_name ⇒ String
The display name of the application.
-
#icon_s3_location ⇒ Types::S3Location
The icon S3 location of the application.
-
#launch_parameters ⇒ String
The launch parameters of the application.
-
#launch_path ⇒ String
The launch path of the application.
-
#name ⇒ String
The name of the application.
-
#working_directory ⇒ String
The working directory of the application.
Instance Attribute Details
#app_block_arn ⇒ String
The ARN of the app block.
6491 6492 6493 6494 6495 6496 6497 6498 6499 6500 6501 6502 6503 |
# File 'lib/aws-sdk-appstream/types.rb', line 6491 class UpdateApplicationRequest < Struct.new( :name, :display_name, :description, :icon_s3_location, :launch_path, :working_directory, :launch_parameters, :app_block_arn, :attributes_to_delete) SENSITIVE = [] include Aws::Structure end |
#attributes_to_delete ⇒ Array<String>
The attributes to delete for an application.
6491 6492 6493 6494 6495 6496 6497 6498 6499 6500 6501 6502 6503 |
# File 'lib/aws-sdk-appstream/types.rb', line 6491 class UpdateApplicationRequest < Struct.new( :name, :display_name, :description, :icon_s3_location, :launch_path, :working_directory, :launch_parameters, :app_block_arn, :attributes_to_delete) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
The description of the application.
6491 6492 6493 6494 6495 6496 6497 6498 6499 6500 6501 6502 6503 |
# File 'lib/aws-sdk-appstream/types.rb', line 6491 class UpdateApplicationRequest < Struct.new( :name, :display_name, :description, :icon_s3_location, :launch_path, :working_directory, :launch_parameters, :app_block_arn, :attributes_to_delete) SENSITIVE = [] include Aws::Structure end |
#display_name ⇒ String
The display name of the application. This name is visible to users in the application catalog.
6491 6492 6493 6494 6495 6496 6497 6498 6499 6500 6501 6502 6503 |
# File 'lib/aws-sdk-appstream/types.rb', line 6491 class UpdateApplicationRequest < Struct.new( :name, :display_name, :description, :icon_s3_location, :launch_path, :working_directory, :launch_parameters, :app_block_arn, :attributes_to_delete) SENSITIVE = [] include Aws::Structure end |
#icon_s3_location ⇒ Types::S3Location
The icon S3 location of the application.
6491 6492 6493 6494 6495 6496 6497 6498 6499 6500 6501 6502 6503 |
# File 'lib/aws-sdk-appstream/types.rb', line 6491 class UpdateApplicationRequest < Struct.new( :name, :display_name, :description, :icon_s3_location, :launch_path, :working_directory, :launch_parameters, :app_block_arn, :attributes_to_delete) SENSITIVE = [] include Aws::Structure end |
#launch_parameters ⇒ String
The launch parameters of the application.
6491 6492 6493 6494 6495 6496 6497 6498 6499 6500 6501 6502 6503 |
# File 'lib/aws-sdk-appstream/types.rb', line 6491 class UpdateApplicationRequest < Struct.new( :name, :display_name, :description, :icon_s3_location, :launch_path, :working_directory, :launch_parameters, :app_block_arn, :attributes_to_delete) SENSITIVE = [] include Aws::Structure end |
#launch_path ⇒ String
The launch path of the application.
6491 6492 6493 6494 6495 6496 6497 6498 6499 6500 6501 6502 6503 |
# File 'lib/aws-sdk-appstream/types.rb', line 6491 class UpdateApplicationRequest < Struct.new( :name, :display_name, :description, :icon_s3_location, :launch_path, :working_directory, :launch_parameters, :app_block_arn, :attributes_to_delete) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the application. This name is visible to users when display name is not specified.
6491 6492 6493 6494 6495 6496 6497 6498 6499 6500 6501 6502 6503 |
# File 'lib/aws-sdk-appstream/types.rb', line 6491 class UpdateApplicationRequest < Struct.new( :name, :display_name, :description, :icon_s3_location, :launch_path, :working_directory, :launch_parameters, :app_block_arn, :attributes_to_delete) SENSITIVE = [] include Aws::Structure end |
#working_directory ⇒ String
The working directory of the application.
6491 6492 6493 6494 6495 6496 6497 6498 6499 6500 6501 6502 6503 |
# File 'lib/aws-sdk-appstream/types.rb', line 6491 class UpdateApplicationRequest < Struct.new( :name, :display_name, :description, :icon_s3_location, :launch_path, :working_directory, :launch_parameters, :app_block_arn, :attributes_to_delete) SENSITIVE = [] include Aws::Structure end |