Class: Aws::AppStream::Types::UpdateEntitlementRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-appstream/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#app_visibilityString

Specifies whether all or only selected apps are entitled.

Returns:

  • (String)


6604
6605
6606
6607
6608
6609
6610
6611
6612
# File 'lib/aws-sdk-appstream/types.rb', line 6604

class UpdateEntitlementRequest < Struct.new(
  :name,
  :stack_name,
  :description,
  :app_visibility,
  :attributes)
  SENSITIVE = []
  include Aws::Structure
end

#attributesArray<Types::EntitlementAttribute>

The attributes of the entitlement.

Returns:



6604
6605
6606
6607
6608
6609
6610
6611
6612
# File 'lib/aws-sdk-appstream/types.rb', line 6604

class UpdateEntitlementRequest < Struct.new(
  :name,
  :stack_name,
  :description,
  :app_visibility,
  :attributes)
  SENSITIVE = []
  include Aws::Structure
end

#descriptionString

The description of the entitlement.

Returns:

  • (String)


6604
6605
6606
6607
6608
6609
6610
6611
6612
# File 'lib/aws-sdk-appstream/types.rb', line 6604

class UpdateEntitlementRequest < Struct.new(
  :name,
  :stack_name,
  :description,
  :app_visibility,
  :attributes)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The name of the entitlement.

Returns:

  • (String)


6604
6605
6606
6607
6608
6609
6610
6611
6612
# File 'lib/aws-sdk-appstream/types.rb', line 6604

class UpdateEntitlementRequest < Struct.new(
  :name,
  :stack_name,
  :description,
  :app_visibility,
  :attributes)
  SENSITIVE = []
  include Aws::Structure
end

#stack_nameString

The name of the stack with which the entitlement is associated.

Returns:

  • (String)


6604
6605
6606
6607
6608
6609
6610
6611
6612
# File 'lib/aws-sdk-appstream/types.rb', line 6604

class UpdateEntitlementRequest < Struct.new(
  :name,
  :stack_name,
  :description,
  :app_visibility,
  :attributes)
  SENSITIVE = []
  include Aws::Structure
end