Class: Aws::AppStream::Types::UpdateStackRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-appstream/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#access_endpointsArray<Types::AccessEndpoint>

The list of interface VPC endpoint (interface endpoint) objects. Users of the stack can connect to WorkSpaces Applications only through the specified endpoints.

Returns:



7044
7045
7046
7047
7048
7049
7050
7051
7052
7053
7054
7055
7056
7057
7058
7059
7060
7061
7062
# File 'lib/aws-sdk-appstream/types.rb', line 7044

class UpdateStackRequest < Struct.new(
  :display_name,
  :description,
  :name,
  :storage_connectors,
  :delete_storage_connectors,
  :redirect_url,
  :feedback_url,
  :attributes_to_delete,
  :user_settings,
  :application_settings,
  :access_endpoints,
  :embed_host_domains,
  :streaming_experience_settings,
  :content_redirection,
  :agent_access_config)
  SENSITIVE = []
  include Aws::Structure
end

#agent_access_configTypes::AgentAccessConfigForUpdate

The configuration for agent access on the stack. Specify this to update agent access settings. To remove agent access, use AttributesToDelete with the AGENT_ACCESS_CONFIG value.



7044
7045
7046
7047
7048
7049
7050
7051
7052
7053
7054
7055
7056
7057
7058
7059
7060
7061
7062
# File 'lib/aws-sdk-appstream/types.rb', line 7044

class UpdateStackRequest < Struct.new(
  :display_name,
  :description,
  :name,
  :storage_connectors,
  :delete_storage_connectors,
  :redirect_url,
  :feedback_url,
  :attributes_to_delete,
  :user_settings,
  :application_settings,
  :access_endpoints,
  :embed_host_domains,
  :streaming_experience_settings,
  :content_redirection,
  :agent_access_config)
  SENSITIVE = []
  include Aws::Structure
end

#application_settingsTypes::ApplicationSettings

The persistent application settings for users of a stack. When these settings are enabled, changes that users make to applications and Windows settings are automatically saved after each session and applied to the next session.



7044
7045
7046
7047
7048
7049
7050
7051
7052
7053
7054
7055
7056
7057
7058
7059
7060
7061
7062
# File 'lib/aws-sdk-appstream/types.rb', line 7044

class UpdateStackRequest < Struct.new(
  :display_name,
  :description,
  :name,
  :storage_connectors,
  :delete_storage_connectors,
  :redirect_url,
  :feedback_url,
  :attributes_to_delete,
  :user_settings,
  :application_settings,
  :access_endpoints,
  :embed_host_domains,
  :streaming_experience_settings,
  :content_redirection,
  :agent_access_config)
  SENSITIVE = []
  include Aws::Structure
end

#attributes_to_deleteArray<String>

The stack attributes to delete.

Returns:

  • (Array<String>)


7044
7045
7046
7047
7048
7049
7050
7051
7052
7053
7054
7055
7056
7057
7058
7059
7060
7061
7062
# File 'lib/aws-sdk-appstream/types.rb', line 7044

class UpdateStackRequest < Struct.new(
  :display_name,
  :description,
  :name,
  :storage_connectors,
  :delete_storage_connectors,
  :redirect_url,
  :feedback_url,
  :attributes_to_delete,
  :user_settings,
  :application_settings,
  :access_endpoints,
  :embed_host_domains,
  :streaming_experience_settings,
  :content_redirection,
  :agent_access_config)
  SENSITIVE = []
  include Aws::Structure
end

#content_redirectionTypes::ContentRedirection

Configuration for bidirectional URL redirection between the streaming session and the local client. Use HostToClient to redirect URLs from the remote desktop to the local browser.



7044
7045
7046
7047
7048
7049
7050
7051
7052
7053
7054
7055
7056
7057
7058
7059
7060
7061
7062
# File 'lib/aws-sdk-appstream/types.rb', line 7044

class UpdateStackRequest < Struct.new(
  :display_name,
  :description,
  :name,
  :storage_connectors,
  :delete_storage_connectors,
  :redirect_url,
  :feedback_url,
  :attributes_to_delete,
  :user_settings,
  :application_settings,
  :access_endpoints,
  :embed_host_domains,
  :streaming_experience_settings,
  :content_redirection,
  :agent_access_config)
  SENSITIVE = []
  include Aws::Structure
end

#delete_storage_connectorsBoolean

Deletes the storage connectors currently enabled for the stack.

Returns:

  • (Boolean)


7044
7045
7046
7047
7048
7049
7050
7051
7052
7053
7054
7055
7056
7057
7058
7059
7060
7061
7062
# File 'lib/aws-sdk-appstream/types.rb', line 7044

class UpdateStackRequest < Struct.new(
  :display_name,
  :description,
  :name,
  :storage_connectors,
  :delete_storage_connectors,
  :redirect_url,
  :feedback_url,
  :attributes_to_delete,
  :user_settings,
  :application_settings,
  :access_endpoints,
  :embed_host_domains,
  :streaming_experience_settings,
  :content_redirection,
  :agent_access_config)
  SENSITIVE = []
  include Aws::Structure
end

#descriptionString

The description to display.

Returns:

  • (String)


7044
7045
7046
7047
7048
7049
7050
7051
7052
7053
7054
7055
7056
7057
7058
7059
7060
7061
7062
# File 'lib/aws-sdk-appstream/types.rb', line 7044

class UpdateStackRequest < Struct.new(
  :display_name,
  :description,
  :name,
  :storage_connectors,
  :delete_storage_connectors,
  :redirect_url,
  :feedback_url,
  :attributes_to_delete,
  :user_settings,
  :application_settings,
  :access_endpoints,
  :embed_host_domains,
  :streaming_experience_settings,
  :content_redirection,
  :agent_access_config)
  SENSITIVE = []
  include Aws::Structure
end

#display_nameString

The stack name to display.

Returns:

  • (String)


7044
7045
7046
7047
7048
7049
7050
7051
7052
7053
7054
7055
7056
7057
7058
7059
7060
7061
7062
# File 'lib/aws-sdk-appstream/types.rb', line 7044

class UpdateStackRequest < Struct.new(
  :display_name,
  :description,
  :name,
  :storage_connectors,
  :delete_storage_connectors,
  :redirect_url,
  :feedback_url,
  :attributes_to_delete,
  :user_settings,
  :application_settings,
  :access_endpoints,
  :embed_host_domains,
  :streaming_experience_settings,
  :content_redirection,
  :agent_access_config)
  SENSITIVE = []
  include Aws::Structure
end

#embed_host_domainsArray<String>

The domains where WorkSpaces Applications streaming sessions can be embedded in an iframe. You must approve the domains that you want to host embedded WorkSpaces Applications streaming sessions.

Returns:

  • (Array<String>)


7044
7045
7046
7047
7048
7049
7050
7051
7052
7053
7054
7055
7056
7057
7058
7059
7060
7061
7062
# File 'lib/aws-sdk-appstream/types.rb', line 7044

class UpdateStackRequest < Struct.new(
  :display_name,
  :description,
  :name,
  :storage_connectors,
  :delete_storage_connectors,
  :redirect_url,
  :feedback_url,
  :attributes_to_delete,
  :user_settings,
  :application_settings,
  :access_endpoints,
  :embed_host_domains,
  :streaming_experience_settings,
  :content_redirection,
  :agent_access_config)
  SENSITIVE = []
  include Aws::Structure
end

#feedback_urlString

The URL that users are redirected to after they choose the Send Feedback link. If no URL is specified, no Send Feedback link is displayed.

Returns:

  • (String)


7044
7045
7046
7047
7048
7049
7050
7051
7052
7053
7054
7055
7056
7057
7058
7059
7060
7061
7062
# File 'lib/aws-sdk-appstream/types.rb', line 7044

class UpdateStackRequest < Struct.new(
  :display_name,
  :description,
  :name,
  :storage_connectors,
  :delete_storage_connectors,
  :redirect_url,
  :feedback_url,
  :attributes_to_delete,
  :user_settings,
  :application_settings,
  :access_endpoints,
  :embed_host_domains,
  :streaming_experience_settings,
  :content_redirection,
  :agent_access_config)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The name of the stack.

Returns:

  • (String)


7044
7045
7046
7047
7048
7049
7050
7051
7052
7053
7054
7055
7056
7057
7058
7059
7060
7061
7062
# File 'lib/aws-sdk-appstream/types.rb', line 7044

class UpdateStackRequest < Struct.new(
  :display_name,
  :description,
  :name,
  :storage_connectors,
  :delete_storage_connectors,
  :redirect_url,
  :feedback_url,
  :attributes_to_delete,
  :user_settings,
  :application_settings,
  :access_endpoints,
  :embed_host_domains,
  :streaming_experience_settings,
  :content_redirection,
  :agent_access_config)
  SENSITIVE = []
  include Aws::Structure
end

#redirect_urlString

The URL that users are redirected to after their streaming session ends.

Returns:

  • (String)


7044
7045
7046
7047
7048
7049
7050
7051
7052
7053
7054
7055
7056
7057
7058
7059
7060
7061
7062
# File 'lib/aws-sdk-appstream/types.rb', line 7044

class UpdateStackRequest < Struct.new(
  :display_name,
  :description,
  :name,
  :storage_connectors,
  :delete_storage_connectors,
  :redirect_url,
  :feedback_url,
  :attributes_to_delete,
  :user_settings,
  :application_settings,
  :access_endpoints,
  :embed_host_domains,
  :streaming_experience_settings,
  :content_redirection,
  :agent_access_config)
  SENSITIVE = []
  include Aws::Structure
end

#storage_connectorsArray<Types::StorageConnector>

The storage connectors to enable.

Returns:



7044
7045
7046
7047
7048
7049
7050
7051
7052
7053
7054
7055
7056
7057
7058
7059
7060
7061
7062
# File 'lib/aws-sdk-appstream/types.rb', line 7044

class UpdateStackRequest < Struct.new(
  :display_name,
  :description,
  :name,
  :storage_connectors,
  :delete_storage_connectors,
  :redirect_url,
  :feedback_url,
  :attributes_to_delete,
  :user_settings,
  :application_settings,
  :access_endpoints,
  :embed_host_domains,
  :streaming_experience_settings,
  :content_redirection,
  :agent_access_config)
  SENSITIVE = []
  include Aws::Structure
end

#streaming_experience_settingsTypes::StreamingExperienceSettings

The streaming protocol you want your stack to prefer. This can be UDP or TCP. Currently, UDP is only supported in the Windows native client.



7044
7045
7046
7047
7048
7049
7050
7051
7052
7053
7054
7055
7056
7057
7058
7059
7060
7061
7062
# File 'lib/aws-sdk-appstream/types.rb', line 7044

class UpdateStackRequest < Struct.new(
  :display_name,
  :description,
  :name,
  :storage_connectors,
  :delete_storage_connectors,
  :redirect_url,
  :feedback_url,
  :attributes_to_delete,
  :user_settings,
  :application_settings,
  :access_endpoints,
  :embed_host_domains,
  :streaming_experience_settings,
  :content_redirection,
  :agent_access_config)
  SENSITIVE = []
  include Aws::Structure
end

#user_settingsArray<Types::UserSetting>

The actions that are enabled or disabled for users during their streaming sessions. By default, these actions are enabled.

Returns:



7044
7045
7046
7047
7048
7049
7050
7051
7052
7053
7054
7055
7056
7057
7058
7059
7060
7061
7062
# File 'lib/aws-sdk-appstream/types.rb', line 7044

class UpdateStackRequest < Struct.new(
  :display_name,
  :description,
  :name,
  :storage_connectors,
  :delete_storage_connectors,
  :redirect_url,
  :feedback_url,
  :attributes_to_delete,
  :user_settings,
  :application_settings,
  :access_endpoints,
  :embed_host_domains,
  :streaming_experience_settings,
  :content_redirection,
  :agent_access_config)
  SENSITIVE = []
  include Aws::Structure
end