Class: Aws::AppStream::Types::UsageReportSubscription
- Inherits:
-
Struct
- Object
- Struct
- Aws::AppStream::Types::UsageReportSubscription
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-appstream/types.rb
Overview
Describes information about the usage report subscription.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#last_generated_report_date ⇒ Time
The time when the last usage report was generated.
-
#s3_bucket_name ⇒ String
The Amazon S3 bucket where generated reports are stored.
-
#schedule ⇒ String
The schedule for generating usage reports.
-
#subscription_errors ⇒ Array<Types::LastReportGenerationExecutionError>
The errors that were returned if usage reports couldn’t be generated.
Instance Attribute Details
#last_generated_report_date ⇒ Time
The time when the last usage report was generated.
6977 6978 6979 6980 6981 6982 6983 6984 |
# File 'lib/aws-sdk-appstream/types.rb', line 6977 class UsageReportSubscription < Struct.new( :s3_bucket_name, :schedule, :last_generated_report_date, :subscription_errors) SENSITIVE = [] include Aws::Structure end |
#s3_bucket_name ⇒ String
The Amazon S3 bucket where generated reports are stored.
If you enabled on-instance session scripts and Amazon S3 logging for your session script configuration, WorkSpaces Applications created an S3 bucket to store the script output. The bucket is unique to your account and Region. When you enable usage reporting in this case, WorkSpaces Applications uses the same bucket to store your usage reports. If you haven’t already enabled on-instance session scripts, when you enable usage reports, WorkSpaces Applications creates a new S3 bucket.
6977 6978 6979 6980 6981 6982 6983 6984 |
# File 'lib/aws-sdk-appstream/types.rb', line 6977 class UsageReportSubscription < Struct.new( :s3_bucket_name, :schedule, :last_generated_report_date, :subscription_errors) SENSITIVE = [] include Aws::Structure end |
#schedule ⇒ String
The schedule for generating usage reports.
6977 6978 6979 6980 6981 6982 6983 6984 |
# File 'lib/aws-sdk-appstream/types.rb', line 6977 class UsageReportSubscription < Struct.new( :s3_bucket_name, :schedule, :last_generated_report_date, :subscription_errors) SENSITIVE = [] include Aws::Structure end |
#subscription_errors ⇒ Array<Types::LastReportGenerationExecutionError>
The errors that were returned if usage reports couldn’t be generated.
6977 6978 6979 6980 6981 6982 6983 6984 |
# File 'lib/aws-sdk-appstream/types.rb', line 6977 class UsageReportSubscription < Struct.new( :s3_bucket_name, :schedule, :last_generated_report_date, :subscription_errors) SENSITIVE = [] include Aws::Structure end |