Class: Aws::AppStream::Types::VpcConfig
- Inherits:
-
Struct
- Object
- Struct
- Aws::AppStream::Types::VpcConfig
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-appstream/types.rb
Overview
Describes VPC configuration information for fleets and image builders.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#security_group_ids ⇒ Array<String>
The identifiers of the security groups for the fleet or image builder.
-
#subnet_ids ⇒ Array<String>
The identifiers of the subnets to which a network interface is attached from the fleet instance or image builder instance.
Instance Attribute Details
#security_group_ids ⇒ Array<String>
The identifiers of the security groups for the fleet or image builder.
7184 7185 7186 7187 7188 7189 |
# File 'lib/aws-sdk-appstream/types.rb', line 7184 class VpcConfig < Struct.new( :subnet_ids, :security_group_ids) SENSITIVE = [] include Aws::Structure end |
#subnet_ids ⇒ Array<String>
The identifiers of the subnets to which a network interface is attached from the fleet instance or image builder instance. Fleet instances use one or more subnets. Image builder instances use one subnet.
7184 7185 7186 7187 7188 7189 |
# File 'lib/aws-sdk-appstream/types.rb', line 7184 class VpcConfig < Struct.new( :subnet_ids, :security_group_ids) SENSITIVE = [] include Aws::Structure end |