Class: Aws::AppStream::Types::AgentAccessConfig
- Inherits:
-
Struct
- Object
- Struct
- Aws::AppStream::Types::AgentAccessConfig
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-appstream/types.rb
Overview
The configuration for agent access on a stack. Agent access enables AI agents to interact with desktop applications during streaming sessions.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#s3_bucket_arn ⇒ String
The Amazon Resource Name (ARN) of the Amazon S3 bucket where agent screenshots are stored.
-
#screen_image_format ⇒ String
The image format for agent screen captures.
-
#screen_resolution ⇒ String
The screen resolution for the agent streaming environment.
-
#screenshots_upload_enabled ⇒ Boolean
Indicates whether screenshot uploads to Amazon S3 are enabled for agent sessions.
-
#settings ⇒ Array<Types::AgentAccessSetting>
The list of agent access settings that define permissions for each agent action.
-
#user_control_mode ⇒ String
The user control mode for agent sessions.
Instance Attribute Details
#s3_bucket_arn ⇒ String
The Amazon Resource Name (ARN) of the Amazon S3 bucket where agent screenshots are stored. Required when ScreenshotsUploadEnabled is true.
118 119 120 121 122 123 124 125 126 127 |
# File 'lib/aws-sdk-appstream/types.rb', line 118 class AgentAccessConfig < Struct.new( :settings, :s3_bucket_arn, :screenshots_upload_enabled, :screen_resolution, :screen_image_format, :user_control_mode) SENSITIVE = [] include Aws::Structure end |
#screen_image_format ⇒ String
The image format for agent screen captures.
118 119 120 121 122 123 124 125 126 127 |
# File 'lib/aws-sdk-appstream/types.rb', line 118 class AgentAccessConfig < Struct.new( :settings, :s3_bucket_arn, :screenshots_upload_enabled, :screen_resolution, :screen_image_format, :user_control_mode) SENSITIVE = [] include Aws::Structure end |
#screen_resolution ⇒ String
The screen resolution for the agent streaming environment.
118 119 120 121 122 123 124 125 126 127 |
# File 'lib/aws-sdk-appstream/types.rb', line 118 class AgentAccessConfig < Struct.new( :settings, :s3_bucket_arn, :screenshots_upload_enabled, :screen_resolution, :screen_image_format, :user_control_mode) SENSITIVE = [] include Aws::Structure end |
#screenshots_upload_enabled ⇒ Boolean
Indicates whether screenshot uploads to Amazon S3 are enabled for agent sessions.
118 119 120 121 122 123 124 125 126 127 |
# File 'lib/aws-sdk-appstream/types.rb', line 118 class AgentAccessConfig < Struct.new( :settings, :s3_bucket_arn, :screenshots_upload_enabled, :screen_resolution, :screen_image_format, :user_control_mode) SENSITIVE = [] include Aws::Structure end |
#settings ⇒ Array<Types::AgentAccessSetting>
The list of agent access settings that define permissions for each agent action. You must specify at least one setting.
118 119 120 121 122 123 124 125 126 127 |
# File 'lib/aws-sdk-appstream/types.rb', line 118 class AgentAccessConfig < Struct.new( :settings, :s3_bucket_arn, :screenshots_upload_enabled, :screen_resolution, :screen_image_format, :user_control_mode) SENSITIVE = [] include Aws::Structure end |
#user_control_mode ⇒ String
The user control mode for agent sessions. This setting determines how users can interact with agent sessions.
118 119 120 121 122 123 124 125 126 127 |
# File 'lib/aws-sdk-appstream/types.rb', line 118 class AgentAccessConfig < Struct.new( :settings, :s3_bucket_arn, :screenshots_upload_enabled, :screen_resolution, :screen_image_format, :user_control_mode) SENSITIVE = [] include Aws::Structure end |