Class: Aws::AppStream::Types::AgentAccessConfig

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-appstream/types.rb

Overview

The configuration for agent access on a stack. Agent access enables AI agents to interact with desktop applications during streaming sessions.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#s3_bucket_arnString

The Amazon Resource Name (ARN) of the Amazon S3 bucket where agent screenshots are stored. Required when ScreenshotsUploadEnabled is true.

Returns:

  • (String)


113
114
115
116
117
118
119
120
121
# File 'lib/aws-sdk-appstream/types.rb', line 113

class AgentAccessConfig < Struct.new(
  :settings,
  :s3_bucket_arn,
  :screenshots_upload_enabled,
  :screen_resolution,
  :screen_image_format)
  SENSITIVE = []
  include Aws::Structure
end

#screen_image_formatString

The image format for agent screen captures.

Returns:

  • (String)


113
114
115
116
117
118
119
120
121
# File 'lib/aws-sdk-appstream/types.rb', line 113

class AgentAccessConfig < Struct.new(
  :settings,
  :s3_bucket_arn,
  :screenshots_upload_enabled,
  :screen_resolution,
  :screen_image_format)
  SENSITIVE = []
  include Aws::Structure
end

#screen_resolutionString

The screen resolution for the agent streaming environment.

Returns:

  • (String)


113
114
115
116
117
118
119
120
121
# File 'lib/aws-sdk-appstream/types.rb', line 113

class AgentAccessConfig < Struct.new(
  :settings,
  :s3_bucket_arn,
  :screenshots_upload_enabled,
  :screen_resolution,
  :screen_image_format)
  SENSITIVE = []
  include Aws::Structure
end

#screenshots_upload_enabledBoolean

Indicates whether screenshot uploads to Amazon S3 are enabled for agent sessions.

Returns:

  • (Boolean)


113
114
115
116
117
118
119
120
121
# File 'lib/aws-sdk-appstream/types.rb', line 113

class AgentAccessConfig < Struct.new(
  :settings,
  :s3_bucket_arn,
  :screenshots_upload_enabled,
  :screen_resolution,
  :screen_image_format)
  SENSITIVE = []
  include Aws::Structure
end

#settingsArray<Types::AgentAccessSetting>

The list of agent access settings that define permissions for each agent action. You must specify at least one setting.

Returns:



113
114
115
116
117
118
119
120
121
# File 'lib/aws-sdk-appstream/types.rb', line 113

class AgentAccessConfig < Struct.new(
  :settings,
  :s3_bucket_arn,
  :screenshots_upload_enabled,
  :screen_resolution,
  :screen_image_format)
  SENSITIVE = []
  include Aws::Structure
end