Class: Aws::AppStream::Types::AgentAccessConfig
- Inherits:
-
Struct
- Object
- Struct
- Aws::AppStream::Types::AgentAccessConfig
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-appstream/types.rb
Overview
The configuration for agent access on a stack. Agent access enables AI agents to interact with desktop applications during streaming sessions.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#s3_bucket_arn ⇒ String
The Amazon Resource Name (ARN) of the Amazon S3 bucket where agent screenshots are stored.
-
#screen_image_format ⇒ String
The image format for agent screen captures.
-
#screen_resolution ⇒ String
The screen resolution for the agent streaming environment.
-
#screenshots_upload_enabled ⇒ Boolean
Indicates whether screenshot uploads to Amazon S3 are enabled for agent sessions.
-
#settings ⇒ Array<Types::AgentAccessSetting>
The list of agent access settings that define permissions for each agent action.
Instance Attribute Details
#s3_bucket_arn ⇒ String
The Amazon Resource Name (ARN) of the Amazon S3 bucket where agent screenshots are stored. Required when ScreenshotsUploadEnabled is true.
113 114 115 116 117 118 119 120 121 |
# File 'lib/aws-sdk-appstream/types.rb', line 113 class AgentAccessConfig < Struct.new( :settings, :s3_bucket_arn, :screenshots_upload_enabled, :screen_resolution, :screen_image_format) SENSITIVE = [] include Aws::Structure end |
#screen_image_format ⇒ String
The image format for agent screen captures.
113 114 115 116 117 118 119 120 121 |
# File 'lib/aws-sdk-appstream/types.rb', line 113 class AgentAccessConfig < Struct.new( :settings, :s3_bucket_arn, :screenshots_upload_enabled, :screen_resolution, :screen_image_format) SENSITIVE = [] include Aws::Structure end |
#screen_resolution ⇒ String
The screen resolution for the agent streaming environment.
113 114 115 116 117 118 119 120 121 |
# File 'lib/aws-sdk-appstream/types.rb', line 113 class AgentAccessConfig < Struct.new( :settings, :s3_bucket_arn, :screenshots_upload_enabled, :screen_resolution, :screen_image_format) SENSITIVE = [] include Aws::Structure end |
#screenshots_upload_enabled ⇒ Boolean
Indicates whether screenshot uploads to Amazon S3 are enabled for agent sessions.
113 114 115 116 117 118 119 120 121 |
# File 'lib/aws-sdk-appstream/types.rb', line 113 class AgentAccessConfig < Struct.new( :settings, :s3_bucket_arn, :screenshots_upload_enabled, :screen_resolution, :screen_image_format) SENSITIVE = [] include Aws::Structure end |
#settings ⇒ Array<Types::AgentAccessSetting>
The list of agent access settings that define permissions for each agent action. You must specify at least one setting.
113 114 115 116 117 118 119 120 121 |
# File 'lib/aws-sdk-appstream/types.rb', line 113 class AgentAccessConfig < Struct.new( :settings, :s3_bucket_arn, :screenshots_upload_enabled, :screen_resolution, :screen_image_format) SENSITIVE = [] include Aws::Structure end |