Class: Aws::AppStream::Types::AgentAccessConfigForUpdate

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-appstream/types.rb

Overview

The configuration for updating agent access on a stack. This type supports partial updates, so you only need to specify the fields you want to change.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#s3_bucket_arnString

The Amazon Resource Name (ARN) of the Amazon S3 bucket where agent screenshots are stored.

Returns:

  • (String)


152
153
154
155
156
157
158
159
160
# File 'lib/aws-sdk-appstream/types.rb', line 152

class AgentAccessConfigForUpdate < Struct.new(
  :settings,
  :s3_bucket_arn,
  :screenshots_upload_enabled,
  :screen_resolution,
  :screen_image_format)
  SENSITIVE = []
  include Aws::Structure
end

#screen_image_formatString

The image format for agent screen captures.

Returns:

  • (String)


152
153
154
155
156
157
158
159
160
# File 'lib/aws-sdk-appstream/types.rb', line 152

class AgentAccessConfigForUpdate < Struct.new(
  :settings,
  :s3_bucket_arn,
  :screenshots_upload_enabled,
  :screen_resolution,
  :screen_image_format)
  SENSITIVE = []
  include Aws::Structure
end

#screen_resolutionString

The screen resolution for the agent streaming environment.

Returns:

  • (String)


152
153
154
155
156
157
158
159
160
# File 'lib/aws-sdk-appstream/types.rb', line 152

class AgentAccessConfigForUpdate < Struct.new(
  :settings,
  :s3_bucket_arn,
  :screenshots_upload_enabled,
  :screen_resolution,
  :screen_image_format)
  SENSITIVE = []
  include Aws::Structure
end

#screenshots_upload_enabledBoolean

Indicates whether screenshot uploads to Amazon S3 are enabled for agent sessions.

Returns:

  • (Boolean)


152
153
154
155
156
157
158
159
160
# File 'lib/aws-sdk-appstream/types.rb', line 152

class AgentAccessConfigForUpdate < Struct.new(
  :settings,
  :s3_bucket_arn,
  :screenshots_upload_enabled,
  :screen_resolution,
  :screen_image_format)
  SENSITIVE = []
  include Aws::Structure
end

#settingsArray<Types::AgentAccessSetting>

The list of agent access settings that define permissions for each agent action.

Returns:



152
153
154
155
156
157
158
159
160
# File 'lib/aws-sdk-appstream/types.rb', line 152

class AgentAccessConfigForUpdate < Struct.new(
  :settings,
  :s3_bucket_arn,
  :screenshots_upload_enabled,
  :screen_resolution,
  :screen_image_format)
  SENSITIVE = []
  include Aws::Structure
end