Class: Aws::AppStream::Types::Application
- Inherits:
-
Struct
- Object
- Struct
- Aws::AppStream::Types::Application
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-appstream/types.rb
Overview
Describes an application in the application catalog.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#app_block_arn ⇒ String
The app block ARN of the application.
-
#arn ⇒ String
The ARN of the application.
-
#created_time ⇒ Time
The time at which the application was created within the app block.
-
#description ⇒ String
The description of the application.
-
#display_name ⇒ String
The application name to display.
-
#enabled ⇒ Boolean
If there is a problem, the application can be disabled after image creation.
-
#icon_s3_location ⇒ Types::S3Location
The S3 location of the application icon.
-
#icon_url ⇒ String
The URL for the application icon.
-
#instance_families ⇒ Array<String>
The instance families for the application.
-
#launch_parameters ⇒ String
The arguments that are passed to the application at launch.
-
#launch_path ⇒ String
The path to the application executable in the instance.
-
#metadata ⇒ Hash<String,String>
Additional attributes that describe the application.
-
#name ⇒ String
The name of the application.
-
#platforms ⇒ Array<String>
The platforms on which the application can run.
-
#working_directory ⇒ String
The working directory for the application.
Instance Attribute Details
#app_block_arn ⇒ String
The app block ARN of the application.
463 464 465 466 467 468 469 470 471 472 473 474 475 476 477 478 479 480 481 |
# File 'lib/aws-sdk-appstream/types.rb', line 463 class Application < Struct.new( :name, :display_name, :icon_url, :launch_path, :launch_parameters, :enabled, :metadata, :working_directory, :description, :arn, :app_block_arn, :icon_s3_location, :platforms, :instance_families, :created_time) SENSITIVE = [] include Aws::Structure end |
#arn ⇒ String
The ARN of the application.
463 464 465 466 467 468 469 470 471 472 473 474 475 476 477 478 479 480 481 |
# File 'lib/aws-sdk-appstream/types.rb', line 463 class Application < Struct.new( :name, :display_name, :icon_url, :launch_path, :launch_parameters, :enabled, :metadata, :working_directory, :description, :arn, :app_block_arn, :icon_s3_location, :platforms, :instance_families, :created_time) SENSITIVE = [] include Aws::Structure end |
#created_time ⇒ Time
The time at which the application was created within the app block.
463 464 465 466 467 468 469 470 471 472 473 474 475 476 477 478 479 480 481 |
# File 'lib/aws-sdk-appstream/types.rb', line 463 class Application < Struct.new( :name, :display_name, :icon_url, :launch_path, :launch_parameters, :enabled, :metadata, :working_directory, :description, :arn, :app_block_arn, :icon_s3_location, :platforms, :instance_families, :created_time) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
The description of the application.
463 464 465 466 467 468 469 470 471 472 473 474 475 476 477 478 479 480 481 |
# File 'lib/aws-sdk-appstream/types.rb', line 463 class Application < Struct.new( :name, :display_name, :icon_url, :launch_path, :launch_parameters, :enabled, :metadata, :working_directory, :description, :arn, :app_block_arn, :icon_s3_location, :platforms, :instance_families, :created_time) SENSITIVE = [] include Aws::Structure end |
#display_name ⇒ String
The application name to display.
463 464 465 466 467 468 469 470 471 472 473 474 475 476 477 478 479 480 481 |
# File 'lib/aws-sdk-appstream/types.rb', line 463 class Application < Struct.new( :name, :display_name, :icon_url, :launch_path, :launch_parameters, :enabled, :metadata, :working_directory, :description, :arn, :app_block_arn, :icon_s3_location, :platforms, :instance_families, :created_time) SENSITIVE = [] include Aws::Structure end |
#enabled ⇒ Boolean
If there is a problem, the application can be disabled after image creation.
463 464 465 466 467 468 469 470 471 472 473 474 475 476 477 478 479 480 481 |
# File 'lib/aws-sdk-appstream/types.rb', line 463 class Application < Struct.new( :name, :display_name, :icon_url, :launch_path, :launch_parameters, :enabled, :metadata, :working_directory, :description, :arn, :app_block_arn, :icon_s3_location, :platforms, :instance_families, :created_time) SENSITIVE = [] include Aws::Structure end |
#icon_s3_location ⇒ Types::S3Location
The S3 location of the application icon.
463 464 465 466 467 468 469 470 471 472 473 474 475 476 477 478 479 480 481 |
# File 'lib/aws-sdk-appstream/types.rb', line 463 class Application < Struct.new( :name, :display_name, :icon_url, :launch_path, :launch_parameters, :enabled, :metadata, :working_directory, :description, :arn, :app_block_arn, :icon_s3_location, :platforms, :instance_families, :created_time) SENSITIVE = [] include Aws::Structure end |
#icon_url ⇒ String
The URL for the application icon. This URL might be time-limited.
463 464 465 466 467 468 469 470 471 472 473 474 475 476 477 478 479 480 481 |
# File 'lib/aws-sdk-appstream/types.rb', line 463 class Application < Struct.new( :name, :display_name, :icon_url, :launch_path, :launch_parameters, :enabled, :metadata, :working_directory, :description, :arn, :app_block_arn, :icon_s3_location, :platforms, :instance_families, :created_time) SENSITIVE = [] include Aws::Structure end |
#instance_families ⇒ Array<String>
The instance families for the application.
463 464 465 466 467 468 469 470 471 472 473 474 475 476 477 478 479 480 481 |
# File 'lib/aws-sdk-appstream/types.rb', line 463 class Application < Struct.new( :name, :display_name, :icon_url, :launch_path, :launch_parameters, :enabled, :metadata, :working_directory, :description, :arn, :app_block_arn, :icon_s3_location, :platforms, :instance_families, :created_time) SENSITIVE = [] include Aws::Structure end |
#launch_parameters ⇒ String
The arguments that are passed to the application at launch.
463 464 465 466 467 468 469 470 471 472 473 474 475 476 477 478 479 480 481 |
# File 'lib/aws-sdk-appstream/types.rb', line 463 class Application < Struct.new( :name, :display_name, :icon_url, :launch_path, :launch_parameters, :enabled, :metadata, :working_directory, :description, :arn, :app_block_arn, :icon_s3_location, :platforms, :instance_families, :created_time) SENSITIVE = [] include Aws::Structure end |
#launch_path ⇒ String
The path to the application executable in the instance.
463 464 465 466 467 468 469 470 471 472 473 474 475 476 477 478 479 480 481 |
# File 'lib/aws-sdk-appstream/types.rb', line 463 class Application < Struct.new( :name, :display_name, :icon_url, :launch_path, :launch_parameters, :enabled, :metadata, :working_directory, :description, :arn, :app_block_arn, :icon_s3_location, :platforms, :instance_families, :created_time) SENSITIVE = [] include Aws::Structure end |
#metadata ⇒ Hash<String,String>
Additional attributes that describe the application.
463 464 465 466 467 468 469 470 471 472 473 474 475 476 477 478 479 480 481 |
# File 'lib/aws-sdk-appstream/types.rb', line 463 class Application < Struct.new( :name, :display_name, :icon_url, :launch_path, :launch_parameters, :enabled, :metadata, :working_directory, :description, :arn, :app_block_arn, :icon_s3_location, :platforms, :instance_families, :created_time) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the application.
463 464 465 466 467 468 469 470 471 472 473 474 475 476 477 478 479 480 481 |
# File 'lib/aws-sdk-appstream/types.rb', line 463 class Application < Struct.new( :name, :display_name, :icon_url, :launch_path, :launch_parameters, :enabled, :metadata, :working_directory, :description, :arn, :app_block_arn, :icon_s3_location, :platforms, :instance_families, :created_time) SENSITIVE = [] include Aws::Structure end |
#platforms ⇒ Array<String>
The platforms on which the application can run.
463 464 465 466 467 468 469 470 471 472 473 474 475 476 477 478 479 480 481 |
# File 'lib/aws-sdk-appstream/types.rb', line 463 class Application < Struct.new( :name, :display_name, :icon_url, :launch_path, :launch_parameters, :enabled, :metadata, :working_directory, :description, :arn, :app_block_arn, :icon_s3_location, :platforms, :instance_families, :created_time) SENSITIVE = [] include Aws::Structure end |
#working_directory ⇒ String
The working directory for the application.
463 464 465 466 467 468 469 470 471 472 473 474 475 476 477 478 479 480 481 |
# File 'lib/aws-sdk-appstream/types.rb', line 463 class Application < Struct.new( :name, :display_name, :icon_url, :launch_path, :launch_parameters, :enabled, :metadata, :working_directory, :description, :arn, :app_block_arn, :icon_s3_location, :platforms, :instance_families, :created_time) SENSITIVE = [] include Aws::Structure end |