Class: Aws::AppStream::Types::ApplicationSettings
- Inherits:
-
Struct
- Object
- Struct
- Aws::AppStream::Types::ApplicationSettings
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-appstream/types.rb
Overview
The persistent application settings for users of a stack.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#enabled ⇒ Boolean
Enables or disables persistent application settings for users during their streaming sessions.
-
#settings_group ⇒ String
The path prefix for the S3 bucket where users’ persistent application settings are stored.
Instance Attribute Details
#enabled ⇒ Boolean
Enables or disables persistent application settings for users during their streaming sessions.
584 585 586 587 588 589 |
# File 'lib/aws-sdk-appstream/types.rb', line 584 class ApplicationSettings < Struct.new( :enabled, :settings_group) SENSITIVE = [] include Aws::Structure end |
#settings_group ⇒ String
The path prefix for the S3 bucket where users’ persistent application settings are stored. You can allow the same persistent application settings to be used across multiple stacks by specifying the same settings group for each stack.
584 585 586 587 588 589 |
# File 'lib/aws-sdk-appstream/types.rb', line 584 class ApplicationSettings < Struct.new( :enabled, :settings_group) SENSITIVE = [] include Aws::Structure end |