Class: Aws::AppStream::Types::AssociateApplicationFleetResult
- Inherits:
-
Struct
- Object
- Struct
- Aws::AppStream::Types::AssociateApplicationFleetResult
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-appstream/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#application_fleet_association ⇒ Types::ApplicationFleetAssociation
If fleet name is specified, this returns the list of applications that are associated to it.
Instance Attribute Details
#application_fleet_association ⇒ Types::ApplicationFleetAssociation
If fleet name is specified, this returns the list of applications that are associated to it. If application ARN is specified, this returns the list of fleets to which it is associated.
573 574 575 576 577 |
# File 'lib/aws-sdk-appstream/types.rb', line 573 class AssociateApplicationFleetResult < Struct.new( :application_fleet_association) SENSITIVE = [] include Aws::Structure end |