Class: Aws::AppStream::Types::ComputeCapacity
- Inherits:
-
Struct
- Object
- Struct
- Aws::AppStream::Types::ComputeCapacity
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-appstream/types.rb
Overview
Describes the capacity for a fleet.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#desired_instances ⇒ Integer
The desired number of streaming instances.
-
#desired_sessions ⇒ Integer
The desired number of user sessions for a multi-session fleet.
Instance Attribute Details
#desired_instances ⇒ Integer
The desired number of streaming instances.
892 893 894 895 896 897 |
# File 'lib/aws-sdk-appstream/types.rb', line 892 class ComputeCapacity < Struct.new( :desired_instances, :desired_sessions) SENSITIVE = [] include Aws::Structure end |
#desired_sessions ⇒ Integer
The desired number of user sessions for a multi-session fleet. This is not allowed for single-session fleets.
When you create a fleet, you must set either the DesiredSessions or DesiredInstances attribute, based on the type of fleet you create. You can’t define both attributes or leave both attributes blank.
892 893 894 895 896 897 |
# File 'lib/aws-sdk-appstream/types.rb', line 892 class ComputeCapacity < Struct.new( :desired_instances, :desired_sessions) SENSITIVE = [] include Aws::Structure end |