Class: Aws::AppStream::Types::CopyImageRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::AppStream::Types::CopyImageRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-appstream/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#destination_image_description ⇒ String
The description that the image will have when it is copied to the destination.
-
#destination_image_name ⇒ String
The name that the image will have when it is copied to the destination.
-
#destination_region ⇒ String
The destination region to which the image will be copied.
-
#source_image_name ⇒ String
The name of the image to copy.
Instance Attribute Details
#destination_image_description ⇒ String
The description that the image will have when it is copied to the destination.
1042 1043 1044 1045 1046 1047 1048 1049 |
# File 'lib/aws-sdk-appstream/types.rb', line 1042 class CopyImageRequest < Struct.new( :source_image_name, :destination_image_name, :destination_region, :destination_image_description) SENSITIVE = [] include Aws::Structure end |
#destination_image_name ⇒ String
The name that the image will have when it is copied to the destination.
1042 1043 1044 1045 1046 1047 1048 1049 |
# File 'lib/aws-sdk-appstream/types.rb', line 1042 class CopyImageRequest < Struct.new( :source_image_name, :destination_image_name, :destination_region, :destination_image_description) SENSITIVE = [] include Aws::Structure end |
#destination_region ⇒ String
The destination region to which the image will be copied. This parameter is required, even if you are copying an image within the same region.
1042 1043 1044 1045 1046 1047 1048 1049 |
# File 'lib/aws-sdk-appstream/types.rb', line 1042 class CopyImageRequest < Struct.new( :source_image_name, :destination_image_name, :destination_region, :destination_image_description) SENSITIVE = [] include Aws::Structure end |
#source_image_name ⇒ String
The name of the image to copy.
1042 1043 1044 1045 1046 1047 1048 1049 |
# File 'lib/aws-sdk-appstream/types.rb', line 1042 class CopyImageRequest < Struct.new( :source_image_name, :destination_image_name, :destination_region, :destination_image_description) SENSITIVE = [] include Aws::Structure end |