Class: Aws::AppStream::Types::CreateStackRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::AppStream::Types::CreateStackRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-appstream/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#access_endpoints ⇒ Array<Types::AccessEndpoint>
The list of interface VPC endpoint (interface endpoint) objects.
-
#agent_access_config ⇒ Types::AgentAccessConfig
The configuration for agent access on the stack.
-
#application_settings ⇒ Types::ApplicationSettings
The persistent application settings for users of a stack.
-
#content_redirection ⇒ Types::ContentRedirection
Configuration for bidirectional URL redirection between the streaming session and the local client.
-
#description ⇒ String
The description to display.
-
#display_name ⇒ String
The stack name to display.
-
#embed_host_domains ⇒ Array<String>
The domains where WorkSpaces Applications streaming sessions can be embedded in an iframe.
-
#feedback_url ⇒ String
The URL that users are redirected to after they click the Send Feedback link.
-
#name ⇒ String
The name of the stack.
-
#redirect_url ⇒ String
The URL that users are redirected to after their streaming session ends.
-
#storage_connectors ⇒ Array<Types::StorageConnector>
The storage connectors to enable.
-
#streaming_experience_settings ⇒ Types::StreamingExperienceSettings
The streaming protocol you want your stack to prefer.
-
#tags ⇒ Hash<String,String>
The tags to associate with the stack.
-
#user_settings ⇒ Array<Types::UserSetting>
The actions that are enabled or disabled for users during their streaming sessions.
Instance Attribute Details
#access_endpoints ⇒ Array<Types::AccessEndpoint>
The list of interface VPC endpoint (interface endpoint) objects. Users of the stack can connect to WorkSpaces Applications only through the specified endpoints.
2431 2432 2433 2434 2435 2436 2437 2438 2439 2440 2441 2442 2443 2444 2445 2446 2447 2448 |
# File 'lib/aws-sdk-appstream/types.rb', line 2431 class CreateStackRequest < Struct.new( :name, :description, :display_name, :storage_connectors, :redirect_url, :feedback_url, :user_settings, :application_settings, :tags, :access_endpoints, :embed_host_domains, :streaming_experience_settings, :content_redirection, :agent_access_config) SENSITIVE = [] include Aws::Structure end |
#agent_access_config ⇒ Types::AgentAccessConfig
The configuration for agent access on the stack. If specified, agent access is enabled for the stack.
2431 2432 2433 2434 2435 2436 2437 2438 2439 2440 2441 2442 2443 2444 2445 2446 2447 2448 |
# File 'lib/aws-sdk-appstream/types.rb', line 2431 class CreateStackRequest < Struct.new( :name, :description, :display_name, :storage_connectors, :redirect_url, :feedback_url, :user_settings, :application_settings, :tags, :access_endpoints, :embed_host_domains, :streaming_experience_settings, :content_redirection, :agent_access_config) SENSITIVE = [] include Aws::Structure end |
#application_settings ⇒ Types::ApplicationSettings
The persistent application settings for users of a stack. When these settings are enabled, changes that users make to applications and Windows settings are automatically saved after each session and applied to the next session.
2431 2432 2433 2434 2435 2436 2437 2438 2439 2440 2441 2442 2443 2444 2445 2446 2447 2448 |
# File 'lib/aws-sdk-appstream/types.rb', line 2431 class CreateStackRequest < Struct.new( :name, :description, :display_name, :storage_connectors, :redirect_url, :feedback_url, :user_settings, :application_settings, :tags, :access_endpoints, :embed_host_domains, :streaming_experience_settings, :content_redirection, :agent_access_config) SENSITIVE = [] include Aws::Structure end |
#content_redirection ⇒ Types::ContentRedirection
Configuration for bidirectional URL redirection between the streaming session and the local client. Use HostToClient to redirect URLs from the remote desktop to the local browser.
2431 2432 2433 2434 2435 2436 2437 2438 2439 2440 2441 2442 2443 2444 2445 2446 2447 2448 |
# File 'lib/aws-sdk-appstream/types.rb', line 2431 class CreateStackRequest < Struct.new( :name, :description, :display_name, :storage_connectors, :redirect_url, :feedback_url, :user_settings, :application_settings, :tags, :access_endpoints, :embed_host_domains, :streaming_experience_settings, :content_redirection, :agent_access_config) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
The description to display.
2431 2432 2433 2434 2435 2436 2437 2438 2439 2440 2441 2442 2443 2444 2445 2446 2447 2448 |
# File 'lib/aws-sdk-appstream/types.rb', line 2431 class CreateStackRequest < Struct.new( :name, :description, :display_name, :storage_connectors, :redirect_url, :feedback_url, :user_settings, :application_settings, :tags, :access_endpoints, :embed_host_domains, :streaming_experience_settings, :content_redirection, :agent_access_config) SENSITIVE = [] include Aws::Structure end |
#display_name ⇒ String
The stack name to display.
2431 2432 2433 2434 2435 2436 2437 2438 2439 2440 2441 2442 2443 2444 2445 2446 2447 2448 |
# File 'lib/aws-sdk-appstream/types.rb', line 2431 class CreateStackRequest < Struct.new( :name, :description, :display_name, :storage_connectors, :redirect_url, :feedback_url, :user_settings, :application_settings, :tags, :access_endpoints, :embed_host_domains, :streaming_experience_settings, :content_redirection, :agent_access_config) SENSITIVE = [] include Aws::Structure end |
#embed_host_domains ⇒ Array<String>
The domains where WorkSpaces Applications streaming sessions can be embedded in an iframe. You must approve the domains that you want to host embedded WorkSpaces Applications streaming sessions.
2431 2432 2433 2434 2435 2436 2437 2438 2439 2440 2441 2442 2443 2444 2445 2446 2447 2448 |
# File 'lib/aws-sdk-appstream/types.rb', line 2431 class CreateStackRequest < Struct.new( :name, :description, :display_name, :storage_connectors, :redirect_url, :feedback_url, :user_settings, :application_settings, :tags, :access_endpoints, :embed_host_domains, :streaming_experience_settings, :content_redirection, :agent_access_config) SENSITIVE = [] include Aws::Structure end |
#feedback_url ⇒ String
The URL that users are redirected to after they click the Send Feedback link. If no URL is specified, no Send Feedback link is displayed.
2431 2432 2433 2434 2435 2436 2437 2438 2439 2440 2441 2442 2443 2444 2445 2446 2447 2448 |
# File 'lib/aws-sdk-appstream/types.rb', line 2431 class CreateStackRequest < Struct.new( :name, :description, :display_name, :storage_connectors, :redirect_url, :feedback_url, :user_settings, :application_settings, :tags, :access_endpoints, :embed_host_domains, :streaming_experience_settings, :content_redirection, :agent_access_config) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the stack.
2431 2432 2433 2434 2435 2436 2437 2438 2439 2440 2441 2442 2443 2444 2445 2446 2447 2448 |
# File 'lib/aws-sdk-appstream/types.rb', line 2431 class CreateStackRequest < Struct.new( :name, :description, :display_name, :storage_connectors, :redirect_url, :feedback_url, :user_settings, :application_settings, :tags, :access_endpoints, :embed_host_domains, :streaming_experience_settings, :content_redirection, :agent_access_config) SENSITIVE = [] include Aws::Structure end |
#redirect_url ⇒ String
The URL that users are redirected to after their streaming session ends.
2431 2432 2433 2434 2435 2436 2437 2438 2439 2440 2441 2442 2443 2444 2445 2446 2447 2448 |
# File 'lib/aws-sdk-appstream/types.rb', line 2431 class CreateStackRequest < Struct.new( :name, :description, :display_name, :storage_connectors, :redirect_url, :feedback_url, :user_settings, :application_settings, :tags, :access_endpoints, :embed_host_domains, :streaming_experience_settings, :content_redirection, :agent_access_config) SENSITIVE = [] include Aws::Structure end |
#storage_connectors ⇒ Array<Types::StorageConnector>
The storage connectors to enable.
2431 2432 2433 2434 2435 2436 2437 2438 2439 2440 2441 2442 2443 2444 2445 2446 2447 2448 |
# File 'lib/aws-sdk-appstream/types.rb', line 2431 class CreateStackRequest < Struct.new( :name, :description, :display_name, :storage_connectors, :redirect_url, :feedback_url, :user_settings, :application_settings, :tags, :access_endpoints, :embed_host_domains, :streaming_experience_settings, :content_redirection, :agent_access_config) SENSITIVE = [] include Aws::Structure end |
#streaming_experience_settings ⇒ Types::StreamingExperienceSettings
The streaming protocol you want your stack to prefer. This can be UDP or TCP. Currently, UDP is only supported in the Windows native client.
2431 2432 2433 2434 2435 2436 2437 2438 2439 2440 2441 2442 2443 2444 2445 2446 2447 2448 |
# File 'lib/aws-sdk-appstream/types.rb', line 2431 class CreateStackRequest < Struct.new( :name, :description, :display_name, :storage_connectors, :redirect_url, :feedback_url, :user_settings, :application_settings, :tags, :access_endpoints, :embed_host_domains, :streaming_experience_settings, :content_redirection, :agent_access_config) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Hash<String,String>
The tags to associate with the stack. A tag is a key-value pair, and the value is optional. For example, Environment=Test. If you do not specify a value, Environment=.
If you do not specify a value, the value is set to an empty string.
Generally allowed characters are: letters, numbers, and spaces representable in UTF-8, and the following special characters:
_ . : / = + \ - @
For more information about tags, see [Tagging Your Resources] in the *Amazon WorkSpaces Applications Administration Guide*.
[1]: docs.aws.amazon.com/appstream2/latest/developerguide/tagging-basic.html
2431 2432 2433 2434 2435 2436 2437 2438 2439 2440 2441 2442 2443 2444 2445 2446 2447 2448 |
# File 'lib/aws-sdk-appstream/types.rb', line 2431 class CreateStackRequest < Struct.new( :name, :description, :display_name, :storage_connectors, :redirect_url, :feedback_url, :user_settings, :application_settings, :tags, :access_endpoints, :embed_host_domains, :streaming_experience_settings, :content_redirection, :agent_access_config) SENSITIVE = [] include Aws::Structure end |
#user_settings ⇒ Array<Types::UserSetting>
The actions that are enabled or disabled for users during their streaming sessions. By default, these actions are enabled.
2431 2432 2433 2434 2435 2436 2437 2438 2439 2440 2441 2442 2443 2444 2445 2446 2447 2448 |
# File 'lib/aws-sdk-appstream/types.rb', line 2431 class CreateStackRequest < Struct.new( :name, :description, :display_name, :storage_connectors, :redirect_url, :feedback_url, :user_settings, :application_settings, :tags, :access_endpoints, :embed_host_domains, :streaming_experience_settings, :content_redirection, :agent_access_config) SENSITIVE = [] include Aws::Structure end |