Class: Aws::AppStream::Types::CreateStreamingURLRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-appstream/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#application_idString

The name of the application to launch after the session starts. This is the name that you specified as Name in the Image Assistant. If your fleet is enabled for the Desktop stream view, you can also choose to launch directly to the operating system desktop. To do so, specify Desktop.

Returns:

  • (String)


2498
2499
2500
2501
2502
2503
2504
2505
2506
2507
# File 'lib/aws-sdk-appstream/types.rb', line 2498

class CreateStreamingURLRequest < Struct.new(
  :stack_name,
  :fleet_name,
  :user_id,
  :application_id,
  :validity,
  :session_context)
  SENSITIVE = []
  include Aws::Structure
end

#fleet_nameString

The name of the fleet.

Returns:

  • (String)


2498
2499
2500
2501
2502
2503
2504
2505
2506
2507
# File 'lib/aws-sdk-appstream/types.rb', line 2498

class CreateStreamingURLRequest < Struct.new(
  :stack_name,
  :fleet_name,
  :user_id,
  :application_id,
  :validity,
  :session_context)
  SENSITIVE = []
  include Aws::Structure
end

#session_contextString

The session context. For more information, see [Session Context] in the *Amazon WorkSpaces Applications Administration Guide*.

[1]: docs.aws.amazon.com/appstream2/latest/developerguide/managing-stacks-fleets.html#managing-stacks-fleets-parameters

Returns:

  • (String)


2498
2499
2500
2501
2502
2503
2504
2505
2506
2507
# File 'lib/aws-sdk-appstream/types.rb', line 2498

class CreateStreamingURLRequest < Struct.new(
  :stack_name,
  :fleet_name,
  :user_id,
  :application_id,
  :validity,
  :session_context)
  SENSITIVE = []
  include Aws::Structure
end

#stack_nameString

The name of the stack.

Returns:

  • (String)


2498
2499
2500
2501
2502
2503
2504
2505
2506
2507
# File 'lib/aws-sdk-appstream/types.rb', line 2498

class CreateStreamingURLRequest < Struct.new(
  :stack_name,
  :fleet_name,
  :user_id,
  :application_id,
  :validity,
  :session_context)
  SENSITIVE = []
  include Aws::Structure
end

#user_idString

The identifier of the user.

Returns:

  • (String)


2498
2499
2500
2501
2502
2503
2504
2505
2506
2507
# File 'lib/aws-sdk-appstream/types.rb', line 2498

class CreateStreamingURLRequest < Struct.new(
  :stack_name,
  :fleet_name,
  :user_id,
  :application_id,
  :validity,
  :session_context)
  SENSITIVE = []
  include Aws::Structure
end

#validityInteger

The time that the streaming URL will be valid, in seconds. Specify a value between 1 and 604800 seconds. The default is 60 seconds.

Returns:

  • (Integer)


2498
2499
2500
2501
2502
2503
2504
2505
2506
2507
# File 'lib/aws-sdk-appstream/types.rb', line 2498

class CreateStreamingURLRequest < Struct.new(
  :stack_name,
  :fleet_name,
  :user_id,
  :application_id,
  :validity,
  :session_context)
  SENSITIVE = []
  include Aws::Structure
end