Class: Aws::AppStream::Types::DescribeDirectoryConfigsResult
- Inherits:
-
Struct
- Object
- Struct
- Aws::AppStream::Types::DescribeDirectoryConfigsResult
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-appstream/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#directory_configs ⇒ Array<Types::DirectoryConfig>
Information about the directory configurations.
-
#next_token ⇒ String
The pagination token to use to retrieve the next page of results for this operation.
Instance Attribute Details
#directory_configs ⇒ Array<Types::DirectoryConfig>
Information about the directory configurations. Note that although the response syntax in this topic includes the account password, this password is not returned in the actual response.
3172 3173 3174 3175 3176 3177 |
# File 'lib/aws-sdk-appstream/types.rb', line 3172 class DescribeDirectoryConfigsResult < Struct.new( :directory_configs, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The pagination token to use to retrieve the next page of results for this operation. If there are no more pages, this value is null.
3172 3173 3174 3175 3176 3177 |
# File 'lib/aws-sdk-appstream/types.rb', line 3172 class DescribeDirectoryConfigsResult < Struct.new( :directory_configs, :next_token) SENSITIVE = [] include Aws::Structure end |