Class: Aws::AppStream::Types::DescribeImageBuildersResult
- Inherits:
-
Struct
- Object
- Struct
- Aws::AppStream::Types::DescribeImageBuildersResult
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-appstream/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#image_builders ⇒ Array<Types::ImageBuilder>
Information about the image builders.
-
#next_token ⇒ String
The pagination token to use to retrieve the next page of results for this operation.
Instance Attribute Details
#image_builders ⇒ Array<Types::ImageBuilder>
Information about the image builders.
3402 3403 3404 3405 3406 3407 |
# File 'lib/aws-sdk-appstream/types.rb', line 3402 class DescribeImageBuildersResult < Struct.new( :image_builders, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The pagination token to use to retrieve the next page of results for this operation. If there are no more pages, this value is null.
3402 3403 3404 3405 3406 3407 |
# File 'lib/aws-sdk-appstream/types.rb', line 3402 class DescribeImageBuildersResult < Struct.new( :image_builders, :next_token) SENSITIVE = [] include Aws::Structure end |