Class: Aws::AppStream::Types::DescribeImagePermissionsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::AppStream::Types::DescribeImagePermissionsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-appstream/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#max_results ⇒ Integer
The maximum size of each page of results.
-
#name ⇒ String
The name of the private image for which to describe permissions.
-
#next_token ⇒ String
The pagination token to use to retrieve the next page of results for this operation.
-
#shared_aws_account_ids ⇒ Array<String>
The 12-digit identifier of one or more AWS accounts with which the image is shared.
Instance Attribute Details
#max_results ⇒ Integer
The maximum size of each page of results.
3430 3431 3432 3433 3434 3435 3436 3437 |
# File 'lib/aws-sdk-appstream/types.rb', line 3430 class DescribeImagePermissionsRequest < Struct.new( :name, :max_results, :shared_aws_account_ids, :next_token) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the private image for which to describe permissions. The image must be one that you own.
3430 3431 3432 3433 3434 3435 3436 3437 |
# File 'lib/aws-sdk-appstream/types.rb', line 3430 class DescribeImagePermissionsRequest < Struct.new( :name, :max_results, :shared_aws_account_ids, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The pagination token to use to retrieve the next page of results for this operation. If this value is null, it retrieves the first page.
3430 3431 3432 3433 3434 3435 3436 3437 |
# File 'lib/aws-sdk-appstream/types.rb', line 3430 class DescribeImagePermissionsRequest < Struct.new( :name, :max_results, :shared_aws_account_ids, :next_token) SENSITIVE = [] include Aws::Structure end |
#shared_aws_account_ids ⇒ Array<String>
The 12-digit identifier of one or more AWS accounts with which the image is shared.
3430 3431 3432 3433 3434 3435 3436 3437 |
# File 'lib/aws-sdk-appstream/types.rb', line 3430 class DescribeImagePermissionsRequest < Struct.new( :name, :max_results, :shared_aws_account_ids, :next_token) SENSITIVE = [] include Aws::Structure end |