Class: Aws::AppStream::Types::DescribeImagePermissionsResult
- Inherits:
-
Struct
- Object
- Struct
- Aws::AppStream::Types::DescribeImagePermissionsResult
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-appstream/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#name ⇒ String
The name of the private image.
-
#next_token ⇒ String
The pagination token to use to retrieve the next page of results for this operation.
-
#shared_image_permissions_list ⇒ Array<Types::SharedImagePermissions>
The permissions for a private image that you own.
Instance Attribute Details
#name ⇒ String
The name of the private image.
3454 3455 3456 3457 3458 3459 3460 |
# File 'lib/aws-sdk-appstream/types.rb', line 3454 class DescribeImagePermissionsResult < Struct.new( :name, :shared_image_permissions_list, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The pagination token to use to retrieve the next page of results for this operation. If there are no more pages, this value is null.
3454 3455 3456 3457 3458 3459 3460 |
# File 'lib/aws-sdk-appstream/types.rb', line 3454 class DescribeImagePermissionsResult < Struct.new( :name, :shared_image_permissions_list, :next_token) SENSITIVE = [] include Aws::Structure end |
#shared_image_permissions_list ⇒ Array<Types::SharedImagePermissions>
The permissions for a private image that you own.
3454 3455 3456 3457 3458 3459 3460 |
# File 'lib/aws-sdk-appstream/types.rb', line 3454 class DescribeImagePermissionsResult < Struct.new( :name, :shared_image_permissions_list, :next_token) SENSITIVE = [] include Aws::Structure end |