Class: Aws::AppStream::Types::DescribeImagesRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::AppStream::Types::DescribeImagesRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-appstream/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#arns ⇒ Array<String>
The ARNs of the public, private, and shared images to describe.
-
#max_results ⇒ Integer
The maximum size of each page of results.
-
#names ⇒ Array<String>
The names of the public or private images to describe.
-
#next_token ⇒ String
The pagination token to use to retrieve the next page of results for this operation.
-
#type ⇒ String
The type of image (public, private, or shared) to describe.
Instance Attribute Details
#arns ⇒ Array<String>
The ARNs of the public, private, and shared images to describe.
3488 3489 3490 3491 3492 3493 3494 3495 3496 |
# File 'lib/aws-sdk-appstream/types.rb', line 3488 class DescribeImagesRequest < Struct.new( :names, :arns, :type, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum size of each page of results.
3488 3489 3490 3491 3492 3493 3494 3495 3496 |
# File 'lib/aws-sdk-appstream/types.rb', line 3488 class DescribeImagesRequest < Struct.new( :names, :arns, :type, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#names ⇒ Array<String>
The names of the public or private images to describe.
3488 3489 3490 3491 3492 3493 3494 3495 3496 |
# File 'lib/aws-sdk-appstream/types.rb', line 3488 class DescribeImagesRequest < Struct.new( :names, :arns, :type, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The pagination token to use to retrieve the next page of results for this operation. If this value is null, it retrieves the first page.
3488 3489 3490 3491 3492 3493 3494 3495 3496 |
# File 'lib/aws-sdk-appstream/types.rb', line 3488 class DescribeImagesRequest < Struct.new( :names, :arns, :type, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#type ⇒ String
The type of image (public, private, or shared) to describe.
3488 3489 3490 3491 3492 3493 3494 3495 3496 |
# File 'lib/aws-sdk-appstream/types.rb', line 3488 class DescribeImagesRequest < Struct.new( :names, :arns, :type, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |