Class: Aws::AppStream::Types::DescribeImagesResult
- Inherits:
-
Struct
- Object
- Struct
- Aws::AppStream::Types::DescribeImagesResult
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-appstream/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#images ⇒ Array<Types::Image>
Information about the images.
-
#next_token ⇒ String
The pagination token to use to retrieve the next page of results for this operation.
Instance Attribute Details
#images ⇒ Array<Types::Image>
Information about the images.
3521 3522 3523 3524 3525 3526 |
# File 'lib/aws-sdk-appstream/types.rb', line 3521 class DescribeImagesResult < Struct.new( :images, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The pagination token to use to retrieve the next page of results for this operation. If there are no more pages, this value is null.
3521 3522 3523 3524 3525 3526 |
# File 'lib/aws-sdk-appstream/types.rb', line 3521 class DescribeImagesResult < Struct.new( :images, :next_token) SENSITIVE = [] include Aws::Structure end |