Class: Aws::AppStream::Types::DescribeSessionsResult
- Inherits:
-
Struct
- Object
- Struct
- Aws::AppStream::Types::DescribeSessionsResult
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-appstream/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#next_token ⇒ String
The pagination token to use to retrieve the next page of results for this operation.
-
#sessions ⇒ Array<Types::Session>
Information about the streaming sessions.
Instance Attribute Details
#next_token ⇒ String
The pagination token to use to retrieve the next page of results for this operation. If there are no more pages, this value is null.
3586 3587 3588 3589 3590 3591 |
# File 'lib/aws-sdk-appstream/types.rb', line 3586 class DescribeSessionsResult < Struct.new( :sessions, :next_token) SENSITIVE = [] include Aws::Structure end |
#sessions ⇒ Array<Types::Session>
Information about the streaming sessions.
3586 3587 3588 3589 3590 3591 |
# File 'lib/aws-sdk-appstream/types.rb', line 3586 class DescribeSessionsResult < Struct.new( :sessions, :next_token) SENSITIVE = [] include Aws::Structure end |