Class: Aws::AppStream::Types::DescribeSessionsResult
- Inherits:
-
Struct
- Object
- Struct
- Aws::AppStream::Types::DescribeSessionsResult
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-appstream/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#next_token ⇒ String
The pagination token to use to retrieve the next page of results for this operation.
-
#sessions ⇒ Array<Types::Session>
Information about the streaming sessions.
Instance Attribute Details
#next_token ⇒ String
The pagination token to use to retrieve the next page of results for this operation. If there are no more pages, this value is null.
3574 3575 3576 3577 3578 3579 |
# File 'lib/aws-sdk-appstream/types.rb', line 3574 class DescribeSessionsResult < Struct.new( :sessions, :next_token) SENSITIVE = [] include Aws::Structure end |
#sessions ⇒ Array<Types::Session>
Information about the streaming sessions.
3574 3575 3576 3577 3578 3579 |
# File 'lib/aws-sdk-appstream/types.rb', line 3574 class DescribeSessionsResult < Struct.new( :sessions, :next_token) SENSITIVE = [] include Aws::Structure end |