Class: Aws::AppStream::Types::DescribeStacksRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::AppStream::Types::DescribeStacksRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-appstream/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#names ⇒ Array<String>
The names of the stacks to describe.
-
#next_token ⇒ String
The pagination token to use to retrieve the next page of results for this operation.
Instance Attribute Details
#names ⇒ Array<String>
The names of the stacks to describe.
3648 3649 3650 3651 3652 3653 |
# File 'lib/aws-sdk-appstream/types.rb', line 3648 class DescribeStacksRequest < Struct.new( :names, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The pagination token to use to retrieve the next page of results for this operation. If this value is null, it retrieves the first page.
3648 3649 3650 3651 3652 3653 |
# File 'lib/aws-sdk-appstream/types.rb', line 3648 class DescribeStacksRequest < Struct.new( :names, :next_token) SENSITIVE = [] include Aws::Structure end |