Class: Aws::AppStream::Types::DescribeStacksResult
- Inherits:
-
Struct
- Object
- Struct
- Aws::AppStream::Types::DescribeStacksResult
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-appstream/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#next_token ⇒ String
The pagination token to use to retrieve the next page of results for this operation.
-
#stacks ⇒ Array<Types::Stack>
Information about the stacks.
Instance Attribute Details
#next_token ⇒ String
The pagination token to use to retrieve the next page of results for this operation. If there are no more pages, this value is null.
3666 3667 3668 3669 3670 3671 |
# File 'lib/aws-sdk-appstream/types.rb', line 3666 class DescribeStacksResult < Struct.new( :stacks, :next_token) SENSITIVE = [] include Aws::Structure end |
#stacks ⇒ Array<Types::Stack>
Information about the stacks.
3666 3667 3668 3669 3670 3671 |
# File 'lib/aws-sdk-appstream/types.rb', line 3666 class DescribeStacksResult < Struct.new( :stacks, :next_token) SENSITIVE = [] include Aws::Structure end |