Class: Aws::AppStream::Types::DescribeUsageReportSubscriptionsResult
- Inherits:
-
Struct
- Object
- Struct
- Aws::AppStream::Types::DescribeUsageReportSubscriptionsResult
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-appstream/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#next_token ⇒ String
The pagination token to use to retrieve the next page of results for this operation.
-
#usage_report_subscriptions ⇒ Array<Types::UsageReportSubscription>
Information about the usage report subscription.
Instance Attribute Details
#next_token ⇒ String
The pagination token to use to retrieve the next page of results for this operation. If there are no more pages, this value is null.
3616 3617 3618 3619 3620 3621 |
# File 'lib/aws-sdk-appstream/types.rb', line 3616 class DescribeUsageReportSubscriptionsResult < Struct.new( :usage_report_subscriptions, :next_token) SENSITIVE = [] include Aws::Structure end |
#usage_report_subscriptions ⇒ Array<Types::UsageReportSubscription>
Information about the usage report subscription.
3616 3617 3618 3619 3620 3621 |
# File 'lib/aws-sdk-appstream/types.rb', line 3616 class DescribeUsageReportSubscriptionsResult < Struct.new( :usage_report_subscriptions, :next_token) SENSITIVE = [] include Aws::Structure end |