Class: Aws::AppStream::Types::DescribeUserStackAssociationsResult
- Inherits:
-
Struct
- Object
- Struct
- Aws::AppStream::Types::DescribeUserStackAssociationsResult
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-appstream/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#next_token ⇒ String
The pagination token to use to retrieve the next page of results for this operation.
-
#user_stack_associations ⇒ Array<Types::UserStackAssociation>
The UserStackAssociation objects.
Instance Attribute Details
#next_token ⇒ String
The pagination token to use to retrieve the next page of results for this operation. If there are no more pages, this value is null.
3782 3783 3784 3785 3786 3787 |
# File 'lib/aws-sdk-appstream/types.rb', line 3782 class DescribeUserStackAssociationsResult < Struct.new( :user_stack_associations, :next_token) SENSITIVE = [] include Aws::Structure end |
#user_stack_associations ⇒ Array<Types::UserStackAssociation>
The UserStackAssociation objects.
3782 3783 3784 3785 3786 3787 |
# File 'lib/aws-sdk-appstream/types.rb', line 3782 class DescribeUserStackAssociationsResult < Struct.new( :user_stack_associations, :next_token) SENSITIVE = [] include Aws::Structure end |