Class: Aws::AppStream::Types::DescribeUsersResult
- Inherits:
-
Struct
- Object
- Struct
- Aws::AppStream::Types::DescribeUsersResult
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-appstream/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#next_token ⇒ String
The pagination token to use to retrieve the next page of results for this operation.
-
#users ⇒ Array<Types::User>
Information about users in the user pool.
Instance Attribute Details
#next_token ⇒ String
The pagination token to use to retrieve the next page of results for this operation. If there are no more pages, this value is null.
3836 3837 3838 3839 3840 3841 |
# File 'lib/aws-sdk-appstream/types.rb', line 3836 class DescribeUsersResult < Struct.new( :users, :next_token) SENSITIVE = [] include Aws::Structure end |
#users ⇒ Array<Types::User>
Information about users in the user pool.
3836 3837 3838 3839 3840 3841 |
# File 'lib/aws-sdk-appstream/types.rb', line 3836 class DescribeUsersResult < Struct.new( :users, :next_token) SENSITIVE = [] include Aws::Structure end |