Class: Aws::AppStream::Types::ImageBuilder
- Inherits:
-
Struct
- Object
- Struct
- Aws::AppStream::Types::ImageBuilder
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-appstream/types.rb
Overview
Describes a virtual machine that is used to create an image.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#access_endpoints ⇒ Array<Types::AccessEndpoint>
The list of virtual private cloud (VPC) interface endpoint objects.
-
#appstream_agent_version ⇒ String
The version of the WorkSpaces Applications agent that is currently being used by the image builder.
-
#arn ⇒ String
The ARN for the image builder.
-
#created_time ⇒ Time
The time stamp when the image builder was created.
-
#description ⇒ String
The description to display.
-
#disable_imdsv1 ⇒ Boolean
Indicates whether Instance Metadata Service Version 1 (IMDSv1) is disabled for the image builder.
-
#display_name ⇒ String
The image builder name to display.
-
#domain_join_info ⇒ Types::DomainJoinInfo
The name of the directory and organizational unit (OU) to use to join the image builder to a Microsoft Active Directory domain.
-
#enable_default_internet_access ⇒ Boolean
Enables or disables default internet access for the image builder.
-
#iam_role_arn ⇒ String
The ARN of the IAM role that is applied to the image builder.
-
#image_arn ⇒ String
The ARN of the image from which this builder was created.
-
#image_builder_errors ⇒ Array<Types::ResourceError>
The image builder errors.
-
#instance_type ⇒ String
The instance type for the image builder.
-
#latest_appstream_agent_version ⇒ String
Indicates whether the image builder is using the latest WorkSpaces Applications agent version or not.
-
#name ⇒ String
The name of the image builder.
-
#network_access_configuration ⇒ Types::NetworkAccessConfiguration
Describes the network details of the fleet or image builder instance.
-
#platform ⇒ String
The operating system platform of the image builder.
-
#root_volume_config ⇒ Types::VolumeConfig
The current configuration of the root volume for the image builder, including the storage size in GB.
-
#state ⇒ String
The state of the image builder.
-
#state_change_reason ⇒ Types::ImageBuilderStateChangeReason
The reason why the last state change occurred.
-
#vpc_config ⇒ Types::VpcConfig
The VPC configuration of the image builder.
Instance Attribute Details
#access_endpoints ⇒ Array<Types::AccessEndpoint>
The list of virtual private cloud (VPC) interface endpoint objects. Administrators can connect to the image builder only through the specified endpoints.
5111 5112 5113 5114 5115 5116 5117 5118 5119 5120 5121 5122 5123 5124 5125 5126 5127 5128 5129 5130 5131 5132 5133 5134 5135 |
# File 'lib/aws-sdk-appstream/types.rb', line 5111 class ImageBuilder < Struct.new( :name, :arn, :image_arn, :description, :display_name, :vpc_config, :instance_type, :platform, :iam_role_arn, :state, :state_change_reason, :created_time, :enable_default_internet_access, :domain_join_info, :network_access_configuration, :image_builder_errors, :appstream_agent_version, :access_endpoints, :root_volume_config, :latest_appstream_agent_version, :disable_imdsv1) SENSITIVE = [] include Aws::Structure end |
#appstream_agent_version ⇒ String
The version of the WorkSpaces Applications agent that is currently being used by the image builder.
5111 5112 5113 5114 5115 5116 5117 5118 5119 5120 5121 5122 5123 5124 5125 5126 5127 5128 5129 5130 5131 5132 5133 5134 5135 |
# File 'lib/aws-sdk-appstream/types.rb', line 5111 class ImageBuilder < Struct.new( :name, :arn, :image_arn, :description, :display_name, :vpc_config, :instance_type, :platform, :iam_role_arn, :state, :state_change_reason, :created_time, :enable_default_internet_access, :domain_join_info, :network_access_configuration, :image_builder_errors, :appstream_agent_version, :access_endpoints, :root_volume_config, :latest_appstream_agent_version, :disable_imdsv1) SENSITIVE = [] include Aws::Structure end |
#arn ⇒ String
The ARN for the image builder.
5111 5112 5113 5114 5115 5116 5117 5118 5119 5120 5121 5122 5123 5124 5125 5126 5127 5128 5129 5130 5131 5132 5133 5134 5135 |
# File 'lib/aws-sdk-appstream/types.rb', line 5111 class ImageBuilder < Struct.new( :name, :arn, :image_arn, :description, :display_name, :vpc_config, :instance_type, :platform, :iam_role_arn, :state, :state_change_reason, :created_time, :enable_default_internet_access, :domain_join_info, :network_access_configuration, :image_builder_errors, :appstream_agent_version, :access_endpoints, :root_volume_config, :latest_appstream_agent_version, :disable_imdsv1) SENSITIVE = [] include Aws::Structure end |
#created_time ⇒ Time
The time stamp when the image builder was created.
5111 5112 5113 5114 5115 5116 5117 5118 5119 5120 5121 5122 5123 5124 5125 5126 5127 5128 5129 5130 5131 5132 5133 5134 5135 |
# File 'lib/aws-sdk-appstream/types.rb', line 5111 class ImageBuilder < Struct.new( :name, :arn, :image_arn, :description, :display_name, :vpc_config, :instance_type, :platform, :iam_role_arn, :state, :state_change_reason, :created_time, :enable_default_internet_access, :domain_join_info, :network_access_configuration, :image_builder_errors, :appstream_agent_version, :access_endpoints, :root_volume_config, :latest_appstream_agent_version, :disable_imdsv1) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
The description to display.
5111 5112 5113 5114 5115 5116 5117 5118 5119 5120 5121 5122 5123 5124 5125 5126 5127 5128 5129 5130 5131 5132 5133 5134 5135 |
# File 'lib/aws-sdk-appstream/types.rb', line 5111 class ImageBuilder < Struct.new( :name, :arn, :image_arn, :description, :display_name, :vpc_config, :instance_type, :platform, :iam_role_arn, :state, :state_change_reason, :created_time, :enable_default_internet_access, :domain_join_info, :network_access_configuration, :image_builder_errors, :appstream_agent_version, :access_endpoints, :root_volume_config, :latest_appstream_agent_version, :disable_imdsv1) SENSITIVE = [] include Aws::Structure end |
#disable_imdsv1 ⇒ Boolean
Indicates whether Instance Metadata Service Version 1 (IMDSv1) is disabled for the image builder.
5111 5112 5113 5114 5115 5116 5117 5118 5119 5120 5121 5122 5123 5124 5125 5126 5127 5128 5129 5130 5131 5132 5133 5134 5135 |
# File 'lib/aws-sdk-appstream/types.rb', line 5111 class ImageBuilder < Struct.new( :name, :arn, :image_arn, :description, :display_name, :vpc_config, :instance_type, :platform, :iam_role_arn, :state, :state_change_reason, :created_time, :enable_default_internet_access, :domain_join_info, :network_access_configuration, :image_builder_errors, :appstream_agent_version, :access_endpoints, :root_volume_config, :latest_appstream_agent_version, :disable_imdsv1) SENSITIVE = [] include Aws::Structure end |
#display_name ⇒ String
The image builder name to display.
5111 5112 5113 5114 5115 5116 5117 5118 5119 5120 5121 5122 5123 5124 5125 5126 5127 5128 5129 5130 5131 5132 5133 5134 5135 |
# File 'lib/aws-sdk-appstream/types.rb', line 5111 class ImageBuilder < Struct.new( :name, :arn, :image_arn, :description, :display_name, :vpc_config, :instance_type, :platform, :iam_role_arn, :state, :state_change_reason, :created_time, :enable_default_internet_access, :domain_join_info, :network_access_configuration, :image_builder_errors, :appstream_agent_version, :access_endpoints, :root_volume_config, :latest_appstream_agent_version, :disable_imdsv1) SENSITIVE = [] include Aws::Structure end |
#domain_join_info ⇒ Types::DomainJoinInfo
The name of the directory and organizational unit (OU) to use to join the image builder to a Microsoft Active Directory domain.
5111 5112 5113 5114 5115 5116 5117 5118 5119 5120 5121 5122 5123 5124 5125 5126 5127 5128 5129 5130 5131 5132 5133 5134 5135 |
# File 'lib/aws-sdk-appstream/types.rb', line 5111 class ImageBuilder < Struct.new( :name, :arn, :image_arn, :description, :display_name, :vpc_config, :instance_type, :platform, :iam_role_arn, :state, :state_change_reason, :created_time, :enable_default_internet_access, :domain_join_info, :network_access_configuration, :image_builder_errors, :appstream_agent_version, :access_endpoints, :root_volume_config, :latest_appstream_agent_version, :disable_imdsv1) SENSITIVE = [] include Aws::Structure end |
#enable_default_internet_access ⇒ Boolean
Enables or disables default internet access for the image builder.
5111 5112 5113 5114 5115 5116 5117 5118 5119 5120 5121 5122 5123 5124 5125 5126 5127 5128 5129 5130 5131 5132 5133 5134 5135 |
# File 'lib/aws-sdk-appstream/types.rb', line 5111 class ImageBuilder < Struct.new( :name, :arn, :image_arn, :description, :display_name, :vpc_config, :instance_type, :platform, :iam_role_arn, :state, :state_change_reason, :created_time, :enable_default_internet_access, :domain_join_info, :network_access_configuration, :image_builder_errors, :appstream_agent_version, :access_endpoints, :root_volume_config, :latest_appstream_agent_version, :disable_imdsv1) SENSITIVE = [] include Aws::Structure end |
#iam_role_arn ⇒ String
The ARN of the IAM role that is applied to the image builder. To assume a role, the image builder calls the AWS Security Token Service (STS) ‘AssumeRole` API operation and passes the ARN of the role to use. The operation creates a new session with temporary credentials. WorkSpaces Applications retrieves the temporary credentials and creates the appstream_machine_role credential profile on the instance.
For more information, see [Using an IAM Role to Grant Permissions to Applications and Scripts Running on WorkSpaces Applications Streaming Instances] in the *Amazon WorkSpaces Applications Administration Guide*.
5111 5112 5113 5114 5115 5116 5117 5118 5119 5120 5121 5122 5123 5124 5125 5126 5127 5128 5129 5130 5131 5132 5133 5134 5135 |
# File 'lib/aws-sdk-appstream/types.rb', line 5111 class ImageBuilder < Struct.new( :name, :arn, :image_arn, :description, :display_name, :vpc_config, :instance_type, :platform, :iam_role_arn, :state, :state_change_reason, :created_time, :enable_default_internet_access, :domain_join_info, :network_access_configuration, :image_builder_errors, :appstream_agent_version, :access_endpoints, :root_volume_config, :latest_appstream_agent_version, :disable_imdsv1) SENSITIVE = [] include Aws::Structure end |
#image_arn ⇒ String
The ARN of the image from which this builder was created.
5111 5112 5113 5114 5115 5116 5117 5118 5119 5120 5121 5122 5123 5124 5125 5126 5127 5128 5129 5130 5131 5132 5133 5134 5135 |
# File 'lib/aws-sdk-appstream/types.rb', line 5111 class ImageBuilder < Struct.new( :name, :arn, :image_arn, :description, :display_name, :vpc_config, :instance_type, :platform, :iam_role_arn, :state, :state_change_reason, :created_time, :enable_default_internet_access, :domain_join_info, :network_access_configuration, :image_builder_errors, :appstream_agent_version, :access_endpoints, :root_volume_config, :latest_appstream_agent_version, :disable_imdsv1) SENSITIVE = [] include Aws::Structure end |
#image_builder_errors ⇒ Array<Types::ResourceError>
The image builder errors.
5111 5112 5113 5114 5115 5116 5117 5118 5119 5120 5121 5122 5123 5124 5125 5126 5127 5128 5129 5130 5131 5132 5133 5134 5135 |
# File 'lib/aws-sdk-appstream/types.rb', line 5111 class ImageBuilder < Struct.new( :name, :arn, :image_arn, :description, :display_name, :vpc_config, :instance_type, :platform, :iam_role_arn, :state, :state_change_reason, :created_time, :enable_default_internet_access, :domain_join_info, :network_access_configuration, :image_builder_errors, :appstream_agent_version, :access_endpoints, :root_volume_config, :latest_appstream_agent_version, :disable_imdsv1) SENSITIVE = [] include Aws::Structure end |
#instance_type ⇒ String
The instance type for the image builder. The following instance types are available:
-
stream.standard.small
-
stream.standard.medium
-
stream.standard.large
-
stream.compute.large
-
stream.compute.xlarge
-
stream.compute.2xlarge
-
stream.compute.4xlarge
-
stream.compute.8xlarge
-
stream.memory.large
-
stream.memory.xlarge
-
stream.memory.2xlarge
-
stream.memory.4xlarge
-
stream.memory.8xlarge
-
stream.memory.z1d.large
-
stream.memory.z1d.xlarge
-
stream.memory.z1d.2xlarge
-
stream.memory.z1d.3xlarge
-
stream.memory.z1d.6xlarge
-
stream.memory.z1d.12xlarge
-
stream.graphics.g4dn.xlarge
-
stream.graphics.g4dn.2xlarge
-
stream.graphics.g4dn.4xlarge
-
stream.graphics.g4dn.8xlarge
-
stream.graphics.g4dn.12xlarge
-
stream.graphics.g4dn.16xlarge
-
stream.graphics.g5.xlarge
-
stream.graphics.g5.2xlarge
-
stream.graphics.g5.4xlarge
-
stream.graphics.g5.8xlarge
-
stream.graphics.g5.16xlarge
-
stream.graphics.g5.12xlarge
-
stream.graphics.g5.24xlarge
-
stream.graphics.g6.xlarge
-
stream.graphics.g6.2xlarge
-
stream.graphics.g6.4xlarge
-
stream.graphics.g6.8xlarge
-
stream.graphics.g6.16xlarge
-
stream.graphics.g6.12xlarge
-
stream.graphics.g6.24xlarge
-
stream.graphics.gr6.4xlarge
-
stream.graphics.gr6.8xlarge
-
stream.graphics.g6f.large
-
stream.graphics.g6f.xlarge
-
stream.graphics.g6f.2xlarge
-
stream.graphics.g6f.4xlarge
-
stream.graphics.gr6f.4xlarge
5111 5112 5113 5114 5115 5116 5117 5118 5119 5120 5121 5122 5123 5124 5125 5126 5127 5128 5129 5130 5131 5132 5133 5134 5135 |
# File 'lib/aws-sdk-appstream/types.rb', line 5111 class ImageBuilder < Struct.new( :name, :arn, :image_arn, :description, :display_name, :vpc_config, :instance_type, :platform, :iam_role_arn, :state, :state_change_reason, :created_time, :enable_default_internet_access, :domain_join_info, :network_access_configuration, :image_builder_errors, :appstream_agent_version, :access_endpoints, :root_volume_config, :latest_appstream_agent_version, :disable_imdsv1) SENSITIVE = [] include Aws::Structure end |
#latest_appstream_agent_version ⇒ String
Indicates whether the image builder is using the latest WorkSpaces Applications agent version or not.
5111 5112 5113 5114 5115 5116 5117 5118 5119 5120 5121 5122 5123 5124 5125 5126 5127 5128 5129 5130 5131 5132 5133 5134 5135 |
# File 'lib/aws-sdk-appstream/types.rb', line 5111 class ImageBuilder < Struct.new( :name, :arn, :image_arn, :description, :display_name, :vpc_config, :instance_type, :platform, :iam_role_arn, :state, :state_change_reason, :created_time, :enable_default_internet_access, :domain_join_info, :network_access_configuration, :image_builder_errors, :appstream_agent_version, :access_endpoints, :root_volume_config, :latest_appstream_agent_version, :disable_imdsv1) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the image builder.
5111 5112 5113 5114 5115 5116 5117 5118 5119 5120 5121 5122 5123 5124 5125 5126 5127 5128 5129 5130 5131 5132 5133 5134 5135 |
# File 'lib/aws-sdk-appstream/types.rb', line 5111 class ImageBuilder < Struct.new( :name, :arn, :image_arn, :description, :display_name, :vpc_config, :instance_type, :platform, :iam_role_arn, :state, :state_change_reason, :created_time, :enable_default_internet_access, :domain_join_info, :network_access_configuration, :image_builder_errors, :appstream_agent_version, :access_endpoints, :root_volume_config, :latest_appstream_agent_version, :disable_imdsv1) SENSITIVE = [] include Aws::Structure end |
#network_access_configuration ⇒ Types::NetworkAccessConfiguration
Describes the network details of the fleet or image builder instance.
5111 5112 5113 5114 5115 5116 5117 5118 5119 5120 5121 5122 5123 5124 5125 5126 5127 5128 5129 5130 5131 5132 5133 5134 5135 |
# File 'lib/aws-sdk-appstream/types.rb', line 5111 class ImageBuilder < Struct.new( :name, :arn, :image_arn, :description, :display_name, :vpc_config, :instance_type, :platform, :iam_role_arn, :state, :state_change_reason, :created_time, :enable_default_internet_access, :domain_join_info, :network_access_configuration, :image_builder_errors, :appstream_agent_version, :access_endpoints, :root_volume_config, :latest_appstream_agent_version, :disable_imdsv1) SENSITIVE = [] include Aws::Structure end |
#platform ⇒ String
The operating system platform of the image builder.
5111 5112 5113 5114 5115 5116 5117 5118 5119 5120 5121 5122 5123 5124 5125 5126 5127 5128 5129 5130 5131 5132 5133 5134 5135 |
# File 'lib/aws-sdk-appstream/types.rb', line 5111 class ImageBuilder < Struct.new( :name, :arn, :image_arn, :description, :display_name, :vpc_config, :instance_type, :platform, :iam_role_arn, :state, :state_change_reason, :created_time, :enable_default_internet_access, :domain_join_info, :network_access_configuration, :image_builder_errors, :appstream_agent_version, :access_endpoints, :root_volume_config, :latest_appstream_agent_version, :disable_imdsv1) SENSITIVE = [] include Aws::Structure end |
#root_volume_config ⇒ Types::VolumeConfig
The current configuration of the root volume for the image builder, including the storage size in GB.
5111 5112 5113 5114 5115 5116 5117 5118 5119 5120 5121 5122 5123 5124 5125 5126 5127 5128 5129 5130 5131 5132 5133 5134 5135 |
# File 'lib/aws-sdk-appstream/types.rb', line 5111 class ImageBuilder < Struct.new( :name, :arn, :image_arn, :description, :display_name, :vpc_config, :instance_type, :platform, :iam_role_arn, :state, :state_change_reason, :created_time, :enable_default_internet_access, :domain_join_info, :network_access_configuration, :image_builder_errors, :appstream_agent_version, :access_endpoints, :root_volume_config, :latest_appstream_agent_version, :disable_imdsv1) SENSITIVE = [] include Aws::Structure end |
#state ⇒ String
The state of the image builder.
5111 5112 5113 5114 5115 5116 5117 5118 5119 5120 5121 5122 5123 5124 5125 5126 5127 5128 5129 5130 5131 5132 5133 5134 5135 |
# File 'lib/aws-sdk-appstream/types.rb', line 5111 class ImageBuilder < Struct.new( :name, :arn, :image_arn, :description, :display_name, :vpc_config, :instance_type, :platform, :iam_role_arn, :state, :state_change_reason, :created_time, :enable_default_internet_access, :domain_join_info, :network_access_configuration, :image_builder_errors, :appstream_agent_version, :access_endpoints, :root_volume_config, :latest_appstream_agent_version, :disable_imdsv1) SENSITIVE = [] include Aws::Structure end |
#state_change_reason ⇒ Types::ImageBuilderStateChangeReason
The reason why the last state change occurred.
5111 5112 5113 5114 5115 5116 5117 5118 5119 5120 5121 5122 5123 5124 5125 5126 5127 5128 5129 5130 5131 5132 5133 5134 5135 |
# File 'lib/aws-sdk-appstream/types.rb', line 5111 class ImageBuilder < Struct.new( :name, :arn, :image_arn, :description, :display_name, :vpc_config, :instance_type, :platform, :iam_role_arn, :state, :state_change_reason, :created_time, :enable_default_internet_access, :domain_join_info, :network_access_configuration, :image_builder_errors, :appstream_agent_version, :access_endpoints, :root_volume_config, :latest_appstream_agent_version, :disable_imdsv1) SENSITIVE = [] include Aws::Structure end |
#vpc_config ⇒ Types::VpcConfig
The VPC configuration of the image builder.
5111 5112 5113 5114 5115 5116 5117 5118 5119 5120 5121 5122 5123 5124 5125 5126 5127 5128 5129 5130 5131 5132 5133 5134 5135 |
# File 'lib/aws-sdk-appstream/types.rb', line 5111 class ImageBuilder < Struct.new( :name, :arn, :image_arn, :description, :display_name, :vpc_config, :instance_type, :platform, :iam_role_arn, :state, :state_change_reason, :created_time, :enable_default_internet_access, :domain_join_info, :network_access_configuration, :image_builder_errors, :appstream_agent_version, :access_endpoints, :root_volume_config, :latest_appstream_agent_version, :disable_imdsv1) SENSITIVE = [] include Aws::Structure end |