Class: Aws::AppStream::Types::ListExportImageTasksResult
- Inherits:
-
Struct
- Object
- Struct
- Aws::AppStream::Types::ListExportImageTasksResult
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-appstream/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#export_image_tasks ⇒ Array<Types::ExportImageTask>
The list of export image tasks that match the specified criteria.
-
#next_token ⇒ String
The pagination token to use for retrieving the next page of results.
Instance Attribute Details
#export_image_tasks ⇒ Array<Types::ExportImageTask>
The list of export image tasks that match the specified criteria.
5277 5278 5279 5280 5281 5282 |
# File 'lib/aws-sdk-appstream/types.rb', line 5277 class ListExportImageTasksResult < Struct.new( :export_image_tasks, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The pagination token to use for retrieving the next page of results. This field is only present when there are more results available.
5277 5278 5279 5280 5281 5282 |
# File 'lib/aws-sdk-appstream/types.rb', line 5277 class ListExportImageTasksResult < Struct.new( :export_image_tasks, :next_token) SENSITIVE = [] include Aws::Structure end |