Class: Aws::AppStream::Types::RuntimeValidationConfig
- Inherits:
-
Struct
- Object
- Struct
- Aws::AppStream::Types::RuntimeValidationConfig
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-appstream/types.rb
Overview
Configuration for runtime validation of imported images. This structure specifies the instance type to use for testing the imported image’s streaming capabilities.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#intended_instance_type ⇒ String
The instance type to use for runtime validation testing.
Instance Attribute Details
#intended_instance_type ⇒ String
The instance type to use for runtime validation testing. It’s recommended to use the same instance type you plan to use for your fleet to ensure accurate validation results.
5625 5626 5627 5628 5629 |
# File 'lib/aws-sdk-appstream/types.rb', line 5625 class RuntimeValidationConfig < Struct.new( :intended_instance_type) SENSITIVE = [] include Aws::Structure end |