Class: Aws::AppStream::Types::Stack
- Inherits:
-
Struct
- Object
- Struct
- Aws::AppStream::Types::Stack
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-appstream/types.rb
Overview
Describes a stack.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#access_endpoints ⇒ Array<Types::AccessEndpoint>
The list of virtual private cloud (VPC) interface endpoint objects.
-
#agent_access_config ⇒ Types::AgentAccessConfig
The agent access configuration of the stack, if agent access is enabled.
-
#application_settings ⇒ Types::ApplicationSettingsResponse
The persistent application settings for users of the stack.
-
#arn ⇒ String
The ARN of the stack.
-
#content_redirection ⇒ Types::ContentRedirection
Configuration for bidirectional URL redirection between the streaming session and the local client.
-
#created_time ⇒ Time
The time the stack was created.
-
#description ⇒ String
The description to display.
-
#display_name ⇒ String
The stack name to display.
-
#embed_host_domains ⇒ Array<String>
The domains where WorkSpaces Applications streaming sessions can be embedded in an iframe.
-
#feedback_url ⇒ String
The URL that users are redirected to after they click the Send Feedback link.
-
#name ⇒ String
The name of the stack.
-
#redirect_url ⇒ String
The URL that users are redirected to after their streaming session ends.
-
#stack_errors ⇒ Array<Types::StackError>
The errors for the stack.
-
#storage_connectors ⇒ Array<Types::StorageConnector>
The storage connectors to enable.
-
#streaming_experience_settings ⇒ Types::StreamingExperienceSettings
The streaming protocol you want your stack to prefer.
-
#user_settings ⇒ Array<Types::UserSetting>
The actions that are enabled or disabled for users during their streaming sessions.
Instance Attribute Details
#access_endpoints ⇒ Array<Types::AccessEndpoint>
The list of virtual private cloud (VPC) interface endpoint objects. Users of the stack can connect to WorkSpaces Applications only through the specified endpoints.
5975 5976 5977 5978 5979 5980 5981 5982 5983 5984 5985 5986 5987 5988 5989 5990 5991 5992 5993 5994 |
# File 'lib/aws-sdk-appstream/types.rb', line 5975 class Stack < Struct.new( :arn, :name, :description, :display_name, :created_time, :storage_connectors, :redirect_url, :feedback_url, :stack_errors, :user_settings, :application_settings, :access_endpoints, :embed_host_domains, :streaming_experience_settings, :content_redirection, :agent_access_config) SENSITIVE = [] include Aws::Structure end |
#agent_access_config ⇒ Types::AgentAccessConfig
The agent access configuration of the stack, if agent access is enabled.
5975 5976 5977 5978 5979 5980 5981 5982 5983 5984 5985 5986 5987 5988 5989 5990 5991 5992 5993 5994 |
# File 'lib/aws-sdk-appstream/types.rb', line 5975 class Stack < Struct.new( :arn, :name, :description, :display_name, :created_time, :storage_connectors, :redirect_url, :feedback_url, :stack_errors, :user_settings, :application_settings, :access_endpoints, :embed_host_domains, :streaming_experience_settings, :content_redirection, :agent_access_config) SENSITIVE = [] include Aws::Structure end |
#application_settings ⇒ Types::ApplicationSettingsResponse
The persistent application settings for users of the stack.
5975 5976 5977 5978 5979 5980 5981 5982 5983 5984 5985 5986 5987 5988 5989 5990 5991 5992 5993 5994 |
# File 'lib/aws-sdk-appstream/types.rb', line 5975 class Stack < Struct.new( :arn, :name, :description, :display_name, :created_time, :storage_connectors, :redirect_url, :feedback_url, :stack_errors, :user_settings, :application_settings, :access_endpoints, :embed_host_domains, :streaming_experience_settings, :content_redirection, :agent_access_config) SENSITIVE = [] include Aws::Structure end |
#arn ⇒ String
The ARN of the stack.
5975 5976 5977 5978 5979 5980 5981 5982 5983 5984 5985 5986 5987 5988 5989 5990 5991 5992 5993 5994 |
# File 'lib/aws-sdk-appstream/types.rb', line 5975 class Stack < Struct.new( :arn, :name, :description, :display_name, :created_time, :storage_connectors, :redirect_url, :feedback_url, :stack_errors, :user_settings, :application_settings, :access_endpoints, :embed_host_domains, :streaming_experience_settings, :content_redirection, :agent_access_config) SENSITIVE = [] include Aws::Structure end |
#content_redirection ⇒ Types::ContentRedirection
Configuration for bidirectional URL redirection between the streaming session and the local client. Use HostToClient to redirect URLs from the remote desktop to the local browser.
5975 5976 5977 5978 5979 5980 5981 5982 5983 5984 5985 5986 5987 5988 5989 5990 5991 5992 5993 5994 |
# File 'lib/aws-sdk-appstream/types.rb', line 5975 class Stack < Struct.new( :arn, :name, :description, :display_name, :created_time, :storage_connectors, :redirect_url, :feedback_url, :stack_errors, :user_settings, :application_settings, :access_endpoints, :embed_host_domains, :streaming_experience_settings, :content_redirection, :agent_access_config) SENSITIVE = [] include Aws::Structure end |
#created_time ⇒ Time
The time the stack was created.
5975 5976 5977 5978 5979 5980 5981 5982 5983 5984 5985 5986 5987 5988 5989 5990 5991 5992 5993 5994 |
# File 'lib/aws-sdk-appstream/types.rb', line 5975 class Stack < Struct.new( :arn, :name, :description, :display_name, :created_time, :storage_connectors, :redirect_url, :feedback_url, :stack_errors, :user_settings, :application_settings, :access_endpoints, :embed_host_domains, :streaming_experience_settings, :content_redirection, :agent_access_config) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
The description to display.
5975 5976 5977 5978 5979 5980 5981 5982 5983 5984 5985 5986 5987 5988 5989 5990 5991 5992 5993 5994 |
# File 'lib/aws-sdk-appstream/types.rb', line 5975 class Stack < Struct.new( :arn, :name, :description, :display_name, :created_time, :storage_connectors, :redirect_url, :feedback_url, :stack_errors, :user_settings, :application_settings, :access_endpoints, :embed_host_domains, :streaming_experience_settings, :content_redirection, :agent_access_config) SENSITIVE = [] include Aws::Structure end |
#display_name ⇒ String
The stack name to display.
5975 5976 5977 5978 5979 5980 5981 5982 5983 5984 5985 5986 5987 5988 5989 5990 5991 5992 5993 5994 |
# File 'lib/aws-sdk-appstream/types.rb', line 5975 class Stack < Struct.new( :arn, :name, :description, :display_name, :created_time, :storage_connectors, :redirect_url, :feedback_url, :stack_errors, :user_settings, :application_settings, :access_endpoints, :embed_host_domains, :streaming_experience_settings, :content_redirection, :agent_access_config) SENSITIVE = [] include Aws::Structure end |
#embed_host_domains ⇒ Array<String>
The domains where WorkSpaces Applications streaming sessions can be embedded in an iframe. You must approve the domains that you want to host embedded WorkSpaces Applications streaming sessions.
5975 5976 5977 5978 5979 5980 5981 5982 5983 5984 5985 5986 5987 5988 5989 5990 5991 5992 5993 5994 |
# File 'lib/aws-sdk-appstream/types.rb', line 5975 class Stack < Struct.new( :arn, :name, :description, :display_name, :created_time, :storage_connectors, :redirect_url, :feedback_url, :stack_errors, :user_settings, :application_settings, :access_endpoints, :embed_host_domains, :streaming_experience_settings, :content_redirection, :agent_access_config) SENSITIVE = [] include Aws::Structure end |
#feedback_url ⇒ String
The URL that users are redirected to after they click the Send Feedback link. If no URL is specified, no Send Feedback link is displayed.
5975 5976 5977 5978 5979 5980 5981 5982 5983 5984 5985 5986 5987 5988 5989 5990 5991 5992 5993 5994 |
# File 'lib/aws-sdk-appstream/types.rb', line 5975 class Stack < Struct.new( :arn, :name, :description, :display_name, :created_time, :storage_connectors, :redirect_url, :feedback_url, :stack_errors, :user_settings, :application_settings, :access_endpoints, :embed_host_domains, :streaming_experience_settings, :content_redirection, :agent_access_config) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the stack.
5975 5976 5977 5978 5979 5980 5981 5982 5983 5984 5985 5986 5987 5988 5989 5990 5991 5992 5993 5994 |
# File 'lib/aws-sdk-appstream/types.rb', line 5975 class Stack < Struct.new( :arn, :name, :description, :display_name, :created_time, :storage_connectors, :redirect_url, :feedback_url, :stack_errors, :user_settings, :application_settings, :access_endpoints, :embed_host_domains, :streaming_experience_settings, :content_redirection, :agent_access_config) SENSITIVE = [] include Aws::Structure end |
#redirect_url ⇒ String
The URL that users are redirected to after their streaming session ends.
5975 5976 5977 5978 5979 5980 5981 5982 5983 5984 5985 5986 5987 5988 5989 5990 5991 5992 5993 5994 |
# File 'lib/aws-sdk-appstream/types.rb', line 5975 class Stack < Struct.new( :arn, :name, :description, :display_name, :created_time, :storage_connectors, :redirect_url, :feedback_url, :stack_errors, :user_settings, :application_settings, :access_endpoints, :embed_host_domains, :streaming_experience_settings, :content_redirection, :agent_access_config) SENSITIVE = [] include Aws::Structure end |
#stack_errors ⇒ Array<Types::StackError>
The errors for the stack.
5975 5976 5977 5978 5979 5980 5981 5982 5983 5984 5985 5986 5987 5988 5989 5990 5991 5992 5993 5994 |
# File 'lib/aws-sdk-appstream/types.rb', line 5975 class Stack < Struct.new( :arn, :name, :description, :display_name, :created_time, :storage_connectors, :redirect_url, :feedback_url, :stack_errors, :user_settings, :application_settings, :access_endpoints, :embed_host_domains, :streaming_experience_settings, :content_redirection, :agent_access_config) SENSITIVE = [] include Aws::Structure end |
#storage_connectors ⇒ Array<Types::StorageConnector>
The storage connectors to enable.
5975 5976 5977 5978 5979 5980 5981 5982 5983 5984 5985 5986 5987 5988 5989 5990 5991 5992 5993 5994 |
# File 'lib/aws-sdk-appstream/types.rb', line 5975 class Stack < Struct.new( :arn, :name, :description, :display_name, :created_time, :storage_connectors, :redirect_url, :feedback_url, :stack_errors, :user_settings, :application_settings, :access_endpoints, :embed_host_domains, :streaming_experience_settings, :content_redirection, :agent_access_config) SENSITIVE = [] include Aws::Structure end |
#streaming_experience_settings ⇒ Types::StreamingExperienceSettings
The streaming protocol you want your stack to prefer. This can be UDP or TCP. Currently, UDP is only supported in the Windows native client.
5975 5976 5977 5978 5979 5980 5981 5982 5983 5984 5985 5986 5987 5988 5989 5990 5991 5992 5993 5994 |
# File 'lib/aws-sdk-appstream/types.rb', line 5975 class Stack < Struct.new( :arn, :name, :description, :display_name, :created_time, :storage_connectors, :redirect_url, :feedback_url, :stack_errors, :user_settings, :application_settings, :access_endpoints, :embed_host_domains, :streaming_experience_settings, :content_redirection, :agent_access_config) SENSITIVE = [] include Aws::Structure end |
#user_settings ⇒ Array<Types::UserSetting>
The actions that are enabled or disabled for users during their streaming sessions. By default these actions are enabled.
5975 5976 5977 5978 5979 5980 5981 5982 5983 5984 5985 5986 5987 5988 5989 5990 5991 5992 5993 5994 |
# File 'lib/aws-sdk-appstream/types.rb', line 5975 class Stack < Struct.new( :arn, :name, :description, :display_name, :created_time, :storage_connectors, :redirect_url, :feedback_url, :stack_errors, :user_settings, :application_settings, :access_endpoints, :embed_host_domains, :streaming_experience_settings, :content_redirection, :agent_access_config) SENSITIVE = [] include Aws::Structure end |