Class: Aws::AppStream::Types::StorageConnector

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-appstream/types.rb

Overview

Describes a connector that enables persistent storage for users.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#connector_typeString

The type of storage connector.

Returns:

  • (String)


6010
6011
6012
6013
6014
6015
6016
6017
# File 'lib/aws-sdk-appstream/types.rb', line 6010

class StorageConnector < Struct.new(
  :connector_type,
  :resource_identifier,
  :domains,
  :domains_require_admin_consent)
  SENSITIVE = []
  include Aws::Structure
end

#domainsArray<String>

The names of the domains for the account.

Returns:

  • (Array<String>)


6010
6011
6012
6013
6014
6015
6016
6017
# File 'lib/aws-sdk-appstream/types.rb', line 6010

class StorageConnector < Struct.new(
  :connector_type,
  :resource_identifier,
  :domains,
  :domains_require_admin_consent)
  SENSITIVE = []
  include Aws::Structure
end

The OneDrive for Business domains where you require admin consent when users try to link their OneDrive account to WorkSpaces Applications. The attribute can only be specified when ConnectorType=ONE_DRIVE.

Returns:

  • (Array<String>)


6010
6011
6012
6013
6014
6015
6016
6017
# File 'lib/aws-sdk-appstream/types.rb', line 6010

class StorageConnector < Struct.new(
  :connector_type,
  :resource_identifier,
  :domains,
  :domains_require_admin_consent)
  SENSITIVE = []
  include Aws::Structure
end

#resource_identifierString

The ARN of the storage connector.

Returns:

  • (String)


6010
6011
6012
6013
6014
6015
6016
6017
# File 'lib/aws-sdk-appstream/types.rb', line 6010

class StorageConnector < Struct.new(
  :connector_type,
  :resource_identifier,
  :domains,
  :domains_require_admin_consent)
  SENSITIVE = []
  include Aws::Structure
end