Class: Aws::AppStream::Types::UpdateStackRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-appstream/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#access_endpointsArray<Types::AccessEndpoint>

The list of interface VPC endpoint (interface endpoint) objects. Users of the stack can connect to WorkSpaces Applications only through the specified endpoints.

Returns:



6847
6848
6849
6850
6851
6852
6853
6854
6855
6856
6857
6858
6859
6860
6861
6862
6863
# File 'lib/aws-sdk-appstream/types.rb', line 6847

class UpdateStackRequest < Struct.new(
  :display_name,
  :description,
  :name,
  :storage_connectors,
  :delete_storage_connectors,
  :redirect_url,
  :feedback_url,
  :attributes_to_delete,
  :user_settings,
  :application_settings,
  :access_endpoints,
  :embed_host_domains,
  :streaming_experience_settings)
  SENSITIVE = []
  include Aws::Structure
end

#application_settingsTypes::ApplicationSettings

The persistent application settings for users of a stack. When these settings are enabled, changes that users make to applications and Windows settings are automatically saved after each session and applied to the next session.



6847
6848
6849
6850
6851
6852
6853
6854
6855
6856
6857
6858
6859
6860
6861
6862
6863
# File 'lib/aws-sdk-appstream/types.rb', line 6847

class UpdateStackRequest < Struct.new(
  :display_name,
  :description,
  :name,
  :storage_connectors,
  :delete_storage_connectors,
  :redirect_url,
  :feedback_url,
  :attributes_to_delete,
  :user_settings,
  :application_settings,
  :access_endpoints,
  :embed_host_domains,
  :streaming_experience_settings)
  SENSITIVE = []
  include Aws::Structure
end

#attributes_to_deleteArray<String>

The stack attributes to delete.

Returns:

  • (Array<String>)


6847
6848
6849
6850
6851
6852
6853
6854
6855
6856
6857
6858
6859
6860
6861
6862
6863
# File 'lib/aws-sdk-appstream/types.rb', line 6847

class UpdateStackRequest < Struct.new(
  :display_name,
  :description,
  :name,
  :storage_connectors,
  :delete_storage_connectors,
  :redirect_url,
  :feedback_url,
  :attributes_to_delete,
  :user_settings,
  :application_settings,
  :access_endpoints,
  :embed_host_domains,
  :streaming_experience_settings)
  SENSITIVE = []
  include Aws::Structure
end

#delete_storage_connectorsBoolean

Deletes the storage connectors currently enabled for the stack.

Returns:

  • (Boolean)


6847
6848
6849
6850
6851
6852
6853
6854
6855
6856
6857
6858
6859
6860
6861
6862
6863
# File 'lib/aws-sdk-appstream/types.rb', line 6847

class UpdateStackRequest < Struct.new(
  :display_name,
  :description,
  :name,
  :storage_connectors,
  :delete_storage_connectors,
  :redirect_url,
  :feedback_url,
  :attributes_to_delete,
  :user_settings,
  :application_settings,
  :access_endpoints,
  :embed_host_domains,
  :streaming_experience_settings)
  SENSITIVE = []
  include Aws::Structure
end

#descriptionString

The description to display.

Returns:

  • (String)


6847
6848
6849
6850
6851
6852
6853
6854
6855
6856
6857
6858
6859
6860
6861
6862
6863
# File 'lib/aws-sdk-appstream/types.rb', line 6847

class UpdateStackRequest < Struct.new(
  :display_name,
  :description,
  :name,
  :storage_connectors,
  :delete_storage_connectors,
  :redirect_url,
  :feedback_url,
  :attributes_to_delete,
  :user_settings,
  :application_settings,
  :access_endpoints,
  :embed_host_domains,
  :streaming_experience_settings)
  SENSITIVE = []
  include Aws::Structure
end

#display_nameString

The stack name to display.

Returns:

  • (String)


6847
6848
6849
6850
6851
6852
6853
6854
6855
6856
6857
6858
6859
6860
6861
6862
6863
# File 'lib/aws-sdk-appstream/types.rb', line 6847

class UpdateStackRequest < Struct.new(
  :display_name,
  :description,
  :name,
  :storage_connectors,
  :delete_storage_connectors,
  :redirect_url,
  :feedback_url,
  :attributes_to_delete,
  :user_settings,
  :application_settings,
  :access_endpoints,
  :embed_host_domains,
  :streaming_experience_settings)
  SENSITIVE = []
  include Aws::Structure
end

#embed_host_domainsArray<String>

The domains where WorkSpaces Applications streaming sessions can be embedded in an iframe. You must approve the domains that you want to host embedded WorkSpaces Applications streaming sessions.

Returns:

  • (Array<String>)


6847
6848
6849
6850
6851
6852
6853
6854
6855
6856
6857
6858
6859
6860
6861
6862
6863
# File 'lib/aws-sdk-appstream/types.rb', line 6847

class UpdateStackRequest < Struct.new(
  :display_name,
  :description,
  :name,
  :storage_connectors,
  :delete_storage_connectors,
  :redirect_url,
  :feedback_url,
  :attributes_to_delete,
  :user_settings,
  :application_settings,
  :access_endpoints,
  :embed_host_domains,
  :streaming_experience_settings)
  SENSITIVE = []
  include Aws::Structure
end

#feedback_urlString

The URL that users are redirected to after they choose the Send Feedback link. If no URL is specified, no Send Feedback link is displayed.

Returns:

  • (String)


6847
6848
6849
6850
6851
6852
6853
6854
6855
6856
6857
6858
6859
6860
6861
6862
6863
# File 'lib/aws-sdk-appstream/types.rb', line 6847

class UpdateStackRequest < Struct.new(
  :display_name,
  :description,
  :name,
  :storage_connectors,
  :delete_storage_connectors,
  :redirect_url,
  :feedback_url,
  :attributes_to_delete,
  :user_settings,
  :application_settings,
  :access_endpoints,
  :embed_host_domains,
  :streaming_experience_settings)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The name of the stack.

Returns:

  • (String)


6847
6848
6849
6850
6851
6852
6853
6854
6855
6856
6857
6858
6859
6860
6861
6862
6863
# File 'lib/aws-sdk-appstream/types.rb', line 6847

class UpdateStackRequest < Struct.new(
  :display_name,
  :description,
  :name,
  :storage_connectors,
  :delete_storage_connectors,
  :redirect_url,
  :feedback_url,
  :attributes_to_delete,
  :user_settings,
  :application_settings,
  :access_endpoints,
  :embed_host_domains,
  :streaming_experience_settings)
  SENSITIVE = []
  include Aws::Structure
end

#redirect_urlString

The URL that users are redirected to after their streaming session ends.

Returns:

  • (String)


6847
6848
6849
6850
6851
6852
6853
6854
6855
6856
6857
6858
6859
6860
6861
6862
6863
# File 'lib/aws-sdk-appstream/types.rb', line 6847

class UpdateStackRequest < Struct.new(
  :display_name,
  :description,
  :name,
  :storage_connectors,
  :delete_storage_connectors,
  :redirect_url,
  :feedback_url,
  :attributes_to_delete,
  :user_settings,
  :application_settings,
  :access_endpoints,
  :embed_host_domains,
  :streaming_experience_settings)
  SENSITIVE = []
  include Aws::Structure
end

#storage_connectorsArray<Types::StorageConnector>

The storage connectors to enable.

Returns:



6847
6848
6849
6850
6851
6852
6853
6854
6855
6856
6857
6858
6859
6860
6861
6862
6863
# File 'lib/aws-sdk-appstream/types.rb', line 6847

class UpdateStackRequest < Struct.new(
  :display_name,
  :description,
  :name,
  :storage_connectors,
  :delete_storage_connectors,
  :redirect_url,
  :feedback_url,
  :attributes_to_delete,
  :user_settings,
  :application_settings,
  :access_endpoints,
  :embed_host_domains,
  :streaming_experience_settings)
  SENSITIVE = []
  include Aws::Structure
end

#streaming_experience_settingsTypes::StreamingExperienceSettings

The streaming protocol you want your stack to prefer. This can be UDP or TCP. Currently, UDP is only supported in the Windows native client.



6847
6848
6849
6850
6851
6852
6853
6854
6855
6856
6857
6858
6859
6860
6861
6862
6863
# File 'lib/aws-sdk-appstream/types.rb', line 6847

class UpdateStackRequest < Struct.new(
  :display_name,
  :description,
  :name,
  :storage_connectors,
  :delete_storage_connectors,
  :redirect_url,
  :feedback_url,
  :attributes_to_delete,
  :user_settings,
  :application_settings,
  :access_endpoints,
  :embed_host_domains,
  :streaming_experience_settings)
  SENSITIVE = []
  include Aws::Structure
end

#user_settingsArray<Types::UserSetting>

The actions that are enabled or disabled for users during their streaming sessions. By default, these actions are enabled.

Returns:



6847
6848
6849
6850
6851
6852
6853
6854
6855
6856
6857
6858
6859
6860
6861
6862
6863
# File 'lib/aws-sdk-appstream/types.rb', line 6847

class UpdateStackRequest < Struct.new(
  :display_name,
  :description,
  :name,
  :storage_connectors,
  :delete_storage_connectors,
  :redirect_url,
  :feedback_url,
  :attributes_to_delete,
  :user_settings,
  :application_settings,
  :access_endpoints,
  :embed_host_domains,
  :streaming_experience_settings)
  SENSITIVE = []
  include Aws::Structure
end