Class: Aws::AppStream::Types::UpdateThemeForStackRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-appstream/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#attributes_to_deleteArray<String>

The attributes to delete.

Returns:

  • (Array<String>)


7001
7002
7003
7004
7005
7006
7007
7008
7009
7010
7011
7012
# File 'lib/aws-sdk-appstream/types.rb', line 7001

class UpdateThemeForStackRequest < Struct.new(
  :stack_name,
  :footer_links,
  :title_text,
  :theme_styling,
  :organization_logo_s3_location,
  :favicon_s3_location,
  :state,
  :attributes_to_delete)
  SENSITIVE = []
  include Aws::Structure
end

#favicon_s3_locationTypes::S3Location

The S3 location of the favicon. The favicon enables users to recognize their application streaming site in a browser full of tabs or bookmarks. It is displayed at the top of the browser tab for the application streaming site during users’ streaming sessions.

Returns:



7001
7002
7003
7004
7005
7006
7007
7008
7009
7010
7011
7012
# File 'lib/aws-sdk-appstream/types.rb', line 7001

class UpdateThemeForStackRequest < Struct.new(
  :stack_name,
  :footer_links,
  :title_text,
  :theme_styling,
  :organization_logo_s3_location,
  :favicon_s3_location,
  :state,
  :attributes_to_delete)
  SENSITIVE = []
  include Aws::Structure
end

The links that are displayed in the footer of the streaming application catalog page. These links are helpful resources for users, such as the organization’s IT support and product marketing sites.

Returns:



7001
7002
7003
7004
7005
7006
7007
7008
7009
7010
7011
7012
# File 'lib/aws-sdk-appstream/types.rb', line 7001

class UpdateThemeForStackRequest < Struct.new(
  :stack_name,
  :footer_links,
  :title_text,
  :theme_styling,
  :organization_logo_s3_location,
  :favicon_s3_location,
  :state,
  :attributes_to_delete)
  SENSITIVE = []
  include Aws::Structure
end

#organization_logo_s3_locationTypes::S3Location

The organization logo that appears on the streaming application catalog page.

Returns:



7001
7002
7003
7004
7005
7006
7007
7008
7009
7010
7011
7012
# File 'lib/aws-sdk-appstream/types.rb', line 7001

class UpdateThemeForStackRequest < Struct.new(
  :stack_name,
  :footer_links,
  :title_text,
  :theme_styling,
  :organization_logo_s3_location,
  :favicon_s3_location,
  :state,
  :attributes_to_delete)
  SENSITIVE = []
  include Aws::Structure
end

#stack_nameString

The name of the stack for the theme.

Returns:

  • (String)


7001
7002
7003
7004
7005
7006
7007
7008
7009
7010
7011
7012
# File 'lib/aws-sdk-appstream/types.rb', line 7001

class UpdateThemeForStackRequest < Struct.new(
  :stack_name,
  :footer_links,
  :title_text,
  :theme_styling,
  :organization_logo_s3_location,
  :favicon_s3_location,
  :state,
  :attributes_to_delete)
  SENSITIVE = []
  include Aws::Structure
end

#stateString

Specifies whether custom branding should be applied to catalog page or not.

Returns:

  • (String)


7001
7002
7003
7004
7005
7006
7007
7008
7009
7010
7011
7012
# File 'lib/aws-sdk-appstream/types.rb', line 7001

class UpdateThemeForStackRequest < Struct.new(
  :stack_name,
  :footer_links,
  :title_text,
  :theme_styling,
  :organization_logo_s3_location,
  :favicon_s3_location,
  :state,
  :attributes_to_delete)
  SENSITIVE = []
  include Aws::Structure
end

#theme_stylingString

The color theme that is applied to website links, text, and buttons. These colors are also applied as accents in the background for the streaming application catalog page.

Returns:

  • (String)


7001
7002
7003
7004
7005
7006
7007
7008
7009
7010
7011
7012
# File 'lib/aws-sdk-appstream/types.rb', line 7001

class UpdateThemeForStackRequest < Struct.new(
  :stack_name,
  :footer_links,
  :title_text,
  :theme_styling,
  :organization_logo_s3_location,
  :favicon_s3_location,
  :state,
  :attributes_to_delete)
  SENSITIVE = []
  include Aws::Structure
end

#title_textString

The title that is displayed at the top of the browser tab during users’ application streaming sessions.

Returns:

  • (String)


7001
7002
7003
7004
7005
7006
7007
7008
7009
7010
7011
7012
# File 'lib/aws-sdk-appstream/types.rb', line 7001

class UpdateThemeForStackRequest < Struct.new(
  :stack_name,
  :footer_links,
  :title_text,
  :theme_styling,
  :organization_logo_s3_location,
  :favicon_s3_location,
  :state,
  :attributes_to_delete)
  SENSITIVE = []
  include Aws::Structure
end