Class: Aws::AppStream::Types::UsageReportSubscription

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-appstream/types.rb

Overview

Describes information about the usage report subscription.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#last_generated_report_dateTime

The time when the last usage report was generated.

Returns:

  • (Time)


7209
7210
7211
7212
7213
7214
7215
7216
# File 'lib/aws-sdk-appstream/types.rb', line 7209

class UsageReportSubscription < Struct.new(
  :s3_bucket_name,
  :schedule,
  :last_generated_report_date,
  :subscription_errors)
  SENSITIVE = []
  include Aws::Structure
end

#s3_bucket_nameString

The Amazon S3 bucket where generated reports are stored.

If you enabled on-instance session scripts and Amazon S3 logging for your session script configuration, WorkSpaces Applications created an S3 bucket to store the script output. The bucket is unique to your account and Region. When you enable usage reporting in this case, WorkSpaces Applications uses the same bucket to store your usage reports. If you haven’t already enabled on-instance session scripts, when you enable usage reports, WorkSpaces Applications creates a new S3 bucket.

Returns:

  • (String)


7209
7210
7211
7212
7213
7214
7215
7216
# File 'lib/aws-sdk-appstream/types.rb', line 7209

class UsageReportSubscription < Struct.new(
  :s3_bucket_name,
  :schedule,
  :last_generated_report_date,
  :subscription_errors)
  SENSITIVE = []
  include Aws::Structure
end

#scheduleString

The schedule for generating usage reports.

Returns:

  • (String)


7209
7210
7211
7212
7213
7214
7215
7216
# File 'lib/aws-sdk-appstream/types.rb', line 7209

class UsageReportSubscription < Struct.new(
  :s3_bucket_name,
  :schedule,
  :last_generated_report_date,
  :subscription_errors)
  SENSITIVE = []
  include Aws::Structure
end

#subscription_errorsArray<Types::LastReportGenerationExecutionError>

The errors that were returned if usage reports couldn’t be generated.



7209
7210
7211
7212
7213
7214
7215
7216
# File 'lib/aws-sdk-appstream/types.rb', line 7209

class UsageReportSubscription < Struct.new(
  :s3_bucket_name,
  :schedule,
  :last_generated_report_date,
  :subscription_errors)
  SENSITIVE = []
  include Aws::Structure
end