Class: Aws::AppStream::Types::VolumeConfig
- Inherits:
-
Struct
- Object
- Struct
- Aws::AppStream::Types::VolumeConfig
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-appstream/types.rb
Overview
Configuration for the root volume of fleet instances and image builders. This allows you to customize the storage capacity beyond the default 200 GB.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#volume_size_in_gb ⇒ Integer
The size of the root volume in GB.
Instance Attribute Details
#volume_size_in_gb ⇒ Integer
The size of the root volume in GB. Valid range is 200-500 GB. The default is 200 GB, which is included in the hourly instance rate. Additional storage beyond 200 GB incurs extra charges and applies to instances regardless of their running state.
7394 7395 7396 7397 7398 |
# File 'lib/aws-sdk-appstream/types.rb', line 7394 class VolumeConfig < Struct.new( :volume_size_in_gb) SENSITIVE = [] include Aws::Structure end |